
/***********************************************************************************/
/* Copyright (c) 2018, SAS Institute Inc., Cary, NC, USA, All Rights Reserved      */
/*                                                                                 */
/* NAME:          ecmrr_efile_fincen_sarx_data                                     */
/* PRODUCT:       Enterprise Case Management                                       */
/* PURPOSE:       Transform the RR data for SARX e-filing                          */
/* PARAMETERS:                                                                     */
/*                rr_subset: name of table containing all RR_RK to be refiled      */
/*                rr_config_rk: key of the report to e-file (required)             */
/* NOTE:                                                                           */
/***********************************************************************************/
%macro ecmrr_efile_fincen_sarx_data(rr_subset_dsn=, form_config_rk=211);
                                          

%put %sysfunc(sasmsg(&smdds,GEN_MAC_START_NOTE,NOQUOTE,&sysmacroname)) ;

%let successYN=Y; 

proc sort data=&rr_subset_dsn;
     by rr_rk;
run;
 

%ecmrr_efile_fincen_sarx_detail(rr_subset_dsn=&rr_subset_dsn, outdsn=rr_udf);

%if &successYN=N %then %goto mExit;

 
filename rawxml "%sysfunc(pathname(work))/sarxRaw.xml";
%let x_filed_dt=%sysfunc(today(),best);

%ecmrr_efile_fincen_sarx_sum(rr_udf_dsn=rr_udf, outfref=rawxml,x_filed_dt=&x_filed_dt);

%if &successYN=N %then %goto mExit;

/* creating data for data base update */
/* z_rr_efiled will be used by ecmrr_efile_fincen_sarx_driver */ 
data  z_rr_efiled;
      set &rr_subset_dsn;
      efile_report_seq_no=_n_;
	  x_filed_dt=&x_filed_dt;
	  format x_filed_dt nldate10.;
run;  

%if &syserr > 4 %then 
%do;      
     %put ERROR: cannot generate rawXml.;
	 %let successYN=N;
     %goto mExit;
%end;

%if &successYN ne N %then
%do;
    %if %symexist(efile_rk) %then
	%do;
        %if &efile_rk ne %then
        %do;
             %ecmrr_efile_fincen_sarx_attach( udf_dsn=rr_udf,
									 attachment_udf_nm=X_SAR_ATTACHMENT_NM,  
                                     efile_rk=&efile_rk,
                                     form_config_rk=&form_config_rk);
		%end;
    %end;

    %if &successYN=N %then %goto mExit;
%end;
%else
%do;
   %goto mExit;
%end;
    

%mExit: 

 
%put %sysfunc(sasmsg(&smdds,GEN_MAC_END_NOTE,NOQUOTE,&sysmacroname)) ;

%mend;
 
