
/***********************************************************************************/
/* Copyright (c) 2018, SAS Institute Inc., Cary, NC, USA, All Rights Reserved      */
/*                                                                                 */
/* NAME:          ecmrr_efile_fincen_sarx_detail                                   */
/* PRODUCT:       Enterprise Case Management                                       */
/* PURPOSE:       Extract and transform the udf values of the reports in the efile.*/
/* PARAMETERS:                                                                     */
/*                rr_subset_dsn: name of the table containing the list of reports  */
/*                        to be processed.                                         */
/*                outdsn: output data set name                                     */
/***********************************************************************************/

%macro ecmrr_efile_fincen_sarx_detail(rr_subset_dsn=, 
                                      outdsn=rr_udf
                                      );
                                          
%put %sysfunc(sasmsg(&smdds,GEN_MAC_START_NOTE,NOQUOTE,&sysmacroname)) ;


%let sucessYN=Y;

  /***********************************************/
  /* Create SAS formats for code conversion      */ 
  /***********************************************/

   proc format cntlin=ecm_form.sarx_code_mapping (rename=(format_nm=fmtname
                                                          format_type=type
                                                          input_cd=start
													      output_cd=label)
											       where=(label ne '')
													  
                                                  );
   run;

   %if &syserr > 4 %then 
   %do;
          %let successYN=N;
          %put %sysfunc(sasmsg(&smdds,GEN_STP_ABORT,NOQUOTE,&sysmacroname)) ;
          %goto mExit;
   %end;
    
  
   %let format_list=;

   proc sql noprint;
        select distinct quote(strip(format_nm)) into :format_list separated by ' '
	    from ecm_form.sarx_code_mapping
	    where output_cd ne ''
	 ;
    quit;

	%if &sqlrc > 4 %then 
    %do;
          %let successYN=N;
          %put %sysfunc(sasmsg(&smdds,GEN_STP_ABORT,NOQUOTE,&sysmacroname)) ;
          %goto mExit;
    %end;
    

    %if &ecm_debug=Y %then %put &format_list;


/***********************************************/
/* Get RR records                              */
/* and write udf nams and values into xml      */
/***********************************************/

    
   /* List the udf tables that are relevant to SARX */
	 
	   
	%let table_wh="X_BRANCH" "X_COMMODITY" "X_CUSIP"  "X_FILING_INST_SF_TYPE" "X_INSTITUTION" "X_INST_SF_TYPE"
	"X_IP_ADDRESS" "X_MARKET" "X_PRODUCT" "X_CYBER_EVENT" "X_SAR_CASINO_TYPE" "X_SAR_FRAUD_TYPE" "X_SAR_ID_TYPE" "X_SAR_INSTRUMENT_TYPE"
	"X_SAR_INSURANCE_TYPE" "X_SAR_ML_TYPE" "X_SAR_MORTGAGE_TYPE" "X_SAR_OTHER_TYPE" "X_SAR_PROD_TYPE" "X_SAR_SF_TYPE"
	"X_SAR_STRUCT_TYPE" "X_SAR_TERRORIST_TYPE" "X_SAR_CYBER_TYPE" "X_SUBJECT" "X_SUBJECT_ACCT_INST" "X_SUBJECT_ADDRESS"
	"X_SUBJECT_ALTERNATE_NM" "X_SUBJECT_EMAIL_ADDRESS" "X_SUBJECT_ID" "X_SUBJECT_INST_ACCT"
	"X_SUBJECT_RELATION_INST" "X_SUBJECT_TELEPHONE_NO" "X_SUBJECT_URL_ADDRESS" "RR"
	;

    

 %macro ecm_ext_std_udf_value(udf_table_nm=); 

 %put %sysfunc(sasmsg(&smdds,GEN_MAC_START_NOTE,NOQUOTE,&sysmacroname)) ;

/* extract and standardize the udf values */ 
    proc sql;
   	 	create table &udf_table_nm as
    	select  a.rr_rk, a.udf_table_nm, a.row_no, a.udf_nm, 
	%if  %scan(%upcase(&udf_table_nm),3,_)=CHAR %then
	%do;
	     udf_value as udf_value_str
	%end;
	%if  %scan(%upcase(&udf_table_nm),3,_)=LGCHR %then
	%do;
	     udf_value as udf_value_str
	%end;	
	%if  %scan(%upcase(&udf_table_nm),3,_)=NUM %then
	%do;
	     strip(put(udf_value,best19.)) as udf_value_str
	%end;
	%if  %scan(%upcase(&udf_table_nm),3,_)=DATE %then
	%do;
	     case 
         	when (index(udf_nm,'_DTTM')) then put(TZONES2U(udf_value),E8601DT20.)
         	else strip(put(datepart(udf_value),yymmddn8.))
         end as udf_value_str
	%end;
    	from   ECM_DB.&udf_table_nm as a  
        	 , ECM_DB.RR_live as b
    	where a.RR_rk=b.RR_rk 
        	  and a.valid_from_dttm=b.valid_from_dttm 
         	  and a.RR_rk &rr_wh;
   		quit;
    %if &sqlrc > 4 %then 
    %do;
          %let successYN=N; 
          %put %sysfunc(sasmsg(&smdds,GEN_STP_ABORT,NOQUOTE,&sysmacroname)) ; 
    %end;
    
    %put %sysfunc(sasmsg(&smdds,GEN_MAC_END_NOTE,NOQUOTE,&sysmacroname)) ;

 %mend;
    
    %let rr_cnt=%ecm_nobs(&rr_subset_dsn);
    %if &rr_cnt < 1  %then  %goto mExit;
    
    proc sql noprint;
         select distinct put(rr_rk,best.) 
                into :rr_rk_list separated by ' ' 
          from &rr_subset_dsn
          ;
    quit;

	/* define filter condition before calling macro ecm_ext_std_udf_value */
    %if &rr_cnt=1 %then %let rr_wh=%str(= &rr_rk_list);
    %else %let rr_wh=%str(in (&rr_rk_list));
  
    /* Extract udf fields by udf data types */
    %ecm_ext_std_udf_value(udf_table_nm=RR_UDF_CHAR_VALUE);
	%if &successYN=N %then %goto mExit;
	%ecm_ext_std_udf_value(udf_table_nm=RR_UDF_LGCHR_VALUE);
	%if &successYN=N %then %goto mExit;
    %ecm_ext_std_udf_value(udf_table_nm=RR_UDF_DATE_VALUE);
	%if &successYN=N %then %goto mExit;
    %ecm_ext_std_udf_value(udf_table_nm=RR_UDF_NUM_VALUE);
	%if &successYN=N %then %goto mExit;

	/* Identify the udfs that are for multiple checkboxes */
	/* only good for udf_table_nm with only one udf_nm */
	%let checkbox_udf_wh="X_FILING_INST_SF_TYPE_CD"  "X_INST_SF_TYPE_CD"
	"X_SAR_CASINO_TYPE_CD" "X_SAR_FRAUD_TYPE_CD" "X_SAR_ID_TYPE_CD" "X_SAR_INSTRUMENT_TYPE_CD"
	"X_SAR_INSURANCE_TYPE_CD" "X_SAR_ML_TYPE_CD" "X_SAR_MORTGAGE_TYPE_CD" "X_SAR_OTHER_TYPE_CD" "X_SAR_PROD_TYPE_CD" "X_SAR_SF_TYPE_CD"
	"X_SAR_STRUCT_TYPE_CD" "X_SAR_TERRORIST_TYPE_CD" "X_SAR_CYBER_TYPE_CD" 
    ;

	/* Identify the udfs which names can be standardized as one name */
	/* Note: X_MIC_COUNTRY_CD is not used.                             */
	%let desc_only_udf_wh="X_COMMODITY_TYPE_TXT" "X_PROD_DESC" "X_CUSIP_NO"  "X_MIC_CD"	 
	;

	
  
    %if &successYN=N %then %goto mExit;
	/* Concatenate all udf rows excluding the boolean flags that are false */
	data rr_udf_all;
	    length udf_value_str $ 32767;
		set rr_udf_char_value  (where=(not (index(udf_nm,'_FLG') and udf_value_str='0')))  
		    rr_udf_num_value  
		    rr_udf_date_value 
            rr_udf_lgchr_value 
 		 ;
        /* convert the code if there is matching format */
		if udf_nm in (&format_list) then
		do; 
		   udf_value_str=putc(udf_value_str,strip(udf_nm));
		end;
		else if udf_nm = 'X_BIRTHDAY_TXT' then
		do;
		   udf_value_str=substr(udf_value_str,5,4)||substr(udf_value_str,1,4);
		end;

		if udf_nm in (&checkbox_udf_wh) then
		    multi_checkbox=1;
		else 
		    multi_checkbox=0;

		if udf_nm in (&desc_only_udf_wh) then
		    desc_only=1;
		else 
		    desc_only=0;
 
	run;

    %if &syserr > 4 %then 
    %do;
          %let successYN=N;
          %put %sysfunc(sasmsg(&smdds,GEN_STP_ABORT,NOQUOTE,&sysmacroname)) ;
          %goto mExit;
    %end;


	/* The following adjustment is needed when the udf tables are nested one level deeper than the subject level */
	/* get x_subject_rk and x_inst_rk in x_subject_relation_inst for subject_relation                            */
	/* X_SUBJECT_RELATION was removed for SARX and the Status codes now exist in X_SUBJECT_RELATION_INST so this */
	/* extra level of depth is no longer needed.                                                                 */
	/* %ecmrr_efile_fincen_nested_key(child_udf_table_nm=X_SUBJECT_RELATION,                                     */
    /*                           parent_udf_table_nm=X_SUBJECT_RELATION_INST,                                    */
    /*                           parent_key_udf_nm=X_SUBJECT_RELATION_INST_RK,                                   */
	/*						   grandparent_key_udf_list='X_SUBJECT_RK' 'X_INST_RK' ,                             */
    /*                           outdsn=subj_relation_more_num_value                                             */
    /*                           );                                                                              */ 	
	/* %if &successYN=N %then %goto mExit;                                                                       */
	/* %if %sysfunc(exist(subj_relation_more_num_value)) %then                                                   */
	/* %do;                                                                                                      */
	/*	proc append base=rr_udf_num_value data=subj_relation_more_num_value force;                               */
	/*	run;                                                                                                     */
	/* %end;                                                                                                     */

 
	proc sql;
	    
	    create table &outdsn as
	    select a.*, b.subject_key, c.inst_key 
	    from rr_udf_all as a
	    left join ( select  rr_rk,
	                        udf_table_nm, 
	                        row_no, 
							udf_value_str as subject_key  
					from rr_udf_num_value 
					where udf_table_nm in ( 
					       "X_SUBJECT" "X_SUBJECT_ACCT_INST" "X_SUBJECT_ADDRESS" 
	                       "X_SUBJECT_ALTERNATE_NM" "X_SUBJECT_EMAIL_ADDRESS" "X_SUBJECT_ID" 
                           "X_SUBJECT_ACCT_INST"  "X_SUBJECT_INST_ACCT" 
	                       "X_SUBJECT_TELEPHONE_NO" "X_SUBJECT_URL_ADDRESS" 
                           "X_SUBJECT_RELATION_INST" ) 
					      and udf_nm='X_SUBJECT_RK'				  
	    			) as b
	    on a.rr_rk= b.rr_rk and a.udf_table_nm=b.udf_table_nm and a.row_no=b.row_no
		left join ( select  rr_rk,
			                        udf_table_nm, 
			                        row_no, 
									udf_value_str as inst_key  
							from rr_udf_num_value 
							where udf_table_nm in ( 
							       "X_INSTITUTION" "X_BRANCH" 
                                   "X_SUBJECT_RELATION_INST"  "X_INST_SF_TYPE"  
                                   "X_SUBJECT_ACCT_INST" "X_SUBJECT_INST_ACCT" ) 
							      and udf_nm in ('X_INST_RK' 'X_ACCT_INST_RK')				  
			    			) as c
			    on a.rr_rk= c.rr_rk and a.udf_table_nm=c.udf_table_nm and a.row_no=c.row_no       
	    order by rr_rk, subject_key, inst_key, udf_table_nm, row_no
	    ;
 
		/* delete any orphan data which does not have a valid subject_key*/
		delete 
		from &outdsn
        where subject_key ne '' and 
		      subject_key not in (select distinct udf_value_str
		                          from rr_udf_num_value 
		                          where udf_table_nm= 'X_SUBJECT'
								        and udf_nm='X_SUBJECT_RK'
								  )		
        ;
		
 
	quit;
	 
	%if &sqlrc > 4 %then 
    %do;
          %let successYN=N;
          %put %sysfunc(sasmsg(&smdds,GEN_STP_ABORT,NOQUOTE,&sysmacroname)) ;
          %goto mExit;
    %end;



%mExit:

%put %sysfunc(sasmsg(&smdds,GEN_MAC_END_NOTE,NOQUOTE,&sysmacroname)) ;

%mend;
 
