
/***********************************************************************************/
/* Copyright (c) 2014, SAS Institute Inc., Cary, NC, USA, All Rights Reserved      */
/*                                                                                 */
/* NAME:          ecmrr_prvw_fincen_webout                                         */
/* PRODUCT:       Enterprise Case Management                                       */
/* PURPOSE:       Create report preview out to stored process _webout.             */
/*                If the output header has the key word '%PDF-', the               */
/*                infile will be displayed. Otherwise, the logfile will be used.   */
/* PARAMETERS:                                                                     */
/*                rr_rk: key of the report to preview (required)                   */
/*                report_nm: report name to use                                    */
/*                infile_fref: file reference of the preview pdf                   */
/*                logfile_fref: file reference of the log ASCII file               */
/* NOTE:                                                                           */
/***********************************************************************************/
%macro ecmrr_prvw_fincen_webout(  rr_rk=
                                , report_nm=
                                ,infile_fref=
                                ,logfile_fref=
                                );

%put %sysfunc(sasmsg(&smdds,GEN_MAC_START_NOTE,NOQUOTE,&sysmacroname)) ;

%let pdf_usable=0;

 %if %sysfunc(fexist(&infile_fref)) %then
 %do;

         
        data _null_;

           length rec5 $ 5; /* to get the first 5 characters of the pdf file */
           length error $ 120;
           filein = fopen("&infile_fref",'I',1,'B');
           if filein=0 then 
           do;
               error=sysmsg();
               put error=;
               stop;
           end;
           rec5='';
           rec='';
           count=1;
           do while(fread(filein)=0 and count < 6);
              rc = fget(filein,rec,1);
              rec5=strip(rec5)||rec;
              count+1;
           end;       
           filein=fclose(filein);
           if rec5='%PDF-' then call symput('PDF_USABLE','1');      
           stop;

         run;

  %end;
  


%if &pdf_usable %then
%do;

    data _null_;
       rc = stpsrv_header('Content-type',"application/pdf"); 

    run;
   
     data _null_;

       filein = fopen("&infile_fref",'I',1,'B');
       fileid = fopen('_webout','O',1,'B');
       
       rec = " ";

       do while(fread(filein)=0);
          rc = fget(filein,rec,1);
          rc = fput(fileid, rec);
          rc =fwrite(fileid);
       end;

       filein=fclose(filein);
       fileid=fclose(fileid);
       
     run;
    
    /* cannot use fcopy() because it corrupts the pdf on Unix*/
	/*
    options msglevel=i;
    %let copyrc=%sysfunc(fcopy(infile,_webout));
    */
	
    %if &syserr > 4 %then
    %do;
 
         ods _all_ close;
         ods pdf file=_webout;
         title "Error Log for %upcase(&report_nm) &rr_rk Preview";
         data _null_;                         
             
             file print;
             
                put '|----------------------------------------------------------|';
                put '|Report cannot be loaded.                                  |';
                put '|Refer to stored process log for more information.         |';
                put '|----------------------------------------------------------|';
                put;
             
         run;
         ods pdf close;
         ods html;
    %end;
     
%end;
%else 
%do;
         ods _all_ close;
         ods pdf file=_webout;
         title "Error Log for %upcase(&report_nm) &rr_rk Preview";
         data _null_;
                         
             infile &logfile_fref;
             input;
             file print;
             if _n_=1 then 
             do;
                put '|----------------------------------------------------------|';
                put '|Output pdf is not generated. Below is the part of the log.|';
                put '|Refer to stored process log for more information.         |';
                put '|----------------------------------------------------------|';
                put;
             end; 
             put _infile_;
         run;
         ods pdf close;
         ods html;
   

%end;
   
%put %sysfunc(sasmsg(&smdds,GEN_MAC_END_NOTE,NOQUOTE,&sysmacroname)) ;
%MEXIT: 

%mend;
