
/***********************************************************************************/
/* Copyright (c) 2018, SAS Institute Inc., Cary, NC, USA, All Rights Reserved      */
/*                                                                                 */
/* NAME:          ecmrr_validate_driver                                            */
/* PRODUCT:       Enterprise Case Management                                       */
/* PURPOSE:       Driver program for validating CTR/SAR Report in xml format       */
/* PARAMETERS:                                                                     */
/*                form_type_cd: type of form to validate                           */
/*                rr_rk: report key                                                */
/* NOTE:                                                                           */
/***********************************************************************************/

%macro ecmrr_validate_driver(rr_rk=
                            ,form_type_cd=);  

%put %sysfunc(sasmsg(&smdds,GEN_MAC_START_NOTE,NOQUOTE,&sysmacroname)) ;

%let successYN=Y;
/* lowercase the form_type_cd to be used in several path and macro names */
%let ltype_code=%lowcase(&form_type_cd);
 
data rr_subset;
     rr_rk=&rr_rk;
run;

%ecmrr_efile_fincen_&ltype_code._data(rr_subset_dsn=rr_subset);

%if %upcase(&successYN)=N %then %goto mEXIT; 

  
	/***********************************************************/
	/* use PROC XSL to transform the xml in udf fields into    */
	/* FinCEN required format xml.                             */
	/***********************************************************/

	%*let efile_subpath=%trim(&ecm_efile_path)&slash.%trim(&output_path_nm);
  %let form_path=&ecm_config_path&slash.Source&slash.form_template;

	filename xslt "&form_path&slash&slash.&ltype_code._efile.xsl";
  
  filename rawxml "%sysfunc(pathname(work))&slash.&ltype_code.Raw.xml";
  filename efilenm "%sysfunc(pathname(work))&slash.&ltype_code.Efile.xml";
  filename outxml "%sysfunc(pathname(work))&slash.&ltype_code.Temp.xml";
	
	proc xsl
	   in=rawxml
	   xsl=xslt
	   out=outxml
	   ;
	run;

    %if &syserr > 4 %then 
    %do;
        %let successYN=N;
        %put %sysfunc(sasmsg(&smdds,GEN_STP_ABORT,NOQUOTE,&sysmacroname)) ;
        %goto mExit;
    %end;
           
   /******************************************/
   /* add unique sequence numbers to the xml */
   /******************************************/

   %let line_cnt=0;

   %ecmrr_efile_xml_seqnum(exclude_dsn=z_rr_efiled, 
                           exclude_var=rr_rk,
                           infname=outxml, 
                           outfname=efilenm,          /* was _webout */ 
                           lineCntVar=line_cnt);

 
   %if &successYN=N %then %goto mExit;

   /* Extract the full filename for the fileref to pass to validation macro */
   proc sql noprint;
       select trim(xpath) into :fullpathnm from sashelp.vextfl
           where fileref='EFILENM';
   quit;
   %let fullpathnm=&fullpathnm.;
   %ecmrr_validate_xml(xml_file=&fullpathnm.
                      ,xsd_file=&ecm_config_path.&slash.Source&slash.form_template&slash.schema&slash.FINCEN&slash.&ltype_code._schema.xsd); 
   data _null_;
       file _webout;
       put "<h3>XML Source</h3>";
       /*put "<textarea rows='20' cols='140' style=border:none;>";*/
       put "<textarea rows='20' cols='140' readonly>";
    run;          
    data _null_;
       filein = fopen('efilenm','I',1,'B');
       fileid = fopen('_webout','O',1,'B');
       rec = " ";
       do while(fread(filein)=0);
          rc = fget(filein,rec,1);
          rc = fput(fileid, rec);
          rc = fwrite(fileid);
          end;
       filein=fclose(filein);
       fileid=fclose(fileid);  
       run; 
    data _null_;
       file _webout;
       put "</textarea>";    
       put "<p>";
    run;      
              
   %if &successYN=N %then %do; 
       %goto mExit;
       %end;

%mEXIT:

%put %sysfunc(sasmsg(&smdds,GEN_MAC_END_NOTE,NOQUOTE,&sysmacroname)) ;

%mend;
