/*******************************************************************************/
/* Load FINCEN SARX configuration data                                         */
/* To test the code without loading the data, use %let ECM_DBUG=Y;             */
/*******************************************************************************/


%macro ecm_loadrr_config_sarx;

/*****************************************************************************************/
/* Define RR and EFILE configuration data                                                */
/*****************************************************************************************/


proc sql;
    create table ref_table_value like ecm_db.ref_table_value; 
    create table efile_config like ecm_db.efile_config;
    create table rr_config like ecm_db.rr_config;
    create table efile_config_x_user_group like ecm_db.efile_config_x_user_group;
    create table rr_config_x_user_group like ecm_db.rr_config_x_user_group;
quit;


proc sql;
        insert into ref_table_value values ('RT_EFILE_TYPE', 'US', 'US', null, null, 0, '1');
        insert into ref_table_value values ('RT_EFILE_CATEGORY', 'FINCEN', 'Financial Crimes Enforcement Network', null, null, 0, '1');
        insert into ref_table_value values ('RT_EFILE_SUBCATEGORY', 'SARX', 
                                             'SARX: Suspicious Activity Report', 'RT_EFILE_CATEGORY', 'FINCEN', 0, '1');
        insert into ref_table_value values ('RT_RR_TYPE', 'US', 'US', null, null, 0, '1');
        insert into ref_table_value values ('RT_RR_CATEGORY', 'FINCEN', 'Financial Crimes Enforcement Network', null, null, 0, '1');
        insert into ref_table_value values ('RT_RR_SUBCATEGORY', 'SARX',
                                            'SARX: Suspicious Activity Report', 'RT_RR_CATEGORY', 'FINCEN', 0, '1');
        insert into ref_table_value values ('RT_FORM_AGENCY', 'FINCEN', 'Financial Crimes Enforcement Network', null, null, 0, '1');
        insert into ref_table_value values ('RT_FORM_TYPE', 'SARX', 'SARX: Suspicious Activity Report', 'RT_FORM_AGENCY', 'FINCEN', 0, '1'); 

        delete from ref_table_value as new 
        where exists (select * from ecm_db.ref_table_value old 
                      where old.ref_table_nm=new.ref_table_nm and
                             old.value_cd=new.value_cd
                      ) ;


        insert into efile_config values (&efile_config_seq_no, 'US', 'FINCEN', 'SARX', 'efile-fincen-new-01.xml'
                                               , 'FINCEN', 'SARX');

        delete from efile_config 
        where efile_config_seq_no in (select distinct efile_config_seq_no from ecm_db.efile_config); 
 

        insert into efile_config_x_user_group values (&efile_config_seq_no, 'CASE_FINANCIAL');

        delete from efile_config_x_user_group as new 
        where exists (select * from ecm_db.efile_config_x_user_group as old 
                      where old.efile_config_seq_no=new.efile_config_seq_no and
                             old.user_group_nm=new.user_group_nm
                      ) ;  

        insert into rr_config values (&rr_config_seq_no, 'US', 'FINCEN', 'SARX', 'rr-fincen-sarx-01.xml'
                                         , 'FINCEN', 'SARX',&efile_config_seq_no, 'FINCENReport');

        delete from rr_config 
        where rr_config_seq_no in (select distinct rr_config_seq_no from ecm_db.rr_config); 
 
 
        insert into rr_config_x_user_group values (&rr_config_seq_no, 'CASE_FINANCIAL');

        delete from rr_config_x_user_group as new 
        where exists (select * from ecm_db.rr_config_x_user_group as old 
                      where old.rr_config_seq_no=new.rr_config_seq_no and
                             old.user_group_nm=new.user_group_nm
                      ) ; 
        
quit;
  
%if &sqlrc <=4 and &ecm_debug=N %then
%do;

   proc append base=ecm_db.ref_table_value data=ref_table_value force;
   run;
   proc append base=ecm_db.efile_config data=efile_config force;
   run;
   proc append base=ecm_db.efile_config_x_user_group data=efile_config_x_user_group force;
   run;
   proc append base=ecm_db.rr_config data=rr_config force;
   run;
   proc append base=ecm_db.rr_config_x_user_group data=rr_config_x_user_group force;
   run;


%end;

%mend;


%macro ecm_loadrr_udf_def_sarx;

/*******************************************************************************/
/*  Load RR UDF fields                                                         */
/*******************************************************************************/

data rr_udf_def_sarx;
if 0 then set ecm_db.rr_udf_def;

   
     infile "&form_path&slash.rr_udf_def_sarx.csv"  
             dsd lrecl=32764 truncover firstobs=2  delimiter=',' ;            
     input udf_table_nm $
           udf_nm $
           udf_type_nm $
           max_char_cnt 
           ref_table_nm $ 
           udf_desc $
                  
    ;
run;
%if &sysrc <= 4 and &ecm_debug=N %then
%do;

    
     
     proc sql noprint;
         create table changed_column_sarx as
         select *
         from rr_udf_def_sarx as sarx 
         where exists
         (select udf_table_nm, udf_nm 
          from ecm_db.rr_udf_def as def 
          where sarx.udf_table_nm=def.udf_table_nm 
                and sarx.udf_nm=def.udf_nm
                and sarx.max_char_cnt ne def.max_char_cnt
          )
          ;

          update ecm_db.rr_udf_def as def
          set max_char_cnt=(select max_char_cnt          
                            from  changed_column_sarx  as chg 
                            where chg.udf_table_nm=def.udf_table_nm 
                            and chg.udf_nm=def.udf_nm
                            )
           where exists (select udf_table_nm, udf_nm 
                         from  changed_column_sarx  as chg 
                         where chg.udf_table_nm=def.udf_table_nm 
                         and chg.udf_nm=def.udf_nm
                         ) 
           ;
            
       
          delete from rr_udf_def_sarx  as sarx
          where exists 
         (select udf_table_nm, udf_nm 
          from ecm_db.rr_udf_def as def 
          where sarx.udf_table_nm=def.udf_table_nm 
                and sarx.udf_nm=def.udf_nm
           )
          ;
    proc append base=ecm_db.rr_udf_def data=rr_udf_def_sarx force;
    run;
%end;

%mend;

%macro ecm_loadrr_ref_sarx;

/******************************************************************************/
/*  Load reference table values                                               */
/******************************************************************************/


/*******************************************************************************************/
/*  Load the sar (old sar) ref table values for sites which never use SAR                  */
/*******************************************************************************************/

data ref_table_value_sar;
 infile  "&form_path&slash.sar-efile_field_config_ref.csv"  
             dsd lrecl=32764 truncover firstobs=2 delimiter=',' ;
   length tmp_word source_ref_list$ 32767;
   if 0 then set ecm_db.form_efile_field_config;
   if 0 then set ecm_db.Ref_table_value;
   input 
           form_efile_record_id $
           target_field_position $
           target_field_nm $
           target_field_length_no
           target_field_desc $
           source_field_nm $
           source_ref_list $                
    ;
    
    keep  ref_table_nm value_cd value_desc parent_ref_table_nm parent_value_cd display_order_no active_flg;
   
    
    tmp_word='';
    tmp_i=1;
    do until (scan(source_ref_list,tmp_i,'|')='');
       tmp_word=left(scan(source_ref_list,tmp_i,'|'));
       ref_table_nm='X_RT_'||substr(source_field_nm,3,length(source_field_nm)-5);
       value_cd=substr(tmp_word,1,1);
       value_desc=left(substr(tmp_word,2));
       display_order_no=tmp_i;
       active_flg='1';
       output;
       tmp_i+1;
    end;
    
 
run;

%if &syserr <= 4 and &ecm_debug=N %then
%do;

   /* only add the reference table values that do not exist in ecm_db */
    proc sql noprint;
         delete from ref_table_value_sar as sar
         where exists 
          (select ref_table_nm 
          from ecm_db.ref_table_value as ref
          where sar.ref_table_nm=ref.ref_table_nm 
           );

     
    proc append base=ecm_db.ref_table_value data=ref_table_value_sar   force;
    run;

%end;

/*******************************************************************************************/
/*  Load SARX ref table values that are not in SAR                                         */
/*******************************************************************************************/

data ref_table_value_sarx;
   infile  "&form_path&slash.sarx-efile_field_config_ref.csv"  
             dsd lrecl=32764 truncover firstobs=2 delimiter=',' ;
   length tmp_word source_ref_list$ 32767;
   if 0 then set ecm_db.form_efile_field_config;
   if 0 then set ecm_db.Ref_table_value;
   input          
           ref_table_nm $
           source_ref_list $                
    ;
    
    keep  ref_table_nm value_cd value_desc parent_ref_table_nm parent_value_cd display_order_no active_flg;
   
    
    tmp_word='';
    tmp_i=1;
    do until (scan(source_ref_list,tmp_i,'|')='');
       tmp_word=left(scan(source_ref_list,tmp_i,'|'));
       value_cd=substr(tmp_word,1,index(tmp_word,' ')-1);
       value_desc=left(substr(tmp_word,index(tmp_word,' ')+1));
       display_order_no=tmp_i;
       active_flg='1';
       output;
       tmp_i+1;
    end;
    
 
run;

%if &syserr <= 4 and &ecm_debug=N %then
%do;

     
    /* delete all existing sarx reference table values before inserting the new ones */
    proc sql noprint;
         delete from ecm_db.ref_table_value as ref
         where exists 
          (select ref_table_nm 
          from ref_table_value_sarx as sarx
          where sarx.ref_table_nm=ref.ref_table_nm 
           );

     
    proc append base=ecm_db.ref_table_value data=ref_table_value_sarx   force;
    run;
%end;


%mend;


%macro ecm_loadrr_form_config_sarx;

/*****************************************************************************************/
/* Add SARX to ECM_DB.FORM_CONFIG                                                        */
/*****************************************************************************************/


%let sarx_form_exist=N;
proc sql noprint;
     select 'Y' into :sarx_form_exist  
     from ecm_db.form_config 
     where form_config_rk=&form_config_rk;
quit;

%if &sarx_form_exist=N and &ecm_debug = N %then
%do;
proc sql;
   insert into ecm_db.form_config values (&form_config_rk,
                                          'FINCEN',
                                          'SARX'
                                          'US',
                                          '01JAN2018:00:00:00'dt,null,
                                          'SARX',
                                          'application/pdf','sarx',
                                          'ecmrr_prvw_fincen_sarx_driver',
                                          'ecmrr_prvw_fincen_sarx_data',
                                          'fincen-sarx-v1',
                                          'ecmrr_efile_fincen_sarx_driver',
                                          'ecmrr_efile_fincen_sarx_data',
                                          200,
                                          null,null,null,null,'0');
%end;

%mend;



%macro ecm_loadrr_code_mapping_sarx;

/****************************************************************/
/* Load FINCEN SARX code mapping                                */
/****************************************************************/
%let form_path=&ecm_config_path&slash.Source&slash.form_template;
libname ecm_form "&form_path"; 


data ecm_form.sarx_code_mapping;

     attrib FORMAT_NM   length=$32 label='Format Name'
            FORMAT_TYPE length=$1  label='Format Type'
            INPUT_CD  length=$2 label='Input Code'
            OUTPUT_CD length=$40 label='Output Code'   
            CODE_DESC length=$100 label='Code Description'       
     ;
        
     retain format_type 'C';
     infile "&form_path&slash.sarx_code_mapping.csv"  
             dsd lrecl=32764 truncover firstobs=2  delimiter=',' ;            
     input format_nm $
           input_cd $
           output_cd $
           code_desc $
           
                     
    ;

run;

 

%mend;



%macro ecm_loadrr_ref_us_terr_state_cd;

/*******************************************************************************/
/*  Load US territories state codes                                            */
/*******************************************************************************/


    data ref_table_value_state;

         if 0 then set ecm_db.Ref_table_value; 
         infile  "&form_path&slash.state_code_list_us_territories.csv"  
                 dsd lrecl=32764 truncover delimiter=',' ;
         
         retain ref_table_nm 'X_RT_STATE_PROVINCE'
                parent_ref_table_nm 'X_RT_COUNTRY'
         ;
         retain value_cd value_desc display_order_no; 
         keep  ref_table_nm value_cd value_desc parent_ref_table_nm parent_value_cd display_order_no active_flg;
       
         input parent_value_cd $
               value_cd $ 
               value_desc $
         ;
         active_flg='1';
         if lag(parent_value_cd) ne parent_value_cd then display_order_no=1;
         else display_order_no+1;
             
    run;

    data ref_table_value_country;

         set ref_table_value_state; 
         ref_table_nm = 'X_RT_COUNTRY';     
         parent_ref_table_nm = '';
         parent_value_cd = '';

    run;   
    /* add country list with only USA and US territories */
    data ref_table_value_country_us;

         set ecm_db.ref_table_value (where=(ref_table_nm='X_RT_COUNTRY' and value_cd='US'))
             ref_table_value_state
         ; 
         ref_table_nm = 'X_RT_COUNTRY_US';      
         parent_ref_table_nm = '';
         parent_value_cd = '';
         display_order_no=_n_;
    run;     

 


%if &sysrc <= 4 %then
%do;
    proc sql noprint;
        delete from ref_table_value_country  as new
        where exists 
         (select ref_table_nm, value_cd 
          from ecm_db.ref_table_value as old 
          where new.ref_table_nm=old.ref_table_nm
                and new.value_cd=old.value_cd                
         )
         ;  
    quit;
    
    
    proc append base=ecm_db.ref_table_value data=ref_table_value_country force;
    run;
    
    proc sql;
          delete from ecm_db.ref_table_value
          where ref_table_nm='X_RT_COUNTRY_US';
    quit;
    
    proc sql noprint;
         delete from ref_table_value_country_us  as new
         where exists 
         (select ref_table_nm, value_cd 
          from ecm_db.ref_table_value as old 
          where new.ref_table_nm=old.ref_table_nm
                and new.value_cd=old.value_cd                
         )
        ;  
    quit;

    proc append base=ecm_db.ref_table_value data=ref_table_value_country_us force;
    run;

    proc sql noprint;
          delete from ref_table_value_state  as new
          where exists 
         (select ref_table_nm, value_cd 
          from ecm_db.ref_table_value as old 
          where new.ref_table_nm=old.ref_table_nm
                and new.value_cd=old.value_cd                
           )
          ;  
    quit;

    proc append base=ecm_db.ref_table_value data=ref_table_value_state force;
    run;
%end;

%mend;



%macro ecm_loadrr_error_code_sarx;

/****************************************************************/
/* Load FINCEN SARX error codes                                 */
/****************************************************************/
    %let form_path=&ecm_config_path&slash.Source&slash.form_template;
    libname ecm_form "&form_path"; 
    data ecm_form.sarx_fincen_error_code;

        attrib ERROR_CD  length=$10 label='Error Type Code'
            ERROR_DESC length=$4000 label='Error Text' 
            ERROR_RECORD_TYPE length=$2 label='Error record type (not used)'  
            ERROR_TYPE_CD length=$1 label='Error Severity Code' 
            ERROR_TYPE_TEXT length=$32 label='Error Severity Description'
            ASSOC_ELEMENT length=$256 label='Associated Element(s)'
            FIELD_REFERENCE length=$4000 label='Field Reference'
        ;
        
        infile "&form_path&slash.sarx_fincen_error_code.csv"  
               dsd lrecl=32764 truncover firstobs=2  delimiter=',' ;            
        input error_cd $
              error_desc $          
              error_type_text $
              assoc_element $
              field_reference $
        ;
        if substrn(error_cd,length(error_cd),1)='*' then 
        do;
           /* if the error_cd contains '*', it is a primary warning */
           error_cd=compress(error_cd,'*');
           error_type_cd='P';
        end;
        else 
        do;
            select (error_type_text);
                when ('Fatal') error_type_cd='F';  
                when ('Warning') error_type_cd='S';
                otherwise;
            end;
        end;
        error_desc=compress(error_desc,,'kw');
        assoc_element=compress(assoc_element,,'kw');
        field_reference=compress(field_reference,,'kw');
       
    run;
    
%mend;


%macro ecm_loadrr_prvw_sarx;

    /* Section level configuration data */
    data sarx_preview_section_config;
    if 0 then set ecm_db.form_preview_section_config;

       
         infile "&form_path&slash.sarx-preview_section_config.csv" 
                 dsd lrecl=32764 truncover firstobs=2  delimiter=',' ;
         input form_config_rk
               form_preview_section_seq_no
               form_preview_section_id $
               section_desc $
               section_order_no 
               section_file_suffix $
               source_table_nm $
        ;
        form_config_rk=&form_config_rk;
    run;

 
    /* Field level configuration data */

    data sarx_preview_field_config;

         if 0 then set ecm_db.form_preview_field_config;

       
         infile  "&form_path&slash.sarx-preview_field_config.csv"  
                 dsd lrecl=32764 truncover firstobs=2 delimiter=',' ;
         
         input form_config_rk 
               form_preview_section_seq_no
               form_preview_field_seq_no :best. /* make sure decimal numbers are read correctly */
               source_field_nm $
               source_field_num_flg $
               source_field_exp $
               target_field_nm $
               target_field_type_cd $
               target_field_type_parm_list $
         ; 
         form_config_rk=&form_config_rk;    
        
    run;

    %if &syserr <= 4 and &ecm_debug=N %then
    %do;
       proc sql;
         delete 
        from ecm_db.form_preview_field_config
         where form_config_rk=&form_config_rk;

         delete 
         from ecm_db.form_preview_section_config
         where form_config_rk=&form_config_rk;
       quit;

    proc append base=ecm_db.form_preview_section_config data=sarx_preview_section_config; 
    run;
    proc append base=ecm_db.form_preview_field_config data=sarx_preview_field_config; 
    run;
    %end;

%mend;

%macro ecm_upgrade_resp_table;

    %let upgraded=N;
    proc sql noprint;
       select "Y" into :upgraded
       from  dictionary.columns
       where  libname eq "ECM_RPT"
              and  memname eq "ECMRR_RESP_FINCEN_ERROR_LIST"
              and  name="ERROR_CONTEXT";
    
    %if &upgraded=N %then
    %do;
      
       /* Upgrade table structure of ECM_RPT.ECMRR_RESP_FINCEN_ERROR_LIST */

       alter table ecm_rpt.ecmrr_resp_fincen_error_list
       add ERROR_CONTEXT char(256) label='Error Content'     
       ; 
    quit; 
    %end;

    %let upgraded=N;
    proc sql noprint;
       select "Y" into :upgraded
       from  dictionary.Columns
       where  libname eq "ECM_RPT"
              and  memname eq "ECMRR_RESP_FINCEN_SUMMARY"
              and  name="SUBMISSION_STATUS_CD";
    
    %if &upgraded=N %then
    %do;
      
       /* Upgrade table structure of ECM_RPT.ECMRR_RESP_FINCEN_ERROR_LIST */

       alter table ecm_rpt.ecmrr_resp_fincen_summary
       add SUBMISSION_STATUS_CD char(256) label='submission status code'     
       ; 
     
    %end;
    quit;
%mend;

/* Change ecm_debug to Y for testing */
%let ecm_debug=N;
/* Adjust the sequence number if it has been used */
%let rr_config_seq_no=211;
%let efile_config_seq_no=211;
%let form_config_rk=211;
%let form_path=&ecm_config_path&slash.Source&slash.form_template;


%ecm_loadrr_config_sarx;    /* load rr and efile config data */
%ecm_loadrr_ref_sarx;       /* load reference values         */
%ecm_loadrr_udf_def_sarx;   /* load rr UDF fields            */

%ecm_loadrr_form_config_sarx;   /* load FORM config data     */
%ecm_loadrr_code_mapping_sarx;
%ecm_loadrr_ref_us_terr_state_cd; 
%ecmrr_efile_makedir(form_config_rk=&form_config_rk);


%ecm_loadrr_prvw_sarx;
%ecmrr_fdf_pgm_gen(form_config_rk=&form_config_rk);
%ecm_loadrr_error_code_sarx;

%ecm_upgrade_resp_table;
