<?xml version="1.0"?>
<!-- ctrx_efile.xsl -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fc2="www.fincen.gov/base">
    <xsl:output method="xml" indent="yes"/>
    <xsl:template match="/collection/items">
        <fc2:EFilingBatchXML TotalAmount="{global/TotalAmount}"
                             PartyCount="{global/PartyCount}" ActivityCount="{global/ActivityCount}"
                             xsi:schemaLocation="www.fincen.gov/base EFL_CTRXBatchSchema.xsd"
                             xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
                             xmlns:fc2="www.fincen.gov/base">

            <fc2:FormTypeCode>CTRX</fc2:FormTypeCode>
            <xsl:apply-templates select="report"/>
        </fc2:EFilingBatchXML>
    </xsl:template>


    <xsl:template match="report">
        <xsl:variable name="RR_TRANSACTION_DT" select="X_TRANSACTION_DT"/>
        <xsl:variable name="RR_FILING_TYPE_CD" select="X_CTR_FILING_TYPE_CD"/>

        <fc2:Activity SeqNum="{RR_RK}">
		
		    <xsl:apply-templates select="X_PRIOR_AGENCY_REF_ID"/>
			
            <fc2:FilingDateText>
                <xsl:value-of select="/collection/items/global/FilingDate"/>
            </fc2:FilingDateText>

            <fc2:ActivityAssociation SeqNum=".">
                <fc2:CorrectsAmendsPriorReportIndicator>
                    <xsl:value-of select="X_CTR_FILING_TYPE_CD_B"/>
                </fc2:CorrectsAmendsPriorReportIndicator>
                <fc2:FinCENDirectBackFileIndicator>
                    <xsl:value-of select="X_CTR_FILING_TYPE_CD_C"/>
                </fc2:FinCENDirectBackFileIndicator>
                <fc2:InitialReportIndicator>
                    <xsl:value-of select="X_CTR_FILING_TYPE_CD_A"/>
                </fc2:InitialReportIndicator>

            </fc2:ActivityAssociation>

            <!--
                Transmitter party(35)  and transmitter contact party(37)
            -->
            <fc2:Party SeqNum=".">

                <fc2:ActivityPartyTypeCode>35</fc2:ActivityPartyTypeCode>
                <!--  efiling coverage period -->
                <fc2:EFilingCoverageBeginningDateText>
                    <xsl:value-of select="$RR_TRANSACTION_DT"/>
                </fc2:EFilingCoverageBeginningDateText>
                <fc2:EFilingCoverageEndDateText>
                    <xsl:value-of select="$RR_TRANSACTION_DT"/>
                </fc2:EFilingCoverageEndDateText>

                <fc2:PartyName SeqNum=".">
                    <fc2:PartyNameTypeCode>L</fc2:PartyNameTypeCode>
                    <xsl:apply-templates select="/collection/items/transmitter/X_FINCEN_TRNSMTTR_NM"/>
                </fc2:PartyName>

                <fc2:Address SeqNum=".">
                    <xsl:apply-templates select="/collection/items/transmitter/X_FINCEN_TRNSMTTR_CITY_NM"/>
                    <xsl:apply-templates select="/collection/items/transmitter/X_FINCEN_TRNSMTTR_COUNTRY_CD"/>
                    <xsl:apply-templates select="/collection/items/transmitter/X_FINCEN_TRNSMTTR_STATE_CD"/>
                    <xsl:apply-templates select="/collection/items/transmitter/X_FINCEN_TRNSMTTR_ADDRESS_TXT"/>
                    <xsl:apply-templates select="/collection/items/transmitter/X_FINCEN_TRNSMTTR_ZIP_CD"/>
                </fc2:Address>

                <xsl:if test="/collection/items/transmitter/X_FINCEN_TRNSMTTR_PHONE_NO">
                    <fc2:PhoneNumber SeqNum=".">
                        <xsl:apply-templates select="/collection/items/transmitter/X_FINCEN_TRNSMTTR_PHONE_NO"/>
                    </fc2:PhoneNumber>
                </xsl:if>

                <fc2:PartyIdentification SeqNum=".">
                    <xsl:apply-templates select="/collection/items/transmitter/X_FINCEN_TRNSMTTR_TIN_NO"/>
                    <fc2:PartyIdentificationTypeCode>4</fc2:PartyIdentificationTypeCode>
                </fc2:PartyIdentification>

                <fc2:PartyIdentification SeqNum=".">
                    <xsl:apply-templates select="/collection/items/transmitter/X_FINCEN_TRNSMTTR_TCC"/>
                    <fc2:PartyIdentificationTypeCode>28</fc2:PartyIdentificationTypeCode>
                </fc2:PartyIdentification>
            </fc2:Party>
            <fc2:Party SeqNum=".">
                <fc2:ActivityPartyTypeCode>37</fc2:ActivityPartyTypeCode>
                <fc2:EFilingCoverageBeginningDateText>
                    <xsl:value-of select="$RR_TRANSACTION_DT"/>
                </fc2:EFilingCoverageBeginningDateText>
                <fc2:EFilingCoverageEndDateText>
                    <xsl:value-of select="$RR_TRANSACTION_DT"/>
                </fc2:EFilingCoverageEndDateText>

                <fc2:PartyName SeqNum=".">
                    <fc2:PartyNameTypeCode>L</fc2:PartyNameTypeCode>
                    <xsl:apply-templates select="/collection/items/transmitter/X_FINCEN_TRNSMTTR_CONTACT_NM"/>
                </fc2:PartyName>
            </fc2:Party>

            <!--
                Reporting financial institution party(30)  and contact for assistant party(8)
            -->

            <fc2:Party SeqNum=".">
                <fc2:ActivityPartyTypeCode>30</fc2:ActivityPartyTypeCode>

                <xsl:apply-templates select="X_FILING_INST_PRIM_FED_REG_CD"/>

                <fc2:PartyName SeqNum=".">
                    <fc2:PartyNameTypeCode>L</fc2:PartyNameTypeCode>
                    <xsl:apply-templates select="X_FILING_INST_NM"/>
                </fc2:PartyName>

                <xsl:if test="X_FILING_INST_ALTERNATE_NM">
                    <fc2:PartyName SeqNum=".">
                        <fc2:PartyNameTypeCode>DBA</fc2:PartyNameTypeCode>
                        <xsl:apply-templates select="X_FILING_INST_ALTERNATE_NM"/>
                    </fc2:PartyName>
                </xsl:if>

                <fc2:Address SeqNum=".">
                    <xsl:apply-templates select="X_FILING_INST_CITY_NM"/>
                    <xsl:apply-templates select="X_FILING_INST_COUNTRY_CD"/>
                    <xsl:apply-templates select="X_FILING_INST_STATE_CD"/>
                    <xsl:apply-templates select="X_FILING_INST_ADDRESS_TXT"/>
                    <xsl:apply-templates select="X_FILING_INST_POSTAL_CD"/>
                </fc2:Address>
                <fc2:PartyIdentification SeqNum=".">
                    <xsl:apply-templates select="X_FILING_INST_TIN_NO"/>
                    <fc2:PartyIdentificationTypeCode>2</fc2:PartyIdentificationTypeCode>
                </fc2:PartyIdentification>


                <fc2:PartyIdentification SeqNum=".">
                    <xsl:apply-templates select="X_FILING_INST_ID_NO"/>
                    <xsl:apply-templates select="X_FILING_INST_ID_TYPE_CD"/>
                </fc2:PartyIdentification>

                <fc2:OrganizationClassificationTypeSubtype SeqNum=".">
                    <xsl:apply-templates select="X_FILING_INST_GAMING_TYPE_CD"/>
                    <xsl:apply-templates select="X_FILING_INST_TYPE_CTR_CD"/>
                    <xsl:apply-templates select="X_FILING_INST_GAMING_TYPE_OTH"/>
                    <xsl:apply-templates select="X_FILING_INST_TYPE_OTH_TXT"/>
                </fc2:OrganizationClassificationTypeSubtype>

            </fc2:Party>
            <fc2:Party SeqNum=".">
                <fc2:ActivityPartyTypeCode>8</fc2:ActivityPartyTypeCode>
                <fc2:PartyName SeqNum=".">
                    <fc2:PartyNameTypeCode>L</fc2:PartyNameTypeCode>
                    <xsl:apply-templates select="X_CTR_CONTACT_OFFICE"/>
                </fc2:PartyName>
                <fc2:PhoneNumber SeqNum=".">
				    <xsl:apply-templates select="X_CTR_CONTACT_PHONE_EXT_NO"/>
                    <xsl:apply-templates select="X_CTR_CONTACT_PHONE_NO"/>
                </fc2:PhoneNumber>
            </fc2:Party>

            <!--
                Transaction location party(34)
            -->

            <xsl:apply-templates select="X_INSTITUTION"/>

            <!--
                Party  party(50,17,23,58)
            -->

            <xsl:apply-templates select="subject"/>

            <!--
                Curreny transaction
            -->

            <fc2:CurrencyTransactionActivity SeqNum=".">
			
				<fc2:AggregateTransactionIndicator>
                    <xsl:value-of select="X_TRAN_METHOD/X_TRAN_METHOD_TYPE_CD_E"/>
                </fc2:AggregateTransactionIndicator>			
              
                <fc2:ArmoredCarServiceIndicator>
                    <xsl:value-of select="X_TRAN_METHOD/X_TRAN_METHOD_TYPE_CD_A"/>
                </fc2:ArmoredCarServiceIndicator>

                <fc2:ATMIndicator>
                    <xsl:value-of select="X_TRAN_METHOD/X_TRAN_METHOD_TYPE_CD_B"/>
                </fc2:ATMIndicator>

                <fc2:MailDepositShipmentIndicator>
                    <xsl:value-of select="X_TRAN_METHOD/X_TRAN_METHOD_TYPE_CD_C"/>
                </fc2:MailDepositShipmentIndicator>

                <fc2:NightDepositIndicator>
                    <xsl:value-of select="X_TRAN_METHOD/X_TRAN_METHOD_TYPE_CD_D"/>
                </fc2:NightDepositIndicator>

				
                <fc2:SharedBranchingIndicator>
                    <xsl:value-of select="X_TRAN_METHOD/X_TRAN_METHOD_TYPE_CD_F"/>
                </fc2:SharedBranchingIndicator>


				
				<!-- 
				
                <xsl:apply-templates select="X_US_CASH_IN_AMT"/>
                <xsl:apply-templates select="X_US_CASH_OUT_AMT"/>
				-->
				<fc2:TotalCashInReceiveAmountText>
					<xsl:value-of select="X_US_CASH_IN_AMT"/>
				</fc2:TotalCashInReceiveAmountText>
				<fc2:TotalCashOutAmountText>
                     <xsl:value-of select="X_US_CASH_OUT_AMT"/>
                </fc2:TotalCashOutAmountText>
                <xsl:apply-templates select="X_TRANSACTION_DT"/>
                <xsl:apply-templates select="X_US_CASH_IN_A_AMT"/>
                <xsl:apply-templates select="X_US_CASH_IN_B_AMT"/>
                <xsl:apply-templates select="X_US_CASH_IN_C_AMT"/>
                <xsl:apply-templates select="X_US_CASH_IN_D_AMT"/>
                <xsl:apply-templates select="X_US_CASH_IN_E_AMT"/>
                <xsl:apply-templates select="X_US_CASH_IN_F_AMT"/>
                <xsl:apply-templates select="X_US_CASH_IN_G_AMT"/>
                <xsl:apply-templates select="X_US_CASH_IN_H_AMT"/>
                <xsl:apply-templates select="X_US_CASH_IN_I_AMT"/>
                <xsl:if test="X_US_CASH_IN_Z_AMT">
                    <fc2:CurrencyTransactionActivityDetail SeqNum=".">
                        <fc2:CurrencyTransactionActivityDetailTypeCode>997</fc2:CurrencyTransactionActivityDetailTypeCode>
                        <xsl:apply-templates select="X_US_CASH_IN_Z_AMT"/>
                        <xsl:apply-templates select="X_US_CASH_IN_OTH_TXT"/>
                        <fc2:OtherForeignCurrencyCountryText/>
                    </fc2:CurrencyTransactionActivityDetail>
                </xsl:if>

                <xsl:apply-templates select="X_US_CASH_OUT_A_AMT"/>
                <xsl:apply-templates select="X_US_CASH_OUT_B_AMT"/>
                <xsl:apply-templates select="X_US_CASH_OUT_C_AMT"/>
                <xsl:apply-templates select="X_US_CASH_OUT_D_AMT"/>
                <xsl:apply-templates select="X_US_CASH_OUT_E_AMT"/>
                <xsl:apply-templates select="X_US_CASH_OUT_F_AMT"/>
                <xsl:apply-templates select="X_US_CASH_OUT_G_AMT"/>
                <xsl:apply-templates select="X_US_CASH_OUT_H_AMT"/>
                <xsl:apply-templates select="X_US_CASH_OUT_I_AMT"/>
				<xsl:apply-templates select="X_US_CASH_OUT_J_AMT"/>



                <xsl:if test="X_US_CASH_OUT_Z_AMT">
                    <fc2:CurrencyTransactionActivityDetail SeqNum=".">
                        <fc2:CurrencyTransactionActivityDetailTypeCode>998</fc2:CurrencyTransactionActivityDetailTypeCode>
                        <xsl:apply-templates select="X_US_CASH_OUT_Z_AMT"/>
                        <xsl:apply-templates select="X_US_CASH_OUT_OTH_TXT"/>
                        <fc2:OtherForeignCurrencyCountryText/>
                    </fc2:CurrencyTransactionActivityDetail>
                </xsl:if>


                <xsl:apply-templates select="X_FOREIGN_CASH_IN"/>
                <xsl:apply-templates select="X_FOREIGN_CASH_OUT"/>


            </fc2:CurrencyTransactionActivity>


        </fc2:Activity>
    </xsl:template>


    <!-- transaction location party 34 -->
    <xsl:template match="X_INSTITUTION">
        <fc2:Party SeqNum=".">
            <fc2:ActivityPartyTypeCode>34</fc2:ActivityPartyTypeCode>


            <xsl:apply-templates select="X_CASH_IN_AMT"/>
            <xsl:apply-templates select="X_CASH_OUT_AMT"/>
            <xsl:apply-templates select="X_INST_PRIM_FED_REG_CD"/>


            <fc2:PartyName SeqNum=".">
                <fc2:PartyNameTypeCode>L</fc2:PartyNameTypeCode>
                <xsl:apply-templates select="X_INST_LEGAL_NM"/>
            </fc2:PartyName>

            <xsl:if test="X_INST_ALT_NM">
                <fc2:PartyName SeqNum=".">
                    <fc2:PartyNameTypeCode>DBA</fc2:PartyNameTypeCode>
                    <xsl:apply-templates select="X_INST_ALT_NM"/>
                </fc2:PartyName>
            </xsl:if>

            <fc2:Address SeqNum=".">
                <xsl:apply-templates select="X_INST_CITY_NM"/>
                <xsl:apply-templates select="X_INST_COUNTRY_CD"/>
                <xsl:apply-templates select="X_INST_STATE_CD"/>
                <xsl:apply-templates select="X_INST_ADDRESS_TXT"/>
                <xsl:apply-templates select="X_INST_POSTAL_CD"/>
            </fc2:Address>

            <fc2:PartyIdentification SeqNum=".">
                <xsl:apply-templates select="X_INST_TIN_NO"/>
                
				<xsl:apply-templates select="X_INST_TIN_UNKNOWN_FLG"/>
            </fc2:PartyIdentification>

            <xsl:if test="X_INST_ID_TYPE_CD">
                <fc2:PartyIdentification SeqNum=".">
                    <xsl:apply-templates select="X_INST_ID"/>
                    <xsl:apply-templates select="X_INST_ID_TYPE_CD"/>
                </fc2:PartyIdentification>
            </xsl:if>

            <fc2:OrganizationClassificationTypeSubtype SeqNum=".">
                <xsl:apply-templates select="X_INST_GAMING_TYPE_CD"/>
                <xsl:apply-templates select="X_INST_TYPE_CTR_CD"/>
                <xsl:apply-templates select="X_INST_GAMING_TYPE_OTH_TXT"/>
                <xsl:apply-templates select="X_INST_TYPE_OTH_TXT"/>
            </fc2:OrganizationClassificationTypeSubtype>


        </fc2:Party>

    </xsl:template>


    <xsl:template match="subject">
        <fc2:Party SeqNum=".">
            <xsl:variable name="PTY_GENDER_CD" select="X_GENDER_CD"/>
            <xsl:variable name="PTY_PERSONAL_ID_TYPE_CD" select="X_PERSONAL_ID_TYPE_CD"/>
            <xsl:apply-templates select="X_PERSON_INVOLVED_TYPE_CD"/> 
			<xsl:apply-templates select="X_BIRTH_DT_UNKNOWN_FLG"/>			
            <xsl:if test="$PTY_GENDER_CD='B'">
                <fc2:FemaleGenderIndicator>Y</fc2:FemaleGenderIndicator>
            </xsl:if>
            <xsl:apply-templates select="X_BIRTHDAY_TXT"/>
            <xsl:apply-templates select="X_CASH_IN_AMT"/>
            <xsl:apply-templates select="X_CASH_OUT_AMT"/>
            <xsl:if test="$PTY_GENDER_CD='A'">
                <fc2:MaleGenderIndicator>Y</fc2:MaleGenderIndicator>
            </xsl:if>

            <xsl:apply-templates select="X_MULTI_TRANSACTION_FLG"/>
            <xsl:apply-templates select="X_ENTITY_FLG"/>
            <xsl:if test="$PTY_GENDER_CD='C'">
                <fc2:UnknownGenderIndicator>Y</fc2:UnknownGenderIndicator>
            </xsl:if>

           

            <fc2:PartyName SeqNum=".">
                <xsl:apply-templates select="X_LAST_NM_UNKNOWN_FLG"/>
                <xsl:apply-templates select="X_FIRST_NM_UNKNOWN_FLG"/>
                <fc2:PartyNameTypeCode>L</fc2:PartyNameTypeCode>
                <xsl:apply-templates select="X_LAST_NM"/>
                <xsl:apply-templates select="X_FIRST_NM"/>
                <xsl:apply-templates select="X_MIDDLE_NM"/>
                <xsl:apply-templates select="X_SUFFIX_NM"/>
            </fc2:PartyName>
            <xsl:if test="X_ALTERNATE_NM">
                <fc2:PartyName SeqNum=".">
                    <fc2:PartyNameTypeCode>AKA</fc2:PartyNameTypeCode>
                    <xsl:apply-templates select="X_ALTERNATE_NM"/>
                </fc2:PartyName>
            </xsl:if>

            <fc2:Address SeqNum=".">
                <xsl:apply-templates select="X_CITY_UNKNOWN_FLG"/>
                <xsl:apply-templates select="X_COUNTRY_UNKNOWN_FLG"/>
                <xsl:apply-templates select="X_CITY_NM"/>
                <xsl:apply-templates select="X_COUNTRY_CD"/>
                <xsl:apply-templates select="X_STATE_CD"/>
                <xsl:apply-templates select="X_ADDRESS_TXT"/>
                <xsl:apply-templates select="X_POSTAL_CD"/>
				<xsl:apply-templates select="X_STATE_UNKNOWN_FLG"/>
                <xsl:apply-templates select="X_ADDRESS_UNKNOWN_FLG"/>
                <xsl:apply-templates select="X_POSTAL_UNKNOWN_FLG"/>
            </fc2:Address>

            <fc2:PhoneNumber SeqNum=".">
                <xsl:apply-templates select="X_PHONE_EXT_NO"/>
                <xsl:apply-templates select="X_PHONE_NO"/>

            </fc2:PhoneNumber>

            <fc2:PartyIdentification SeqNum=".">
                <xsl:apply-templates select="X_TIN_NO"/>
                <xsl:apply-templates select="X_TIN_TYPE_CD"/>
                <xsl:apply-templates select="X_TIN_UKNOWN_FLG"/>
            </fc2:PartyIdentification>

            <fc2:PartyIdentification SeqNum=".">

                <xsl:if test="$PTY_PERSONAL_ID_TYPE_CD='A'">
                    <fc2:IdentificationPresentUnknownIndicator>Y</fc2:IdentificationPresentUnknownIndicator>
                </xsl:if>

                <xsl:apply-templates select="X_ID_AUTHORITY_COUNTRY_CD"/>
                <xsl:apply-templates select="X_ID_AUTHORITY_STATE_CD"/>
                <xsl:apply-templates select="X_PERSONAL_ID_TYPE_OTH_TXT"/>
                <xsl:apply-templates select="X_ID_NO"/>

                <xsl:if test="$PTY_PERSONAL_ID_TYPE_CD!='A'">
                    <fc2:PartyIdentificationTypeCode>
                        <xsl:value-of select="$PTY_PERSONAL_ID_TYPE_CD"/>
                    </fc2:PartyIdentificationTypeCode>
                </xsl:if>


            </fc2:PartyIdentification>

            <fc2:PartyOccupationBusiness SeqNum=".">
                <fc2:NAICSCode>
                    <xsl:value-of select="X_NAICS_CD"/>
                </fc2:NAICSCode>
                <fc2:OccupationBusinessText>
                    <xsl:value-of select="X_OCCUPATION_TXT"/>
                </fc2:OccupationBusinessText>


            </fc2:PartyOccupationBusiness>

            <fc2:ElectronicAddress SeqNum=".">
                <xsl:apply-templates select="X_EMAIL_ADDRESS_TXT"/>
            </fc2:ElectronicAddress>

            <xsl:apply-templates select="X_ACCOUNT_CASH_IN"/>
            <xsl:apply-templates select="X_ACCOUNT_CASH_OUT"/>

        </fc2:Party>

    </xsl:template>

    <xsl:template match="X_FOREIGN_CASH_IN">

        <fc2:CurrencyTransactionActivityDetail SeqNum=".">
            <fc2:CurrencyTransactionActivityDetailTypeCode>53</fc2:CurrencyTransactionActivityDetailTypeCode>
            <xsl:apply-templates select="X_FOREIGN_CASH_IN_AMT"/>
            <fc2:OtherCurrencyTransactionActivityDetailText/>
            <xsl:apply-templates select="X_FOREIGN_CASH_IN_COUNTRY_CD"/>
        </fc2:CurrencyTransactionActivityDetail>

    </xsl:template>


    <xsl:template match="X_FOREIGN_CASH_OUT">
        <fc2:CurrencyTransactionActivityDetail SeqNum=".">
            <fc2:CurrencyTransactionActivityDetailTypeCode>54</fc2:CurrencyTransactionActivityDetailTypeCode>
            <xsl:apply-templates select="X_FOREIGN_CASH_OUT_AMT"/>
            <fc2:OtherCurrencyTransactionActivityDetailText/>
            <xsl:apply-templates select="X_FOREIGN_CASH_OUT_COUNTRY_CD"/>
        </fc2:CurrencyTransactionActivityDetail>

    </xsl:template>

    <xsl:template match="X_ACCOUNT_CASH_IN">
        <fc2:Account SeqNum=".">
            <xsl:apply-templates select="X_CASH_IN_ACCT_ID"/>
            <fc2:PartyAccountAssociation SeqNum=".">
                <fc2:PartyAccountAssociationTypeCode>8</fc2:PartyAccountAssociationTypeCode>
            </fc2:PartyAccountAssociation>
        </fc2:Account>
    </xsl:template>


    <xsl:template match="X_ACCOUNT_CASH_OUT">
        <fc2:Account SeqNum=".">
            <xsl:apply-templates select="X_CASH_OUT_ACCT_ID"/>
            <fc2:PartyAccountAssociation SeqNum=".">
                <fc2:PartyAccountAssociationTypeCode>9</fc2:PartyAccountAssociationTypeCode>
            </fc2:PartyAccountAssociation>
        </fc2:Account>
    </xsl:template>


    <!--
    programmatically generated field definition starts here
    -->
    <xsl:template match="/collection/items/transmitter/X_FINCEN_TRNSMTTR_NM">
        <fc2:RawPartyFullName>
            <xsl:value-of select="."/>
        </fc2:RawPartyFullName>
    </xsl:template>
    <xsl:template match="/collection/items/transmitter/X_FINCEN_TRNSMTTR_ADDRESS_TXT">
        <fc2:RawStreetAddress1Text>
            <xsl:value-of select="."/>
        </fc2:RawStreetAddress1Text>
    </xsl:template>
    <xsl:template match="/collection/items/transmitter/X_FINCEN_TRNSMTTR_CITY_NM">
        <fc2:RawCityText>
            <xsl:value-of select="."/>
        </fc2:RawCityText>
    </xsl:template>
    <xsl:template match="/collection/items/transmitter/X_FINCEN_TRNSMTTR_STATE_CD">
        <fc2:RawStateCodeText>
            <xsl:value-of select="."/>
        </fc2:RawStateCodeText>
    </xsl:template>
    <xsl:template match="/collection/items/transmitter/X_FINCEN_TRNSMTTR_ZIP_CD">
        <fc2:RawZIPCode>
            <xsl:value-of select="."/>
        </fc2:RawZIPCode>
    </xsl:template>
    <xsl:template match="/collection/items/transmitter/X_FINCEN_TRNSMTTR_COUNTRY_CD">
        <fc2:RawCountryCodeText>
            <xsl:value-of select="."/>
        </fc2:RawCountryCodeText>
    </xsl:template>
    <xsl:template match="/collection/items/transmitter/X_FINCEN_TRNSMTTR_PHONE_NO">
        <fc2:PhoneNumberText>
            <xsl:value-of select="."/>
        </fc2:PhoneNumberText>
    </xsl:template>
    <xsl:template match="/collection/items/transmitter/X_FINCEN_TRNSMTTR_CONTACT_NM">
        <fc2:RawPartyFullName>
            <xsl:value-of select="."/>
        </fc2:RawPartyFullName>
    </xsl:template>
    <xsl:template match="/collection/items/transmitter/X_FINCEN_TRNSMTTR_TIN_NO">
        <fc2:PartyIdentificationNumberText>
            <xsl:value-of select="."/>
        </fc2:PartyIdentificationNumberText>
    </xsl:template>
    <xsl:template match="/collection/items/transmitter/Z_COVERAGE_START_DT">
        <fc2:EFilingCoverageBeginningDateText>
            <xsl:value-of select="."/>
        </fc2:EFilingCoverageBeginningDateText>
    </xsl:template>
    <xsl:template match="/collection/items/transmitter/Z_COVERAGE_END_DT">
        <fc2:EFilingCoverageBeginningDateText>
            <xsl:value-of select="."/>
        </fc2:EFilingCoverageBeginningDateText>
    </xsl:template>
    <xsl:template match="/collection/items/transmitter/X_FINCEN_TRNSMTTR_TCC">
        <fc2:PartyIdentificationNumberText>
            <xsl:value-of select="."/>
        </fc2:PartyIdentificationNumberText>
    </xsl:template>
    <xsl:template match="X_FILING_INST_PRIM_FED_REG_CD">
        <fc2:PrimaryRegulatorTypeCode>
            <xsl:value-of select="."/>
        </fc2:PrimaryRegulatorTypeCode>
    </xsl:template>
    <xsl:template match="X_FILING_INST_NM">
        <fc2:RawPartyFullName>
            <xsl:value-of select="."/>
        </fc2:RawPartyFullName>
    </xsl:template>
    <xsl:template match="X_FILING_INST_ALTERNATE_NM">
        <fc2:RawPartyFullName>
            <xsl:value-of select="."/>
        </fc2:RawPartyFullName>
    </xsl:template>
    <xsl:template match="X_FILING_INST_ADDRESS_TXT">
        <fc2:RawStreetAddress1Text>
            <xsl:value-of select="."/>
        </fc2:RawStreetAddress1Text>
    </xsl:template>
    <xsl:template match="X_FILING_INST_CITY_NM">
        <fc2:RawCityText>
            <xsl:value-of select="."/>
        </fc2:RawCityText>
    </xsl:template>
    <xsl:template match="X_FILING_INST_STATE_CD">
        <fc2:RawStateCodeText>
            <xsl:value-of select="."/>
        </fc2:RawStateCodeText>
    </xsl:template>
    <xsl:template match="X_FILING_INST_POSTAL_CD">
        <fc2:RawZIPCode>
            <xsl:value-of select="."/>
        </fc2:RawZIPCode>
    </xsl:template>
    <xsl:template match="X_FILING_INST_COUNTRY_CD">
        <fc2:RawCountryCodeText>
            <xsl:value-of select="."/>
        </fc2:RawCountryCodeText>
    </xsl:template>
    <xsl:template match="X_FILING_INST_TIN_NO">
        <fc2:PartyIdentificationNumberText>
            <xsl:value-of select="."/>			
        </fc2:PartyIdentificationNumberText>
		
    </xsl:template>
    <xsl:template match="X_FILING_INST_TYPE_CTR_CD">
        <fc2:OrganizationTypeID>
            <xsl:value-of select="."/>
        </fc2:OrganizationTypeID>
    </xsl:template>
    <xsl:template match="X_FILING_INST_TYPE_OTH_TXT">
        <fc2:OtherOrganizationTypeText>
            <xsl:value-of select="."/>
        </fc2:OtherOrganizationTypeText>
    </xsl:template>
    <xsl:template match="X_FILING_INST_GAMING_TYPE_CD">
        <fc2:OrganizationSubtypeID>
            <xsl:value-of select="."/>
        </fc2:OrganizationSubtypeID>
    </xsl:template>
    <xsl:template match="X_FILING_INST_GAMING_TYPE_OTH">
        <fc2:OtherOrganizationSubTypeText>
            <xsl:value-of select="."/>
        </fc2:OtherOrganizationSubTypeText>
    </xsl:template>
    <xsl:template match="X_FILING_INST_ID_TYPE_CD">
        <fc2:PartyIdentificationTypeCode>
            <xsl:value-of select="."/>
        </fc2:PartyIdentificationTypeCode>
    </xsl:template>
    <xsl:template match="X_FILING_INST_ID_NO">
        <fc2:PartyIdentificationNumberText>
            <xsl:value-of select="."/>
        </fc2:PartyIdentificationNumberText>
    </xsl:template>
    <xsl:template match="X_INST_PRIM_FED_REG_CD">
        <fc2:PrimaryRegulatorTypeCode>
            <xsl:value-of select="."/>
        </fc2:PrimaryRegulatorTypeCode>
    </xsl:template>
    <xsl:template match="X_INST_LEGAL_NM">
        <fc2:RawPartyFullName>
            <xsl:value-of select="."/>
        </fc2:RawPartyFullName>
    </xsl:template>
    <xsl:template match="X_INST_ALT_NM">
        <fc2:RawPartyFullName>
            <xsl:value-of select="."/>
        </fc2:RawPartyFullName>
    </xsl:template>
    <xsl:template match="X_INST_TIN_NO">
        <fc2:PartyIdentificationNumberText>
            <xsl:value-of select="."/>
        </fc2:PartyIdentificationNumberText>
		<fc2:PartyIdentificationTypeCode>2</fc2:PartyIdentificationTypeCode>
    </xsl:template>
	<xsl:template match="X_INST_TIN_UNKNOWN_FLG">
        <fc2:TINUnknownIndicator>Y</fc2:TINUnknownIndicator>
    </xsl:template>
    <xsl:template match="X_INST_ADDRESS_TXT">
        <fc2:RawStreetAddress1Text>
            <xsl:value-of select="."/>
        </fc2:RawStreetAddress1Text>
    </xsl:template>
    <xsl:template match="X_INST_CITY_NM">
        <fc2:RawCityText>
            <xsl:value-of select="."/>
        </fc2:RawCityText>
    </xsl:template>
    <xsl:template match="X_INST_STATE_CD">
        <fc2:RawStateCodeText>
            <xsl:value-of select="."/>
        </fc2:RawStateCodeText>
    </xsl:template>
    <xsl:template match="X_INST_POSTAL_CD">
        <fc2:RawZIPCode>
            <xsl:value-of select="."/>
        </fc2:RawZIPCode>
    </xsl:template>
    <xsl:template match="X_INST_COUNTRY_CD">
        <fc2:RawCountryCodeText>
            <xsl:value-of select="."/>
        </fc2:RawCountryCodeText>
    </xsl:template>
    <xsl:template match="X_INST_TYPE_CTR_CD">
        <fc2:OrganizationTypeID>
            <xsl:value-of select="."/>
        </fc2:OrganizationTypeID>
    </xsl:template>
    <xsl:template match="X_INST_TYPE_OTH_TXT">
        <fc2:OtherOrganizationTypeText>
            <xsl:value-of select="."/>
        </fc2:OtherOrganizationTypeText>
    </xsl:template>
    <xsl:template match="X_INST_GAMING_TYPE_CD">
        <fc2:OrganizationSubtypeID>
            <xsl:value-of select="."/>
        </fc2:OrganizationSubtypeID>
    </xsl:template>
    <xsl:template match="X_INST_GAMING_TYPE_OTH_TXT">
        <fc2:OtherOrganizationSubTypeText>
            <xsl:value-of select="."/>
        </fc2:OtherOrganizationSubTypeText>
    </xsl:template>
    <xsl:template match="X_INST_ID_TYPE_CD">
        <fc2:PartyIdentificationTypeCode>
            <xsl:value-of select="."/>
        </fc2:PartyIdentificationTypeCode>
    </xsl:template>
    <xsl:template match="X_INST_ID">
        <fc2:PartyIdentificationNumberText>
            <xsl:value-of select="."/>
        </fc2:PartyIdentificationNumberText>
    </xsl:template>
    <xsl:template match="X_PRIOR_AGENCY_REF_ID">
        <fc2:EFilingPriorDocumentNumber>
            <xsl:value-of select="."/>
        </fc2:EFilingPriorDocumentNumber>
    </xsl:template>
    <xsl:template match="X_TRANSACTION_DT">
        <fc2:TransactionDateText>
            <xsl:value-of select="."/>
        </fc2:TransactionDateText>
    </xsl:template>
    <xsl:template match="X_US_CASH_IN_AMT">
        <fc2:TotalCashInReceiveAmountText>
            <xsl:value-of select="."/>
        </fc2:TotalCashInReceiveAmountText>
    </xsl:template>
    <xsl:template match="X_US_CASH_IN_A_AMT">
        <fc2:CurrencyTransactionActivityDetail SeqNum=".">
            <fc2:CurrencyTransactionActivityDetailTypeCode>55</fc2:CurrencyTransactionActivityDetailTypeCode>
            <fc2:DetailTransactionAmountText>
                <xsl:value-of select="."/>
            </fc2:DetailTransactionAmountText>
            <fc2:OtherCurrencyTransactionActivityDetailText/>
            <fc2:OtherForeignCurrencyCountryText/>
        </fc2:CurrencyTransactionActivityDetail>
    </xsl:template>
    <xsl:template match="X_US_CASH_IN_B_AMT">
        <fc2:CurrencyTransactionActivityDetail SeqNum=".">
            <fc2:CurrencyTransactionActivityDetailTypeCode>46</fc2:CurrencyTransactionActivityDetailTypeCode>
            <fc2:DetailTransactionAmountText>
                <xsl:value-of select="."/>
            </fc2:DetailTransactionAmountText>
            <fc2:OtherCurrencyTransactionActivityDetailText/>
            <fc2:OtherForeignCurrencyCountryText/>
        </fc2:CurrencyTransactionActivityDetail>
    </xsl:template>
    <xsl:template match="X_US_CASH_IN_C_AMT">
        <fc2:CurrencyTransactionActivityDetail SeqNum=".">
            <fc2:CurrencyTransactionActivityDetailTypeCode>23</fc2:CurrencyTransactionActivityDetailTypeCode>
            <fc2:DetailTransactionAmountText>
                <xsl:value-of select="."/>
            </fc2:DetailTransactionAmountText>
            <fc2:OtherCurrencyTransactionActivityDetailText/>
            <fc2:OtherForeignCurrencyCountryText/>
        </fc2:CurrencyTransactionActivityDetail>
    </xsl:template>
    <xsl:template match="X_US_CASH_IN_D_AMT">
        <fc2:CurrencyTransactionActivityDetail SeqNum=".">
            <fc2:CurrencyTransactionActivityDetailTypeCode>12</fc2:CurrencyTransactionActivityDetailTypeCode>
            <fc2:DetailTransactionAmountText>
                <xsl:value-of select="."/>
            </fc2:DetailTransactionAmountText>
            <fc2:OtherCurrencyTransactionActivityDetailText/>
            <fc2:OtherForeignCurrencyCountryText/>
        </fc2:CurrencyTransactionActivityDetail>
    </xsl:template>
    <xsl:template match="X_US_CASH_IN_E_AMT">
        <fc2:CurrencyTransactionActivityDetail SeqNum=".">
            <fc2:CurrencyTransactionActivityDetailTypeCode>14</fc2:CurrencyTransactionActivityDetailTypeCode>
            <fc2:DetailTransactionAmountText>
                <xsl:value-of select="."/>
            </fc2:DetailTransactionAmountText>
            <fc2:OtherCurrencyTransactionActivityDetailText/>
            <fc2:OtherForeignCurrencyCountryText/>
        </fc2:CurrencyTransactionActivityDetail>
    </xsl:template>
    <xsl:template match="X_US_CASH_IN_F_AMT">
        <fc2:CurrencyTransactionActivityDetail SeqNum=".">
            <fc2:CurrencyTransactionActivityDetailTypeCode>49</fc2:CurrencyTransactionActivityDetailTypeCode>
            <fc2:DetailTransactionAmountText>
                <xsl:value-of select="."/>
            </fc2:DetailTransactionAmountText>
            <fc2:OtherCurrencyTransactionActivityDetailText/>
            <fc2:OtherForeignCurrencyCountryText/>
        </fc2:CurrencyTransactionActivityDetail>
    </xsl:template>
    <xsl:template match="X_US_CASH_IN_G_AMT">
        <fc2:CurrencyTransactionActivityDetail SeqNum=".">
            <fc2:CurrencyTransactionActivityDetailTypeCode>18</fc2:CurrencyTransactionActivityDetailTypeCode>
            <fc2:DetailTransactionAmountText>
                <xsl:value-of select="."/>
            </fc2:DetailTransactionAmountText>
            <fc2:OtherCurrencyTransactionActivityDetailText/>
            <fc2:OtherForeignCurrencyCountryText/>
        </fc2:CurrencyTransactionActivityDetail>
    </xsl:template>
    <xsl:template match="X_US_CASH_IN_H_AMT">
        <fc2:CurrencyTransactionActivityDetail SeqNum=".">
            <fc2:CurrencyTransactionActivityDetailTypeCode>21</fc2:CurrencyTransactionActivityDetailTypeCode>
            <fc2:DetailTransactionAmountText>
                <xsl:value-of select="."/>
            </fc2:DetailTransactionAmountText>
            <fc2:OtherCurrencyTransactionActivityDetailText/>
            <fc2:OtherForeignCurrencyCountryText/>
        </fc2:CurrencyTransactionActivityDetail>
    </xsl:template>
    <xsl:template match="X_US_CASH_IN_I_AMT">
        <fc2:CurrencyTransactionActivityDetail SeqNum=".">
            <fc2:CurrencyTransactionActivityDetailTypeCode>25</fc2:CurrencyTransactionActivityDetailTypeCode>
            <fc2:DetailTransactionAmountText>
                <xsl:value-of select="."/>
            </fc2:DetailTransactionAmountText>
            <fc2:OtherCurrencyTransactionActivityDetailText/>
            <fc2:OtherForeignCurrencyCountryText/>
        </fc2:CurrencyTransactionActivityDetail>
    </xsl:template>
    <xsl:template match="X_US_CASH_IN_OTH_TXT">
        <fc2:OtherCurrencyTransactionActivityDetailText>
            <xsl:value-of select="."/>
        </fc2:OtherCurrencyTransactionActivityDetailText>
    </xsl:template>
    <xsl:template match="X_US_CASH_IN_Z_AMT">
        <fc2:DetailTransactionAmountText>
            <xsl:value-of select="."/>
        </fc2:DetailTransactionAmountText>
    </xsl:template>
    <xsl:template match="X_US_CASH_OUT_AMT">
        <fc2:TotalCashOutAmountText>
            <xsl:value-of select="."/>
        </fc2:TotalCashOutAmountText>
    </xsl:template>
    <xsl:template match="X_US_CASH_OUT_A_AMT">
        <fc2:CurrencyTransactionActivityDetail SeqNum=".">
            <fc2:CurrencyTransactionActivityDetailTypeCode>56</fc2:CurrencyTransactionActivityDetailTypeCode>
            <fc2:DetailTransactionAmountText>
                <xsl:value-of select="."/>
            </fc2:DetailTransactionAmountText>
            <fc2:OtherCurrencyTransactionActivityDetailText/>
            <fc2:OtherForeignCurrencyCountryText/>
        </fc2:CurrencyTransactionActivityDetail>
    </xsl:template>
    <xsl:template match="X_US_CASH_OUT_B_AMT">
        <fc2:CurrencyTransactionActivityDetail SeqNum=".">
            <fc2:CurrencyTransactionActivityDetailTypeCode>30</fc2:CurrencyTransactionActivityDetailTypeCode>
            <fc2:DetailTransactionAmountText>
                <xsl:value-of select="."/>
            </fc2:DetailTransactionAmountText>
            <fc2:OtherCurrencyTransactionActivityDetailText/>
            <fc2:OtherForeignCurrencyCountryText/>
        </fc2:CurrencyTransactionActivityDetail>
    </xsl:template>
    <xsl:template match="X_US_CASH_OUT_C_AMT">
        <fc2:CurrencyTransactionActivityDetail SeqNum=".">
            <fc2:CurrencyTransactionActivityDetailTypeCode>32</fc2:CurrencyTransactionActivityDetailTypeCode>
            <fc2:DetailTransactionAmountText>
                <xsl:value-of select="."/>
            </fc2:DetailTransactionAmountText>
            <fc2:OtherCurrencyTransactionActivityDetailText/>
            <fc2:OtherForeignCurrencyCountryText/>
        </fc2:CurrencyTransactionActivityDetail>
    </xsl:template>
    <xsl:template match="X_US_CASH_OUT_D_AMT">
        <fc2:CurrencyTransactionActivityDetail SeqNum=".">
            <fc2:CurrencyTransactionActivityDetailTypeCode>13</fc2:CurrencyTransactionActivityDetailTypeCode>
            <fc2:DetailTransactionAmountText>
                <xsl:value-of select="."/>
            </fc2:DetailTransactionAmountText>
            <fc2:OtherCurrencyTransactionActivityDetailText/>
            <fc2:OtherForeignCurrencyCountryText/>
        </fc2:CurrencyTransactionActivityDetail>
    </xsl:template>
    <xsl:template match="X_US_CASH_OUT_E_AMT">
        <fc2:CurrencyTransactionActivityDetail SeqNum=".">
            <fc2:CurrencyTransactionActivityDetailTypeCode>15</fc2:CurrencyTransactionActivityDetailTypeCode>
            <fc2:DetailTransactionAmountText>
                <xsl:value-of select="."/>
            </fc2:DetailTransactionAmountText>
            <fc2:OtherCurrencyTransactionActivityDetailText/>
            <fc2:OtherForeignCurrencyCountryText/>
        </fc2:CurrencyTransactionActivityDetail>
    </xsl:template>
    <xsl:template match="X_US_CASH_OUT_F_AMT">
        <fc2:CurrencyTransactionActivityDetail SeqNum=".">
            <fc2:CurrencyTransactionActivityDetailTypeCode>48</fc2:CurrencyTransactionActivityDetailTypeCode>
            <fc2:DetailTransactionAmountText>
                <xsl:value-of select="."/>
            </fc2:DetailTransactionAmountText>
            <fc2:OtherCurrencyTransactionActivityDetailText/>
            <fc2:OtherForeignCurrencyCountryText/>
        </fc2:CurrencyTransactionActivityDetail>
    </xsl:template>
    <xsl:template match="X_US_CASH_OUT_G_AMT">
        <fc2:CurrencyTransactionActivityDetail SeqNum=".">
            <fc2:CurrencyTransactionActivityDetailTypeCode>28</fc2:CurrencyTransactionActivityDetailTypeCode>
            <fc2:DetailTransactionAmountText>
                <xsl:value-of select="."/>
            </fc2:DetailTransactionAmountText>
            <fc2:OtherCurrencyTransactionActivityDetailText/>
            <fc2:OtherForeignCurrencyCountryText/>
        </fc2:CurrencyTransactionActivityDetail>
    </xsl:template>
    <xsl:template match="X_US_CASH_OUT_H_AMT">
        <fc2:CurrencyTransactionActivityDetail SeqNum=".">
            <fc2:CurrencyTransactionActivityDetailTypeCode>31</fc2:CurrencyTransactionActivityDetailTypeCode>
            <fc2:DetailTransactionAmountText>
                <xsl:value-of select="."/>
            </fc2:DetailTransactionAmountText>
            <fc2:OtherCurrencyTransactionActivityDetailText/>
            <fc2:OtherForeignCurrencyCountryText/>
        </fc2:CurrencyTransactionActivityDetail>
    </xsl:template>
    <xsl:template match="X_US_CASH_OUT_I_AMT">
        <fc2:CurrencyTransactionActivityDetail SeqNum=".">
            <fc2:CurrencyTransactionActivityDetailTypeCode>33</fc2:CurrencyTransactionActivityDetailTypeCode>
            <fc2:DetailTransactionAmountText>
                <xsl:value-of select="."/>
            </fc2:DetailTransactionAmountText>
            <fc2:OtherCurrencyTransactionActivityDetailText/>
            <fc2:OtherForeignCurrencyCountryText/>
        </fc2:CurrencyTransactionActivityDetail>
    </xsl:template>
    <xsl:template match="X_US_CASH_OUT_J_AMT">
        <fc2:CurrencyTransactionActivityDetail SeqNum=".">
            <fc2:CurrencyTransactionActivityDetailTypeCode>34</fc2:CurrencyTransactionActivityDetailTypeCode>
            <fc2:DetailTransactionAmountText>
                <xsl:value-of select="."/>
            </fc2:DetailTransactionAmountText>
            <fc2:OtherCurrencyTransactionActivityDetailText/>
            <fc2:OtherForeignCurrencyCountryText/>
        </fc2:CurrencyTransactionActivityDetail>
    </xsl:template>
    <xsl:template match="X_US_CASH_OUT_OTH_TXT">
        <fc2:OtherCurrencyTransactionActivityDetailText>
            <xsl:value-of select="."/>
        </fc2:OtherCurrencyTransactionActivityDetailText>
    </xsl:template>
    <xsl:template match="X_US_CASH_OUT_Z_AMT">
        <fc2:DetailTransactionAmountText>
            <xsl:value-of select="."/>
        </fc2:DetailTransactionAmountText>
    </xsl:template>
    <xsl:template match="X_CTR_CONTACT_OFFICE">
        <fc2:RawPartyFullName>
            <xsl:value-of select="."/>
        </fc2:RawPartyFullName>
    </xsl:template>
    <xsl:template match="X_CTR_CONTACT_PHONE_NO">
        <fc2:PhoneNumberText>
            <xsl:value-of select="."/>
        </fc2:PhoneNumberText>
    </xsl:template>
    <xsl:template match="X_CTR_CONTACT_PHONE_EXT_NO">
        <fc2:PhoneNumberExtensionText>
            <xsl:value-of select="."/>
        </fc2:PhoneNumberExtensionText>
    </xsl:template>
    <xsl:template match="X_FILED_DT">
        <fc2:FilingDateText>
            <xsl:value-of select="."/>
        </fc2:FilingDateText>
    </xsl:template>
    <xsl:template match="X_FOREIGN_CASH_IN_AMT">
        <fc2:DetailTransactionAmountText>
            <xsl:value-of select="."/>
        </fc2:DetailTransactionAmountText>
    </xsl:template>
    <xsl:template match="X_FOREIGN_CASH_IN_COUNTRY_CD">
        <fc2:OtherForeignCurrencyCountryText>
            <xsl:value-of select="."/>
        </fc2:OtherForeignCurrencyCountryText>
    </xsl:template>
    <xsl:template match="X_FOREIGN_CASH_OUT_AMT">
        <fc2:DetailTransactionAmountText>
            <xsl:value-of select="."/>
        </fc2:DetailTransactionAmountText>
    </xsl:template>
    <xsl:template match="X_FOREIGN_CASH_OUT_COUNTRY_CD">
        <fc2:OtherForeignCurrencyCountryText>
            <xsl:value-of select="."/>
        </fc2:OtherForeignCurrencyCountryText>
    </xsl:template>
    <xsl:template match="X_PERSON_INVOLVED_TYPE_CD">
        <fc2:ActivityPartyTypeCode>
            <xsl:value-of select="."/>
        </fc2:ActivityPartyTypeCode>
    </xsl:template>
    <xsl:template match="X_MULTI_TRANSACTION_FLG">
        <fc2:MultipleTransactionsPersonsIndividualsIndicator>Y</fc2:MultipleTransactionsPersonsIndividualsIndicator>
    </xsl:template>
    <xsl:template match="X_LAST_NM">
        <fc2:RawEntityIndividualLastName>
            <xsl:value-of select="."/>
        </fc2:RawEntityIndividualLastName>
    </xsl:template>
    <xsl:template match="X_ENTITY_FLG">
        <fc2:PartyAsEntityOrganizationIndicator>Y</fc2:PartyAsEntityOrganizationIndicator>
    </xsl:template>
    <xsl:template match="X_LAST_NM_UNKNOWN_FLG">
        <fc2:EntityLastNameUnknownIndicator>Y</fc2:EntityLastNameUnknownIndicator>
    </xsl:template>
    <xsl:template match="X_FIRST_NM">
        <fc2:RawIndividualFirstName>
            <xsl:value-of select="."/>
        </fc2:RawIndividualFirstName>
    </xsl:template>
    <xsl:template match="X_FIRST_NM_UNKNOWN_FLG">
        <fc2:FirstNameUnknownIndicator>Y</fc2:FirstNameUnknownIndicator>
    </xsl:template>
    <xsl:template match="X_MIDDLE_NM">
        <fc2:RawIndividualMiddleName>
            <xsl:value-of select="."/>
        </fc2:RawIndividualMiddleName>
    </xsl:template>
    <xsl:template match="X_SUFFIX_NM">
        <fc2:RawIndividualNameSuffixText>
            <xsl:value-of select="."/>
        </fc2:RawIndividualNameSuffixText>
    </xsl:template>
    <xsl:template match="X_ALTERNATE_NM">
        <fc2:RawEntityIndividualLastName>
            <xsl:value-of select="."/>
        </fc2:RawEntityIndividualLastName>
    </xsl:template>
    <xsl:template match="X_ADDRESS_TXT">
        <fc2:RawStreetAddress1Text>
            <xsl:value-of select="."/>
        </fc2:RawStreetAddress1Text>
    </xsl:template>
    <xsl:template match="X_ADDRESS_UNKNOWN_FLG">
        <fc2:StreetAddressUnknownIndicator>Y</fc2:StreetAddressUnknownIndicator>
    </xsl:template>
    <xsl:template match="X_CITY_NM">
        <fc2:RawCityText>
            <xsl:value-of select="."/>
        </fc2:RawCityText>
    </xsl:template>
    <xsl:template match="X_CITY_UNKNOWN_FLG">
        <fc2:CityUnknownIndicator>Y</fc2:CityUnknownIndicator>
    </xsl:template>
    <xsl:template match="X_STATE_CD">
        <fc2:RawStateCodeText>
            <xsl:value-of select="."/>
        </fc2:RawStateCodeText>
    </xsl:template>
    <xsl:template match="X_STATE_UNKNOWN_FLG">
        <fc2:StateCodeUnknownIndicator>Y</fc2:StateCodeUnknownIndicator>
    </xsl:template>
    <xsl:template match="X_POSTAL_CD">
        <fc2:RawZIPCode>
            <xsl:value-of select="."/>
        </fc2:RawZIPCode>
    </xsl:template>
    <xsl:template match="X_POSTAL_UNKNOWN_FLG">
        <fc2:ZIPCodeUnknownIndicator>Y</fc2:ZIPCodeUnknownIndicator>
    </xsl:template>
    <xsl:template match="X_COUNTRY_CD">
        <fc2:RawCountryCodeText>
            <xsl:value-of select="."/>
        </fc2:RawCountryCodeText>
    </xsl:template>
    <xsl:template match="X_COUNTRY_UNKNOWN_FLG">
        <fc2:CountryCodeUnknownIndicator>Y</fc2:CountryCodeUnknownIndicator>
    </xsl:template>
    <xsl:template match="X_TIN_NO">
        <fc2:PartyIdentificationNumberText>
            <xsl:value-of select="."/>
        </fc2:PartyIdentificationNumberText>
    </xsl:template>
    <xsl:template match="X_TIN_UNKNOWN_FLG">
        <fc2:TINUnknownIndicator>Y</fc2:TINUnknownIndicator>
    </xsl:template>
    <xsl:template match="X_TIN_TYPE_CD">
        <fc2:PartyIdentificationTypeCode>
            <xsl:value-of select="."/>
        </fc2:PartyIdentificationTypeCode>
    </xsl:template>
    <xsl:template match="X_BIRTHDAY_TXT">
        <fc2:IndividualBirthDateText>
            <xsl:value-of select="."/>
        </fc2:IndividualBirthDateText>
    </xsl:template>
    <xsl:template match="X_BIRTH_DT_UNKNOWN_FLG">
        <fc2:BirthDateUnknownIndicator>Y</fc2:BirthDateUnknownIndicator>
    </xsl:template>
    <xsl:template match="X_PHONE_NO">
        <fc2:PhoneNumberText>
            <xsl:value-of select="."/>
        </fc2:PhoneNumberText>
    </xsl:template>
    <xsl:template match="X_PHONE_EXT_NO">
        <fc2:PhoneNumberExtensionText>
            <xsl:value-of select="."/>
        </fc2:PhoneNumberExtensionText>
    </xsl:template>
    <xsl:template match="X_EMAIL_ADDRESS_TXT">
        <fc2:ElectronicAddressText>
            <xsl:value-of select="."/>
        </fc2:ElectronicAddressText>
    </xsl:template>
    <xsl:template match="X_PERSONAL_ID_TYPE_OTH_TXT">
        <fc2:OtherPartyIdentificationTypeText>
            <xsl:value-of select="."/>
        </fc2:OtherPartyIdentificationTypeText>
    </xsl:template>
    <xsl:template match="X_ID_AUTHORITY_STATE_CD">
        <fc2:OtherIssuerStateText>
            <xsl:value-of select="."/>
        </fc2:OtherIssuerStateText>
    </xsl:template>
    <xsl:template match="X_ID_AUTHORITY_COUNTRY_CD">
        <fc2:OtherIssuerCountryText>
            <xsl:value-of select="."/>
        </fc2:OtherIssuerCountryText>
    </xsl:template>
    <xsl:template match="X_ID_NO">
        <fc2:PartyIdentificationNumberText>
            <xsl:value-of select="."/>
        </fc2:PartyIdentificationNumberText>
    </xsl:template>
    <xsl:template match="X_CASH_IN_AMT">
        <fc2:IndividualEntityCashInAmountText>
            <xsl:value-of select="."/>
        </fc2:IndividualEntityCashInAmountText>
    </xsl:template>
    <xsl:template match="X_CASH_OUT_AMT">
        <fc2:IndividualEntityCashOutAmountText>
            <xsl:value-of select="."/>
        </fc2:IndividualEntityCashOutAmountText>
    </xsl:template>
    <xsl:template match="X_CASH_IN_ACCT_ID">
        <fc2:AccountNumberText>
            <xsl:value-of select="."/>
        </fc2:AccountNumberText>
    </xsl:template>
    <xsl:template match="X_CASH_OUT_ACCT_ID">
        <fc2:AccountNumberText>
            <xsl:value-of select="."/>
        </fc2:AccountNumberText>
    </xsl:template>


    <!--
    programmatically generated field definition ends here
    -->

</xsl:stylesheet>
