<?xml version="1.0"?>
<!-- sarx_efile.xsl -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fc2="www.fincen.gov/base">
	<xsl:output method="xml" indent="yes"/>
	<xsl:template match="/collection/items">
		<fc2:EFilingBatchXML ActivityCount="{global/ActivityCount}"
							 TotalAmount="{global/TotalAmount}"
                             PartyCount="{global/PartyCount}" 
							 ActivityAttachmentCount="{global/ActivityAttachmentCount}"
							 AttachmentCount="{global/AttachmentCount}"
                             xsi:schemaLocation="www.fincen.gov/base EFL_SARXBatchSchema.xsd"
                             xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
                             xmlns:fc2="www.fincen.gov/base">

			<fc2:FormTypeCode>SARX</fc2:FormTypeCode>
			<xsl:apply-templates select="report"/>
		</fc2:EFilingBatchXML>
	</xsl:template>


	<xsl:template match="/collection/items/report">	 

		<fc2:Activity SeqNum="{RR_RK}">

			<xsl:if test="X_PRIOR_AGENCY_REF_ID">
				<fc2:EFilingPriorDocumentNumber>
					<xsl:value-of select="X_PRIOR_AGENCY_REF_ID"/>				 
				</fc2:EFilingPriorDocumentNumber>
			</xsl:if>

			<fc2:FilingDateText>
				<xsl:value-of select="/collection/items/global/FilingDate"/>				 
			</fc2:FilingDateText>	

			<xsl:if test="X_NOTE_TO_FINCEN">
				<fc2:FilingInstitutionNotetoFinCEN>
					<xsl:value-of select="X_NOTE_TO_FINCEN"/>				 
				</fc2:FilingInstitutionNotetoFinCEN>
			</xsl:if> 


			<fc2:ActivityAssociation SeqNum=".">
				<xsl:if test="X_SAR_CONTINUE_ACTIVITY_FLG='1'">
					<fc2:ContinuingActivityReportIndicator>Y</fc2:ContinuingActivityReportIndicator>
				</xsl:if>
				<fc2:CorrectsAmendsPriorReportIndicator>
					<xsl:value-of select="X_SAR_FILING_TYPE_CD_B"/>
				</fc2:CorrectsAmendsPriorReportIndicator>                
				<fc2:InitialReportIndicator>
					<xsl:value-of select="X_SAR_FILING_TYPE_CD_A"/>
				</fc2:InitialReportIndicator>
				<xsl:if test="X_SAR_JOINT_RPT_FLG='1'">
					<fc2:JointReportIndicator>Y</fc2:JointReportIndicator>
				</xsl:if>
			</fc2:ActivityAssociation>

			<xsl:if test="X_SAR_ATTACHMENT_NM">
				<fc2:ActivitySupportDocument SeqNum=".">
					<fc2:OriginalAttachmentFileName>
						<xsl:value-of select="X_SAR_ATTACHMENT_NM"/>	
					</fc2:OriginalAttachmentFileName>
				</fc2:ActivitySupportDocument>
			</xsl:if>
			<!--
                Transmitter party(35), 
				Transmitter contact party(37)
            -->

			<xsl:apply-templates select="/collection/items/transmitter"/>


			<!--
                Filing Institution party(30)				 		
            -->

			<xsl:apply-templates select="X_FILING_INST_NM"/>

			<!--
                 
				Designated contact office party(8)				
            -->
			<xsl:apply-templates select="X_SAR_CONTACT_OFFICE"/>

			<!--
                Law enforcement agency party(18)
            -->

			<xsl:apply-templates select="X_SAR_LE_CONTACT_AGENCY_NM"/>


			<!--
                Law enforcement name party(18)
            -->

			<xsl:apply-templates select="X_SAR_LE_CONTACT_NM"/>

			<!--
                Financial Institution Where Activity Occurred party(34)
            -->

			<xsl:apply-templates select="institution"/>


			<!--
                Subject Party  party(33)
            -->

			<xsl:apply-templates select="subject"/>

			<!-- Suspicious Activity -->
			<fc2:SuspiciousActivity SeqNum=".">
				<!-- AmountUnknown, CumulativeTotal and NoAmount before the Begin and End Date -->
				<xsl:if test="X_SAR_INVOLVED_AMT_CD='A'">
					<fc2:AmountUnknownIndicator>Y</fc2:AmountUnknownIndicator>
				</xsl:if>
				<xsl:if test="X_SAR_CUMULATE_AMT">
					<fc2:CumulativeTotalViolationAmountText>
						<xsl:value-of select="X_SAR_CUMULATE_AMT"/>
					</fc2:CumulativeTotalViolationAmountText>
				</xsl:if>
				<xsl:if test="X_SAR_INVOLVED_AMT_CD='B'">
					<fc2:NoAmountInvolvedIndicator>Y</fc2:NoAmountInvolvedIndicator>
				</xsl:if>
				<fc2:SuspiciousActivityFromDateText>
					<xsl:value-of select="X_SAR_BEGIN_DT"/>
				</fc2:SuspiciousActivityFromDateText>
				<xsl:if test="X_SAR_END_DT">
					<fc2:SuspiciousActivityToDateText>
						<xsl:value-of select="X_SAR_END_DT"/>
					</fc2:SuspiciousActivityToDateText>
				</xsl:if> 

				<fc2:TotalSuspiciousAmountText>
					<xsl:value-of select="X_SAR_INVOLVED_AMT"/>
				</fc2:TotalSuspiciousAmountText>

				<xsl:for-each select="*/@SuspiciousActivityTypeID">

					<xsl:call-template name="SARClassification">
						<xsl:with-param name="SARType" select = ".." />
					</xsl:call-template>

				</xsl:for-each>

			</fc2:SuspiciousActivity>



			<xsl:apply-templates select="X_IP_ADDRESS"/>

			<xsl:apply-templates select="X_CYBER_EVENT"/>

			<!-- Assets -->
			<xsl:for-each select="*/@AssetTypeID">

				<xsl:call-template name="AssetClassification">
					<xsl:with-param name="AssetType" select = ".." />
				</xsl:call-template>

			</xsl:for-each>	

			<!-- AssetsAttribute -->
			<xsl:for-each select="*/@AssetAttributeTypeID">

				<xsl:call-template name="AssetAttributeClassification">
					<xsl:with-param name="AssetAttributeType" select = ".." />
				</xsl:call-template>

			</xsl:for-each>	

			<xsl:apply-templates select="X_SAR_NARRATIVE_DESC"/>			

		</fc2:Activity>
	</xsl:template>


	<xsl:template name = "SARClassification" >

		<xsl:param name = "SARType" />

		<xsl:variable name="typeOtherName">
			<xsl:value-of select="name(..)"/>_OTH_TXT</xsl:variable>

		<xsl:for-each select="../checkbox_code">
			<fc2:SuspiciousActivityClassification SeqNum=".">
				<xsl:variable name="typeValue">
					<xsl:value-of select = "."/>
				</xsl:variable>

				<xsl:if test="substring($typeValue, string-length($typeValue) - 2)='999'">
					<fc2:OtherSuspiciousActivityTypeText>
						<xsl:value-of select = "../../*[name()=$typeOtherName]"/>
					</fc2:OtherSuspiciousActivityTypeText>
				</xsl:if>

				<fc2:SuspiciousActivitySubtypeID>
					<xsl:value-of select = "."/>
				</fc2:SuspiciousActivitySubtypeID>	 
				<fc2:SuspiciousActivityTypeID>
					<xsl:value-of select = "../@SuspiciousActivityTypeID" />
				</fc2:SuspiciousActivityTypeID>
			</fc2:SuspiciousActivityClassification>
		</xsl:for-each>

	</xsl:template>


	<xsl:template match="X_SAR_NARRATIVE_DESC">

		<fc2:ActivityNarrativeInformation SeqNum=".">
			<fc2:ActivityNarrativeSequenceNumber>
				<xsl:value-of select="_sequenceNumber"/>
			</fc2:ActivityNarrativeSequenceNumber>
			<!-- No white space between tag and text is allowed by FinCEN as of 31jul2018 -->
			<fc2:ActivityNarrativeText><xsl:value-of select="_text"/></fc2:ActivityNarrativeText>
		</fc2:ActivityNarrativeInformation>
	</xsl:template>


	<xsl:template name = "AssetClassification" >

		<xsl:param name = "AssetType" />
		<xsl:variable name="AssetTypeOtherName">
			<xsl:value-of select="name(..)"/>_OTH_TXT</xsl:variable>
		<xsl:for-each select="../checkbox_code">
			<fc2:Assets SeqNum=".">
				<xsl:variable name="AssetTypeValue">
					<xsl:value-of select = "."/>
				</xsl:variable>

				<fc2:AssetSubtypeID>
					<xsl:value-of select = "."/>
				</fc2:AssetSubtypeID>
				<fc2:AssetTypeID>
					<xsl:value-of select = "../@AssetTypeID" />
				</fc2:AssetTypeID>

				<xsl:if test="$AssetTypeValue='41' or $AssetTypeValue='30'">
					<fc2:OtherAssetSubtypeText>
						<xsl:value-of select = "../../*[name()=$AssetTypeOtherName]"/>
					</fc2:OtherAssetSubtypeText>
				</xsl:if>

			</fc2:Assets>
		</xsl:for-each>



	</xsl:template>


	<xsl:template match="X_IP_ADDRESS">

		<fc2:ActivityIPAddress SeqNum=".">
			<fc2:ActivityIPAddressDateText>
				<xsl:value-of select = "X_IP_ADDRESS_DT"/>
			</fc2:ActivityIPAddressDateText>
			<fc2:ActivityIPAddressTimeStampText>
				<xsl:value-of select = "X_IP_ADDRESS_TM"/>
			</fc2:ActivityIPAddressTimeStampText>
			<fc2:IPAddressText>
				<xsl:value-of select = "X_IP_ADDRESS_TXT"/>
			</fc2:IPAddressText>
		</fc2:ActivityIPAddress>
	</xsl:template>

	<xsl:template match="X_CYBER_EVENT">
		<fc2:CyberEventIndicators SeqNum=".">
			<fc2:CyberEventDateText>
				<xsl:value-of select = "X_CYBER_EVENT_DT"/>
			</fc2:CyberEventDateText>
			<fc2:CyberEventIndicatorsTypeCode>
				<xsl:value-of select = "X_CYBER_EVENT_TYPE_CD"/>
			</fc2:CyberEventIndicatorsTypeCode>
			<fc2:CyberEventTimeStampText>
				<xsl:value-of select = "X_CYBER_EVENT_TM"/>
			</fc2:CyberEventTimeStampText>
			<fc2:CyberEventTypeOtherText>
				<xsl:value-of select = "X_CYBER_EVENT_TYPE_OTH_TXT"/>
			</fc2:CyberEventTypeOtherText>
			<fc2:EventValueText>
				<xsl:value-of select = "X_CYBER_EVENT_VALUE"/>
			</fc2:EventValueText>
		</fc2:CyberEventIndicators>

	</xsl:template>

	<xsl:template name = "AssetAttributeClassification" >

		<xsl:param name = "AssetAttributeType" />

		<xsl:for-each select="../description_text">
			<fc2:AssetsAttribute SeqNum=".">
				<fc2:AssetAttributeDescriptionText>
					<xsl:value-of select = "."/>
				</fc2:AssetAttributeDescriptionText>
				<fc2:AssetAttributeTypeID>
					<xsl:value-of select = "../@AssetAttributeTypeID" />
				</fc2:AssetAttributeTypeID>		
			</fc2:AssetsAttribute>
		</xsl:for-each>
	</xsl:template>

	<!--   Transmitter -->
	<xsl:template match="/collection/items/transmitter">
		<!--   Transmitter party(35)     -->
		<fc2:Party SeqNum=".">

			<fc2:ActivityPartyTypeCode>35</fc2:ActivityPartyTypeCode>                 
			<fc2:PartyName SeqNum=".">
				<fc2:PartyNameTypeCode>L</fc2:PartyNameTypeCode>
				<fc2:RawPartyFullName>
					<xsl:value-of select="X_FINCEN_TRNSMTTR_NM"/>
				</fc2:RawPartyFullName>
			</fc2:PartyName>

			<fc2:Address SeqNum=".">

				<fc2:RawCityText>
					<xsl:value-of select="X_FINCEN_TRNSMTTR_CITY_NM"/>
				</fc2:RawCityText>

				<fc2:RawCountryCodeText>
					<xsl:value-of select="X_FINCEN_TRNSMTTR_COUNTRY_CD"/>
				</fc2:RawCountryCodeText>


				<fc2:RawStateCodeText>
					<xsl:value-of select="X_FINCEN_TRNSMTTR_STATE_CD"/>
				</fc2:RawStateCodeText>

				<fc2:RawStreetAddress1Text>
					<xsl:value-of select="X_FINCEN_TRNSMTTR_ADDRESS_TXT"/>
				</fc2:RawStreetAddress1Text>


				<fc2:RawZIPCode>
					<xsl:value-of select="X_FINCEN_TRNSMTTR_ZIP_CD"/>
				</fc2:RawZIPCode>

			</fc2:Address>

			<xsl:if test="X_FINCEN_TRNSMTTR_PHONE_NO">
				<fc2:PhoneNumber SeqNum=".">					 
					<fc2:PhoneNumberText>
						<xsl:value-of select="X_FINCEN_TRNSMTTR_PHONE_NO"/>
					</fc2:PhoneNumberText>
				</fc2:PhoneNumber>
			</xsl:if>

			<fc2:PartyIdentification SeqNum=".">				 
				<fc2:PartyIdentificationNumberText>
					<xsl:value-of select="X_FINCEN_TRNSMTTR_TIN_NO"/>
				</fc2:PartyIdentificationNumberText>
				<fc2:PartyIdentificationTypeCode>4</fc2:PartyIdentificationTypeCode>
			</fc2:PartyIdentification>

			<fc2:PartyIdentification SeqNum=".">
				<fc2:PartyIdentificationNumberText>
					<xsl:value-of select="X_FINCEN_TRNSMTTR_TCC"/>
				</fc2:PartyIdentificationNumberText>

				<fc2:PartyIdentificationTypeCode>28</fc2:PartyIdentificationTypeCode>
			</fc2:PartyIdentification>
		</fc2:Party>

		<!--   Transmitter contact party(37) -->
		<fc2:Party SeqNum=".">
			<fc2:ActivityPartyTypeCode>37</fc2:ActivityPartyTypeCode>              

			<fc2:PartyName SeqNum=".">
				<fc2:PartyNameTypeCode>L</fc2:PartyNameTypeCode>
				<fc2:RawPartyFullName>
					<xsl:value-of select="X_FINCEN_TRNSMTTR_CONTACT_NM"/>
				</fc2:RawPartyFullName>

			</fc2:PartyName>
		</fc2:Party>
	</xsl:template>

	<!--   Filing institution  -->
	<xsl:template match="X_FILING_INST_NM">

		<!--  Filing Institution party(30)  -->
		<fc2:Party SeqNum=".">
			<fc2:ActivityPartyTypeCode>30</fc2:ActivityPartyTypeCode>

			<fc2:PrimaryRegulatorTypeCode>
				<xsl:value-of select="../X_FILING_INST_PRIM_FED_REG_CD"/>
			</fc2:PrimaryRegulatorTypeCode>

			<fc2:PartyName SeqNum=".">
				<fc2:PartyNameTypeCode>L</fc2:PartyNameTypeCode>
				<fc2:RawPartyFullName>
					<xsl:value-of select="."/>
				</fc2:RawPartyFullName>
			</fc2:PartyName>

			<xsl:if test="../X_FILING_INST_ALTERNATE_NM">
				<fc2:PartyName SeqNum=".">
					<fc2:PartyNameTypeCode>DBA</fc2:PartyNameTypeCode>
					<fc2:RawPartyFullName>
						<xsl:value-of select="../X_FILING_INST_ALTERNATE_NM"/>
					</fc2:RawPartyFullName>
				</fc2:PartyName>
			</xsl:if>

			<fc2:Address SeqNum=".">

				<fc2:RawCityText>
					<xsl:value-of select="../X_FILING_INST_CITY_NM"/>
				</fc2:RawCityText>
				<fc2:RawCountryCodeText>
					<xsl:value-of select="../X_FILING_INST_COUNTRY_CD"/>
				</fc2:RawCountryCodeText>
				<fc2:RawStateCodeText>
					<xsl:value-of select="../X_FILING_INST_STATE_CD"/>
				</fc2:RawStateCodeText>
				<fc2:RawStreetAddress1Text>
					<xsl:value-of select="../X_FILING_INST_ADDRESS_TXT"/>
				</fc2:RawStreetAddress1Text>
				<fc2:RawZIPCode>
					<xsl:value-of select="../X_FILING_INST_POSTAL_CD"/>
				</fc2:RawZIPCode>				 
			</fc2:Address>
			<fc2:PartyIdentification SeqNum=".">				 
				<fc2:PartyIdentificationNumberText>
					<xsl:value-of select="../X_FILING_INST_TIN_NO"/>
				</fc2:PartyIdentificationNumberText>
				<fc2:PartyIdentificationTypeCode>
					<xsl:value-of select="../X_FILING_INST_TIN_TYPE_CD"/>
				</fc2:PartyIdentificationTypeCode>
			</fc2:PartyIdentification>


			<xsl:if test="X_FILING_INST_ID_NO != '' and X_FILING_INST_ID_TYPE_CD != ''">
				<fc2:PartyIdentification SeqNum=".">

					<fc2:PartyIdentificationNumberText>
						<xsl:value-of select="../X_FILING_INST_ID_NO"/>
					</fc2:PartyIdentificationNumberText>

					<fc2:PartyIdentificationTypeCode>
						<xsl:value-of select="../X_FILING_INST_ID_TYPE_CD"/>
					</fc2:PartyIdentificationTypeCode>
				</fc2:PartyIdentification>
			</xsl:if>

			<!-- for multiple organization subtypes  (Security Futures) -->
			<xsl:apply-templates select="../X_FILING_INST_SF_TYPE/checkbox_code"/>

			<!-- for single organization subtypes  -->
			<xsl:if test="../X_FILING_INST_TYPE_CD!='5' ">
				<fc2:OrganizationClassificationTypeSubtype SeqNum=".">					
					<fc2:OrganizationTypeID>
						<xsl:value-of select="../X_FILING_INST_TYPE_CD"/>
					</fc2:OrganizationTypeID>
					<xsl:apply-templates select="../X_FILING_INST_TYPE_OTH_TXT"/>					
				</fc2:OrganizationClassificationTypeSubtype>
			</xsl:if>
		</fc2:Party>
	</xsl:template>


	<!-- Designated contact office party(8) -->
	<xsl:template match="X_SAR_CONTACT_OFFICE">
		<fc2:Party SeqNum=".">
			<fc2:ActivityPartyTypeCode>8</fc2:ActivityPartyTypeCode>
			<fc2:PartyName SeqNum=".">
				<fc2:PartyNameTypeCode>L</fc2:PartyNameTypeCode>
				<fc2:RawPartyFullName>
					<xsl:value-of select="."/>
				</fc2:RawPartyFullName>
			</fc2:PartyName>

			<fc2:PhoneNumber SeqNum=".">
				<xsl:apply-templates select="../X_SAR_CONTACT_PHONE_EXT_NO"/>
				<xsl:apply-templates select="../X_SAR_CONTACT_PHONE_NO"/>				
			</fc2:PhoneNumber>

		</fc2:Party>
	</xsl:template>



	<!-- Law enforcement agency party 18  -->
	<xsl:template match="X_SAR_LE_CONTACT_AGENCY_NM">
		<fc2:Party SeqNum=".">
			<fc2:ActivityPartyTypeCode>18</fc2:ActivityPartyTypeCode> 

			<fc2:PartyName SeqNum=".">
				<fc2:PartyNameTypeCode>L</fc2:PartyNameTypeCode>				 
				<fc2:RawPartyFullName>
					<xsl:value-of select="."/>
				</fc2:RawPartyFullName>
			</fc2:PartyName>           
		</fc2:Party>
	</xsl:template>

	<!-- Law enforcement name party 19 -->
	<xsl:template match="X_SAR_LE_CONTACT_NM">
		<fc2:Party SeqNum=".">
			<fc2:ActivityPartyTypeCode>19</fc2:ActivityPartyTypeCode>

			<xsl:apply-templates select="../X_SAR_LE_CONTACTED_DT"/>   

			<fc2:PartyName SeqNum=".">
				<fc2:PartyNameTypeCode>L</fc2:PartyNameTypeCode>
				<fc2:RawPartyFullName>
					<xsl:value-of select="."/>
				</fc2:RawPartyFullName>                
			</fc2:PartyName>


			<xsl:if test="../X_SAR_LE_CONTACT_PHONE_NO">
				<fc2:PhoneNumber SeqNum=".">
					<fc2:PhoneNumberExtensionText>
						<xsl:value-of select="../X_SAR_LE_PHONE_EXT_NO"/>
					</fc2:PhoneNumberExtensionText>				
					<fc2:PhoneNumberText>
						<xsl:value-of select="../X_SAR_LE_CONTACT_PHONE_NO"/>
					</fc2:PhoneNumberText>
				</fc2:PhoneNumber>
			</xsl:if>



		</fc2:Party>
	</xsl:template>




	<!-- Financial Institution Where Activity Occurred party(34) 
	 -->

	<xsl:template match="institution">

		<fc2:Party SeqNum=".">
			<fc2:ActivityPartyTypeCode>34</fc2:ActivityPartyTypeCode>
			<xsl:apply-templates select="X_INSTITUTION"/>
			<!-- for multiple organization subtypes  (Security Futures) -->
			<xsl:apply-templates select="X_INST_SF_TYPE"/>

			<xsl:if test="X_BRANCH">
				<fc2:PartyAssociation SeqNum=".">
					<xsl:apply-templates select="X_BRANCH"/>
				</fc2:PartyAssociation>
			</xsl:if>
		</fc2:Party>

	</xsl:template>


	<!-- Financial Institution Where Activity Occurred institution portion 
	 -->
	<xsl:template match="X_INSTITUTION">
		<xsl:apply-templates select="X_INST_LOSS_AMT"/>

		<xsl:apply-templates select="X_NO_BRANCH_FLG"/>


		<xsl:if test="X_INST_ROLE_CD_B">
			<fc2:PayLocationIndicator>Y</fc2:PayLocationIndicator>
		</xsl:if>

		<xsl:apply-templates select="X_INST_PRIM_FED_REG_CD"/>

		<xsl:if test="X_INST_ROLE_CD_A">
			<fc2:SellingLocationIndicator>Y</fc2:SellingLocationIndicator>
		</xsl:if>

		<xsl:if test="X_INST_ROLE_CD_C">
			<fc2:SellingPayingLocationIndicator>Y</fc2:SellingPayingLocationIndicator>
		</xsl:if>

		<fc2:PartyName SeqNum=".">
			<xsl:apply-templates select="X_INST_LEGAL_NM_UNKNOWN_FLG"/>
			<fc2:PartyNameTypeCode>L</fc2:PartyNameTypeCode> 
			<xsl:apply-templates select="X_INST_LEGAL_NM"/>
		</fc2:PartyName>

		<xsl:if test="X_INST_ALT_NM">
			<fc2:PartyName SeqNum=".">
				<fc2:PartyNameTypeCode>DBA</fc2:PartyNameTypeCode>
				<xsl:apply-templates select="X_INST_ALT_NM"/>
			</fc2:PartyName>
		</xsl:if>

		<fc2:Address SeqNum=".">

			<xsl:apply-templates select="X_INST_CITY_UNKNOWN_FLG"/>
			<xsl:apply-templates select="X_INST_COUNTRY_UNKNOWN_FLG"/>
			<xsl:apply-templates select="X_INST_CITY_NM"/>
			<xsl:apply-templates select="X_INST_COUNTRY_CD"/>
			<xsl:apply-templates select="X_INST_STATE_CD"/>
			<xsl:apply-templates select="X_INST_ADDRESS_TXT"/>
			<xsl:apply-templates select="X_INST_POSTAL_CD"/>
			<xsl:apply-templates select="X_INST_ADDRESS_UNKNOWN_FLG"/>				 
			<xsl:apply-templates select="X_INST_POSTAL_UNKNOWN_FLG"/>
		</fc2:Address>

		<fc2:PartyIdentification SeqNum=".">		
			<xsl:apply-templates select="X_INST_TIN_NO"/>
			<xsl:apply-templates select="X_INST_TIN_TYPE_CD"/>
			<xsl:apply-templates select="X_INST_TIN_UNKNOWN_FLG"/>
		</fc2:PartyIdentification>

		<xsl:if test="X_INST_ID_TYPE_CD != '' and X_INST_ID_NO != ''">
			<fc2:PartyIdentification SeqNum=".">
				<xsl:apply-templates select="X_INST_ID"/>
				<xsl:apply-templates select="X_INST_ID_TYPE_CD"/>
			</fc2:PartyIdentification>
		</xsl:if>



		<!-- for single organization subtypes  -->
		<xsl:if test="X_INST_TYPE_CD!='5' ">
			<fc2:OrganizationClassificationTypeSubtype SeqNum=".">

				<xsl:if test="X_INST_TYPE_CD='1' ">		 		    
					<fc2:OrganizationSubtypeID>
						<xsl:value-of select="X_INST_GAMING_TYPE_CD"/>
					</fc2:OrganizationSubtypeID>
					<fc2:OrganizationTypeID>1</fc2:OrganizationTypeID>
					<xsl:apply-templates select="X_INST_GAMING_TYPE_OTH"/>
				</xsl:if>					

				<xsl:if test="X_INST_TYPE_CD !='1'">
					<fc2:OrganizationTypeID>
						<xsl:value-of select="X_INST_TYPE_CD"/>
					</fc2:OrganizationTypeID>
					<xsl:apply-templates select="X_INST_TYPE_OTH_TXT"/>
				</xsl:if>
			</fc2:OrganizationClassificationTypeSubtype>
		</xsl:if>
	</xsl:template>

	<!-- Branch Where Activity Occurred Party 46 -->
	<xsl:template match="X_BRANCH">

		<fc2:Party SeqNum=".">
			<fc2:ActivityPartyTypeCode>46</fc2:ActivityPartyTypeCode>


			<xsl:if test="X_BRANCH_ROLE_CD_B">
				<fc2:PayLocationIndicator>Y</fc2:PayLocationIndicator>
			</xsl:if>

			<xsl:if test="X_BRANCH_ROLE_CD_A">
				<fc2:SellingLocationIndicator>Y</fc2:SellingLocationIndicator>
			</xsl:if>

			<xsl:if test="X_BRANCH_ROLE_CD_C">
				<fc2:SellingPayingLocationIndicator>Y</fc2:SellingPayingLocationIndicator>
			</xsl:if> 

			<fc2:Address SeqNum=".">

				<xsl:apply-templates select="X_BRANCH_CITY_NM"/>
				<xsl:apply-templates select="X_BRANCH_COUNTRY_CD"/>
				<xsl:apply-templates select="X_BRANCH_STATE_CD"/>
				<xsl:apply-templates select="X_BRANCH_ADDRESS_TXT"/>
				<xsl:apply-templates select="X_BRANCH_POSTAL_CD"/>

			</fc2:Address>

			<xsl:apply-templates select="X_BRANCH_RSSD_ID"/> 

		</fc2:Party>

	</xsl:template>


	<xsl:template match="subject">
		<fc2:Party SeqNum=".">

			<fc2:ActivityPartyTypeCode>33</fc2:ActivityPartyTypeCode>

			<xsl:if test="not(X_SUBJECT/X_CORROBORATIVE_STMT_FLG)">
				<fc2:AdmissionConfessionNoIndicator>Y</fc2:AdmissionConfessionNoIndicator>
			</xsl:if>
			<xsl:if test="X_SUBJECT/X_CORROBORATIVE_STMT_FLG">
				<fc2:AdmissionConfessionYesIndicator>Y</fc2:AdmissionConfessionYesIndicator>
			</xsl:if> 			
			<xsl:if test="X_SUBJECT/X_ALL_CRITICAL_UNAVAILABLE_FLG">
				<fc2:AllCriticalSubjectInformationUnavailableIndicator>Y</fc2:AllCriticalSubjectInformationUnavailableIndicator>
			</xsl:if> 			 
			<xsl:if test="X_SUBJECT/X_BIRTHDAY_UNKNOWN_FLG and not((X_SUBJECT/X_ENTITY_FLG='1') or (X_SUBJECT/X_ALL_CRITICAL_UNAVAILABLE_FLG='1')) ">
				<fc2:BirthDateUnknownIndicator>Y</fc2:BirthDateUnknownIndicator>
			</xsl:if> 
			<xsl:if test="X_SUBJECT/X_SAR_ROLE_CD_C">
				<fc2:BothPurchaserSenderPayeeReceiveIndicator>Y</fc2:BothPurchaserSenderPayeeReceiveIndicator>
			</xsl:if>	
			<xsl:if test="X_SUBJECT/X_GENDER_CD_B and not((X_SUBJECT/X_ENTITY_FLG='1') or (X_SUBJECT/X_ALL_CRITICAL_UNAVAILABLE_FLG='1'))">
				<fc2:FemaleGenderIndicator>Y</fc2:FemaleGenderIndicator>
			</xsl:if>
			<xsl:if test="X_SUBJECT/X_BIRTHDAY_TXT and not((X_SUBJECT/X_ENTITY_FLG='1') or (X_SUBJECT/X_ALL_CRITICAL_UNAVAILABLE_FLG='1'))">
				<fc2:IndividualBirthDateText>
					<xsl:value-of select="X_SUBJECT/X_BIRTHDAY_TXT"/>
				</fc2:IndividualBirthDateText>				
			</xsl:if>		 
			<xsl:if test="X_SUBJECT/X_GENDER_CD_A and not((X_SUBJECT/X_ENTITY_FLG='1') or (X_SUBJECT/X_ALL_CRITICAL_UNAVAILABLE_FLG='1'))">
				<fc2:MaleGenderIndicator>Y</fc2:MaleGenderIndicator>
			</xsl:if>
			<xsl:if test="X_SUBJECT/X_NO_ACCT_FLG">
				<fc2:NoKnownAccountInvolvedIndicator>Y</fc2:NoKnownAccountInvolvedIndicator>
			</xsl:if>
			<xsl:if test="X_SUBJECT/X_ENTITY_FLG='1'">
				<fc2:PartyAsEntityOrganizationIndicator>Y</fc2:PartyAsEntityOrganizationIndicator>
			</xsl:if>
			<xsl:if test="X_SUBJECT/X_SAR_ROLE_CD_B">
				<fc2:PayeeReceiverIndicator>Y</fc2:PayeeReceiverIndicator>
			</xsl:if>
			<xsl:if test="X_SUBJECT/X_SAR_ROLE_CD_A">
				<fc2:PurchaserSenderIndicator>Y</fc2:PurchaserSenderIndicator>
			</xsl:if>
			<xsl:if test="X_SUBJECT/X_GENDER_CD_C and not((X_SUBJECT/X_ENTITY_FLG='1') or (X_SUBJECT/X_ALL_CRITICAL_UNAVAILABLE_FLG='1'))">
				<fc2:UnknownGenderIndicator>Y</fc2:UnknownGenderIndicator>
			</xsl:if>

			<xsl:if test="not(X_SUBJECT/X_ALL_CRITICAL_UNAVAILABLE_FLG)">
				<fc2:PartyName SeqNum=".">
					<xsl:apply-templates select="X_SUBJECT/X_LAST_NM_UNKNOWN_FLG"/>

					<xsl:if test="not(X_SUBJECT/X_ENTITY_FLG='1')">
						<xsl:apply-templates select="X_SUBJECT/X_FIRST_NM_UNKNOWN_FLG"/>
					</xsl:if>

					<fc2:PartyNameTypeCode>L</fc2:PartyNameTypeCode>
					<xsl:apply-templates select="X_SUBJECT/X_LAST_NM"/>
					<xsl:if test="not(X_SUBJECT/X_ENTITY_FLG='1')">
						<xsl:apply-templates select="X_SUBJECT/X_FIRST_NM"/>
						<xsl:apply-templates select="X_SUBJECT/X_MIDDLE_NM"/>
						<xsl:apply-templates select="X_SUBJECT/X_NM_SUFFIX"/>
					</xsl:if>
				</fc2:PartyName>
			</xsl:if>

			<xsl:apply-templates select="X_SUBJECT_ALTERNATE_NM"/>  
			<xsl:if test="not(X_SUBJECT/X_ALL_CRITICAL_UNAVAILABLE_FLG)">			
				<xsl:apply-templates select="X_SUBJECT_ADDRESS"/>
			</xsl:if>
			<xsl:apply-templates select="X_SUBJECT_TELEPHONE_NO"/> 
			<xsl:if test="not(X_SUBJECT/X_ALL_CRITICAL_UNAVAILABLE_FLG)">

				<xsl:apply-templates select="X_SUBJECT_ID"/> 
			</xsl:if>  			
			<xsl:if test="not(X_SUBJECT/X_ALL_CRITICAL_UNAVAILABLE_FLG)">	
				<fc2:PartyIdentification SeqNum=".">
					<xsl:apply-templates select="X_SUBJECT/X_TIN_NO"/>
					<xsl:apply-templates select="X_SUBJECT/X_TIN_TYPE_CD"/>
					<xsl:apply-templates select="X_SUBJECT/X_TIN_UKNOWN_FLG"/>
				</fc2:PartyIdentification>
			</xsl:if> 


			<fc2:PartyOccupationBusiness SeqNum=".">
				<fc2:NAICSCode>
					<xsl:value-of select="X_SUBJECT/X_NAICS_CD"/>
				</fc2:NAICSCode>
				<fc2:OccupationBusinessText>
					<xsl:value-of select="X_SUBJECT/X_OCCUPATION_TXT"/>
				</fc2:OccupationBusinessText>
			</fc2:PartyOccupationBusiness>

			<xsl:apply-templates select="X_SUBJECT_EMAIL_ADDRESS"/> 

			<xsl:apply-templates select="X_SUBJECT_URL_ADDRESS"/> 

			<xsl:apply-templates select="subjectInstitution/X_SUBJECT_RELATION_INST"/>	

			<xsl:if test="subjectInstitution/X_SUBJECT_ACCT_INST">	
				<fc2:PartyAccountAssociation SeqNum=".">
					<fc2:PartyAccountAssociationTypeCode>7</fc2:PartyAccountAssociationTypeCode>				
					<xsl:apply-templates select="subjectInstitution/X_SUBJECT_ACCT_INST"/>
				</fc2:PartyAccountAssociation>	
			</xsl:if>			

		</fc2:Party>

	</xsl:template>  

	<!-- subject sub level templates -->

	<xsl:template match="X_SUBJECT_TELEPHONE_NO">
		<fc2:PhoneNumber SeqNum=".">
			<fc2:PhoneNumberExtensionText>
				<xsl:value-of select="X_PHONE_EXT_NO"/>
			</fc2:PhoneNumberExtensionText>
			<fc2:PhoneNumberText>
				<xsl:value-of select="X_PHONE_NO"/>
			</fc2:PhoneNumberText>
			<fc2:PhoneNumberTypeCode>
				<xsl:value-of select="X_PHONE_TYPE_CD"/>
			</fc2:PhoneNumberTypeCode>

		</fc2:PhoneNumber>
	</xsl:template>

	<xsl:template match="X_SUBJECT_ADDRESS">
		<fc2:Address SeqNum=".">
			<xsl:apply-templates select="X_CITY_NM_UNKNOWN_FLG"/>
			<xsl:apply-templates select="X_COUNTRY_UNKNOWN_FLG"/>
			<xsl:apply-templates select="X_CITY_NM"/>
			<xsl:apply-templates select="X_COUNTRY_CD"/>
			<xsl:apply-templates select="X_STATE_CD"/>
			<xsl:apply-templates select="X_ADDRESS_TXT"/>
			<xsl:apply-templates select="X_POSTAL_CD"/>						
			<xsl:apply-templates select="X_STATE_UNKNOWN_FLG"/>
			<xsl:apply-templates select="X_ADDRESS_UNKNOWN_FLG"/>
			<xsl:apply-templates select="X_POSTAL_UNKNOWN_FLG"/>
		</fc2:Address>
	</xsl:template>

	<xsl:template match="X_SUBJECT_ALTERNATE_NM">
		<fc2:PartyName SeqNum=".">
			<fc2:PartyNameTypeCode>AKA</fc2:PartyNameTypeCode>
			<fc2:RawPartyFullName>
				<xsl:value-of select="X_ALTERNATE_NM"/>
			</fc2:RawPartyFullName>
		</fc2:PartyName>
	</xsl:template>

	<xsl:template match="X_SUBJECT_ID">
		<fc2:PartyIdentification SeqNum=".">


			<fc2:OtherIssuerCountryText>
				<xsl:value-of select="X_ID_AUTHORITY_COUNTRY_CD"/>
			</fc2:OtherIssuerCountryText>
			<fc2:OtherIssuerStateText>
				<xsl:value-of select="X_ID_AUTHORITY_STATE_CD"/>
			</fc2:OtherIssuerStateText>	
			<fc2:OtherPartyIdentificationTypeText>
				<xsl:value-of select="X_SUBJECT_ID_TYPE_OTH_TXT"/>
			</fc2:OtherPartyIdentificationTypeText>

			<fc2:PartyIdentificationNumberText>
				<xsl:value-of select="X_ID_NO"/>
			</fc2:PartyIdentificationNumberText>	 

			<fc2:PartyIdentificationTypeCode>
				<xsl:value-of select="X_SUBJECT_ID_TYPE_CD"/>
			</fc2:PartyIdentificationTypeCode>

		</fc2:PartyIdentification>

	</xsl:template>
	<xsl:template match="X_SUBJECT_EMAIL_ADDRESS">
		<fc2:ElectronicAddress SeqNum=".">
			<fc2:ElectronicAddressText>
				<xsl:value-of select="X_EMAIL_ADDRESS_TXT"/>
			</fc2:ElectronicAddressText>
			<fc2:ElectronicAddressTypeCode>E</fc2:ElectronicAddressTypeCode>
		</fc2:ElectronicAddress>
	</xsl:template> 

	<xsl:template match="X_SUBJECT_URL_ADDRESS">
		<fc2:ElectronicAddress SeqNum=".">
			<fc2:ElectronicAddressText>
				<xsl:value-of select="X_URL_ADDRESS_TXT"/>
			</fc2:ElectronicAddressText>
			<fc2:ElectronicAddressTypeCode>U</fc2:ElectronicAddressTypeCode>
		</fc2:ElectronicAddress>
	</xsl:template>


	<xsl:template match="subjectInstitution/X_SUBJECT_RELATION_INST">

		<fc2:PartyAssociation SeqNum=".">
			<xsl:if test="X_SUBJECT_RELATION_CD_B='1'">	
				<fc2:AccountantIndicator>Y</fc2:AccountantIndicator>
			</xsl:if>
			<xsl:if test="X_SUBJECT_RELATION_STATUS_DT">	
				<fc2:ActionTakenDateText>
					<xsl:value-of select="X_SUBJECT_RELATION_STATUS_DT"/>
				</fc2:ActionTakenDateText>
			</xsl:if>
			<xsl:if test="X_SUBJECT_RELATION_CD_C='1'">	
				<fc2:AgentIndicator>Y</fc2:AgentIndicator>
			</xsl:if>			
			<xsl:if test="X_SUBJECT_RELATION_CD_D='1'">	
				<fc2:AppraiserIndicator>Y</fc2:AppraiserIndicator>
			</xsl:if>
			<xsl:if test="X_SUBJECT_RELATION_CD_E='1'">	
				<fc2:AttorneyIndicator>Y</fc2:AttorneyIndicator>
			</xsl:if>
			<xsl:if test="X_SUBJECT_RELATION_CD_F='1'">	
				<fc2:BorrowerIndicator>Y</fc2:BorrowerIndicator>
			</xsl:if>
			<xsl:if test="X_SUBJECT_RELATION_CD_G='1'">	
				<fc2:CustomerIndicator>Y</fc2:CustomerIndicator>
			</xsl:if>
			<xsl:if test="X_SUBJECT_RELATION_CD_H='1'">	
				<fc2:DirectorIndicator>Y</fc2:DirectorIndicator>
			</xsl:if>
			<xsl:if test="X_SUBJECT_RELATION_CD_I='1'">	
				<fc2:EmployeeIndicator>Y</fc2:EmployeeIndicator>
			</xsl:if>
			<xsl:if test="X_SUBJECT_RELATION_CD_J='1'">	
				<fc2:NoRelationshipToInstitutionIndicator>Y</fc2:NoRelationshipToInstitutionIndicator>
			</xsl:if>
			<xsl:if test="X_SUBJECT_RELATION_CD_K='1'">	
				<fc2:OfficerIndicator>Y</fc2:OfficerIndicator>
			</xsl:if>
			<xsl:if test="X_SUBJECT_RELATION_CD_Z_TXT">	
				<fc2:OtherPartyAssociationTypeText>
					<xsl:value-of select="X_SUBJECT_RELATION_CD_Z_TXT"/>
				</fc2:OtherPartyAssociationTypeText>
			</xsl:if>
			<xsl:if test="X_SUBJECT_RELATION_CD_Z='1'">	
				<fc2:OtherRelationshipIndicator>Y</fc2:OtherRelationshipIndicator>
			</xsl:if>
			<xsl:if test="X_SUBJECT_RELATION_CD_L='1'">	
				<fc2:OwnerShareholderIndicator>Y</fc2:OwnerShareholderIndicator>
			</xsl:if>
			<xsl:if test="X_SUBJECT_RELATION_STATUS_CD_A">	
				<fc2:RelationshipContinuesIndicator>Y</fc2:RelationshipContinuesIndicator>
			</xsl:if>
			<xsl:if test="X_SUBJECT_RELATION_STATUS_CD_D">	
				<fc2:ResignedIndicator>Y</fc2:ResignedIndicator>
			</xsl:if>
			<xsl:if test="X_SUBJECT_RELATION_TIN_NO">	
				<fc2:SubjectRelationshipFinancialInstitutionTINText>
					<xsl:value-of select="X_SUBJECT_RELATION_TIN_NO"/>
				</fc2:SubjectRelationshipFinancialInstitutionTINText>
			</xsl:if>
			<xsl:if test="X_SUBJECT_RELATION_STATUS_CD_C">	
				<fc2:SuspendedBarredIndicator>Y</fc2:SuspendedBarredIndicator>
			</xsl:if>
			<xsl:if test="X_SUBJECT_RELATION_STATUS_CD_B">	
				<fc2:TerminatedIndicator>Y</fc2:TerminatedIndicator>
			</xsl:if>
		</fc2:PartyAssociation>
	</xsl:template> 



	<!-- Financial Institution Where Account is Held Party 41 -->
	<xsl:template match="subjectInstitution/X_SUBJECT_ACCT_INST">

		<fc2:Party SeqNum=".">
			<fc2:ActivityPartyTypeCode>41</fc2:ActivityPartyTypeCode>
			<xsl:if test="X_ACCT_INST_NON_US_FLG">	
				<fc2:NonUSFinancialInstitutionIndicator>Y</fc2:NonUSFinancialInstitutionIndicator>
			</xsl:if>
			<xsl:if test="X_ACCT_INST_ID">	
				<fc2:PartyIdentification SeqNum=".">
					<fc2:PartyIdentificationNumberText>
						<xsl:value-of select="X_ACCT_INST_ID"/>
					</fc2:PartyIdentificationNumberText>
					<fc2:PartyIdentificationTypeCode>4</fc2:PartyIdentificationTypeCode>
				</fc2:PartyIdentification>
			</xsl:if>
			<xsl:for-each select="../X_SUBJECT_INST_ACCT">
				<fc2:Account SeqNum=".">
					<fc2:AccountNumberText>
						<xsl:value-of select="X_ACCT_ID"/>
					</fc2:AccountNumberText>
					<fc2:PartyAccountAssociation SeqNum=".">
						<xsl:if test="X_ACCT_CLOSED_FLG">	
							<fc2:AccountClosedIndicator>Y</fc2:AccountClosedIndicator>
						</xsl:if>
						<fc2:PartyAccountAssociationTypeCode>5</fc2:PartyAccountAssociationTypeCode>
					</fc2:PartyAccountAssociation>
				</fc2:Account>
			</xsl:for-each>				

		</fc2:Party>

	</xsl:template> 



	<xsl:template match="X_FILING_INST_SF_TYPE/checkbox_code">
		<xsl:variable name="typeValue">
			<xsl:value-of select = "."/>
		</xsl:variable>
		<fc2:OrganizationClassificationTypeSubtype SeqNum=".">
			<fc2:OrganizationSubtypeID>
				<xsl:value-of select="."/>
			</fc2:OrganizationSubtypeID>

			<fc2:OrganizationTypeID>5</fc2:OrganizationTypeID>		

			<xsl:if test="substring($typeValue, string-length($typeValue) - 2)='999'">
				<fc2:OtherOrganizationSubTypeText>
					<xsl:value-of select="../../X_FILING_INST_SF_TYPE_OTH_TXT"/>
				</fc2:OtherOrganizationSubTypeText>
			</xsl:if>
		</fc2:OrganizationClassificationTypeSubtype>
	</xsl:template>

	<xsl:template match="X_FILING_INST_TYPE_OTH_TXT">
		<fc2:OtherOrganizationTypeText>
			<xsl:value-of select="."/>
		</fc2:OtherOrganizationTypeText>
	</xsl:template>


	<xsl:template match="X_FILING_INST_GAMING_TYPE_OTH">
		<fc2:OtherOrganizationSubTypeText>
			<xsl:value-of select="."/>
		</fc2:OtherOrganizationSubTypeText>
	</xsl:template>

	<xsl:template match="X_INST_PRIM_FED_REG_CD">
		<fc2:PrimaryRegulatorTypeCode>
			<xsl:value-of select="."/>
		</fc2:PrimaryRegulatorTypeCode>
	</xsl:template>
	<xsl:template match="X_INST_LEGAL_NM">
		<fc2:RawPartyFullName>
			<xsl:value-of select="."/>
		</fc2:RawPartyFullName>
	</xsl:template>
	<xsl:template match="X_INST_LEGAL_NM_UNKNOWN_FLG">
		<fc2:EntityLastNameUnknownIndicator>Y</fc2:EntityLastNameUnknownIndicator>
	</xsl:template>
	<xsl:template match="X_INST_ALT_NM">
		<fc2:RawPartyFullName>
			<xsl:value-of select="."/>
		</fc2:RawPartyFullName>
	</xsl:template>
	<xsl:template match="X_INST_TIN_NO">
		<fc2:PartyIdentificationNumberText>
			<xsl:value-of select="."/>
		</fc2:PartyIdentificationNumberText>				 		
	</xsl:template>
	<xsl:template match="X_INST_TIN_TYPE_CD">
		<fc2:PartyIdentificationTypeCode>
			<xsl:value-of select="."/>
		</fc2:PartyIdentificationTypeCode>			
	</xsl:template>
	<xsl:template match="X_INST_TIN_UNKNOWN_FLG">
		<fc2:TINUnknownIndicator>Y</fc2:TINUnknownIndicator>
	</xsl:template>
	<xsl:template match="X_INST_ADDRESS_TXT">
		<fc2:RawStreetAddress1Text>
			<xsl:value-of select="."/>
		</fc2:RawStreetAddress1Text>
	</xsl:template>
	<xsl:template match="X_INST_CITY_NM">
		<fc2:RawCityText>
			<xsl:value-of select="."/>
		</fc2:RawCityText>
	</xsl:template>
	<xsl:template match="X_INST_STATE_CD">
		<fc2:RawStateCodeText>
			<xsl:value-of select="."/>
		</fc2:RawStateCodeText>
	</xsl:template>
	<xsl:template match="X_INST_POSTAL_CD">
		<fc2:RawZIPCode>
			<xsl:value-of select="."/>
		</fc2:RawZIPCode>
	</xsl:template>
	<xsl:template match="X_INST_COUNTRY_CD">
		<fc2:RawCountryCodeText>
			<xsl:value-of select="."/>
		</fc2:RawCountryCodeText>
	</xsl:template>
	<xsl:template match="X_INST_ADDRESS_UNKNOWN_FLG">
		<fc2:StreetAddressUnknownIndicator>Y</fc2:StreetAddressUnknownIndicator>
	</xsl:template>
	<xsl:template match="X_INST_CITY_UNKNOWN_FLG">
		<fc2:CityUnknownIndicator>Y</fc2:CityUnknownIndicator>
	</xsl:template>	 
	<xsl:template match="X_INST_POSTAL_UNKNOWN_FLG">
		<fc2:ZIPCodeUnknownIndicator>Y</fc2:ZIPCodeUnknownIndicator>
	</xsl:template>
	<xsl:template match="X_INST_COUNTRY_UNKNOWN_FLG">
		<fc2:CountryCodeUnknownIndicator>Y</fc2:CountryCodeUnknownIndicator>
	</xsl:template>
	<xsl:template match="X_INST_TYPE_SAR_CD">
		<fc2:OrganizationTypeID>
			<xsl:value-of select="."/>
		</fc2:OrganizationTypeID>
	</xsl:template>
	<xsl:template match="X_INST_TYPE_OTH_TXT">
		<fc2:OtherOrganizationTypeText>
			<xsl:value-of select="."/>
		</fc2:OtherOrganizationTypeText>
	</xsl:template>
	<xsl:template match="X_INST_GAMING_TYPE_CD">
		<fc2:OrganizationSubtypeID>
			<xsl:value-of select="."/>
		</fc2:OrganizationSubtypeID>
	</xsl:template>
	<xsl:template match="X_INST_GAMING_TYPE_OTH_TXT">
		<fc2:OtherOrganizationSubTypeText>
			<xsl:value-of select="."/>
		</fc2:OtherOrganizationSubTypeText>
	</xsl:template>
	<xsl:template match="X_INST_ID_TYPE_CD">
		<fc2:PartyIdentificationTypeCode>
			<xsl:value-of select="."/>
		</fc2:PartyIdentificationTypeCode>
	</xsl:template>
	<xsl:template match="X_INST_ID">
		<fc2:PartyIdentificationNumberText>
			<xsl:value-of select="."/>
		</fc2:PartyIdentificationNumberText>
	</xsl:template>

	<xsl:template match="X_INST_LOSS_AMT">
		<fc2:LossToFinancialAmountText>
			<xsl:value-of select="."/>
		</fc2:LossToFinancialAmountText>
	</xsl:template> 

	<xsl:template match="X_INST_SF_TYPE">	 
		<xsl:for-each select="checkbox_code">
			<xsl:variable name="typeValue">
				<xsl:value-of select = "."/>
			</xsl:variable>		
			<fc2:OrganizationClassificationTypeSubtype SeqNum=".">	
				<fc2:OrganizationSubtypeID>
					<xsl:value-of select="."/>
				</fc2:OrganizationSubtypeID>
				<fc2:OrganizationTypeID>5</fc2:OrganizationTypeID>		
				<xsl:if test="substring($typeValue, string-length($typeValue) - 2)='999'">
					<fc2:OtherOrganizationSubTypeText>
						<xsl:value-of select="../X_INST_SF_TYPE_OTH_TXT"/>
					</fc2:OtherOrganizationSubTypeText>
				</xsl:if>
			</fc2:OrganizationClassificationTypeSubtype>			
		</xsl:for-each>
	</xsl:template>

	<xsl:template match="X_NO_BRANCH_FLG">
		<fc2:NoBranchActivityInvolvedIndicator>Y</fc2:NoBranchActivityInvolvedIndicator>
	</xsl:template>

	<xsl:template match="X_BRANCH_ADDRESS_TXT">
		<fc2:RawStreetAddress1Text>
			<xsl:value-of select="."/>
		</fc2:RawStreetAddress1Text>
	</xsl:template>
	<xsl:template match="X_BRANCH_CITY_NM">
		<fc2:RawCityText>
			<xsl:value-of select="."/>
		</fc2:RawCityText>
	</xsl:template>
	<xsl:template match="X_BRANCH_STATE_CD">
		<fc2:RawStateCodeText>
			<xsl:value-of select="."/>
		</fc2:RawStateCodeText>
	</xsl:template>
	<xsl:template match="X_BRANCH_POSTAL_CD">
		<fc2:RawZIPCode>
			<xsl:value-of select="."/>
		</fc2:RawZIPCode>
	</xsl:template>
	<xsl:template match="X_BRANCH_COUNTRY_CD">
		<fc2:RawCountryCodeText>
			<xsl:value-of select="."/>
		</fc2:RawCountryCodeText>
	</xsl:template>

	<xsl:template match="X_BRANCH_RSSD_ID">
		<fc2:PartyIdentification SeqNum=".">
			<fc2:PartyIdentificationNumberText>
				<xsl:value-of select="."/>
			</fc2:PartyIdentificationNumberText>
			<fc2:PartyIdentificationTypeCode>14</fc2:PartyIdentificationTypeCode>
		</fc2:PartyIdentification>
	</xsl:template>


	<xsl:template match="X_PRIOR_AGENCY_REF_ID">
		<fc2:EFilingPriorDocumentNumber>
			<xsl:value-of select="."/>
		</fc2:EFilingPriorDocumentNumber>
	</xsl:template>
	<xsl:template match="X_SAR_BEGIN_DT">
		<fc2:TransactionDateText>
			<xsl:value-of select="."/>
		</fc2:TransactionDateText>
	</xsl:template> 
	<xsl:template match="X_SAR_CONTACT_PHONE_NO">
		<fc2:PhoneNumberText>
			<xsl:value-of select="."/>
		</fc2:PhoneNumberText>
	</xsl:template>
	<xsl:template match="X_SAR_CONTACT_PHONE_EXT_NO">
		<fc2:PhoneNumberExtensionText>
			<xsl:value-of select="."/>
		</fc2:PhoneNumberExtensionText>
	</xsl:template>	 

	<xsl:template match="X_SAR_LE_CONTACTED_DT">
		<fc2:ContactDateText> 
			<xsl:value-of select="."/>
		</fc2:ContactDateText>
	</xsl:template>

	<xsl:template match="X_LAST_NM">
		<fc2:RawEntityIndividualLastName>
			<xsl:value-of select="."/>
		</fc2:RawEntityIndividualLastName>
	</xsl:template>

	<xsl:template match="X_LAST_NM_UNKNOWN_FLG">
		<fc2:EntityLastNameUnknownIndicator>Y</fc2:EntityLastNameUnknownIndicator>
	</xsl:template>
	<xsl:template match="X_FIRST_NM">
		<fc2:RawIndividualFirstName>
			<xsl:value-of select="."/>
		</fc2:RawIndividualFirstName>
	</xsl:template>
	<xsl:template match="X_FIRST_NM_UNKNOWN_FLG">
		<fc2:FirstNameUnknownIndicator>Y</fc2:FirstNameUnknownIndicator>
	</xsl:template>
	<xsl:template match="X_MIDDLE_NM">
		<fc2:RawIndividualMiddleName>
			<xsl:value-of select="."/>
		</fc2:RawIndividualMiddleName>
	</xsl:template>
	<xsl:template match="X_NM_SUFFIX">
		<fc2:RawIndividualNameSuffixText>
			<xsl:value-of select="."/>
		</fc2:RawIndividualNameSuffixText>
	</xsl:template>	 
	<xsl:template match="X_ADDRESS_TXT">
		<fc2:RawStreetAddress1Text>
			<xsl:value-of select="."/>
		</fc2:RawStreetAddress1Text>
	</xsl:template>
	<xsl:template match="X_ADDRESS_UNKNOWN_FLG">
		<fc2:StreetAddressUnknownIndicator>Y</fc2:StreetAddressUnknownIndicator>
	</xsl:template>
	<xsl:template match="X_CITY_NM">
		<fc2:RawCityText>
			<xsl:value-of select="."/>
		</fc2:RawCityText>
	</xsl:template>
	<xsl:template match="X_CITY_NM_UNKNOWN_FLG">
		<fc2:CityUnknownIndicator>Y</fc2:CityUnknownIndicator>
	</xsl:template>
	<xsl:template match="X_STATE_CD">
		<fc2:RawStateCodeText>
			<xsl:value-of select="."/>
		</fc2:RawStateCodeText>
	</xsl:template>
	<xsl:template match="X_STATE_UNKNOWN_FLG">
		<fc2:StateCodeUnknownIndicator>Y</fc2:StateCodeUnknownIndicator>
	</xsl:template>
	<xsl:template match="X_POSTAL_CD">
		<fc2:RawZIPCode>
			<xsl:value-of select="."/>
		</fc2:RawZIPCode>
	</xsl:template>
	<xsl:template match="X_POSTAL_UNKNOWN_FLG">
		<fc2:ZIPCodeUnknownIndicator>Y</fc2:ZIPCodeUnknownIndicator>
	</xsl:template>
	<xsl:template match="X_COUNTRY_CD">
		<fc2:RawCountryCodeText>
			<xsl:value-of select="."/>
		</fc2:RawCountryCodeText>
	</xsl:template>
	<xsl:template match="X_COUNTRY_UNKNOWN_FLG">
		<fc2:CountryCodeUnknownIndicator>Y</fc2:CountryCodeUnknownIndicator>
	</xsl:template>
	<xsl:template match="X_TIN_NO">
		<fc2:PartyIdentificationNumberText>
			<xsl:value-of select="."/>
		</fc2:PartyIdentificationNumberText>
	</xsl:template>
	<xsl:template match="X_TIN_UNKNOWN_FLG">
		<fc2:TINUnknownIndicator>Y</fc2:TINUnknownIndicator>
	</xsl:template>
	<xsl:template match="X_TIN_TYPE_CD">
		<fc2:PartyIdentificationTypeCode>
			<xsl:value-of select="."/>
		</fc2:PartyIdentificationTypeCode>
	</xsl:template>







</xsl:stylesheet>
