
/***********************************************************************************/
/* Copyright (c) 2017, SAS Institute Inc., Cary, NC, USA, All Rights Reserved      */
/*                                                                                 */
/* NAME:          ecmrr_efile_fincen_ctrx_detail                                   */
/* PRODUCT:       Enterprise Case Management                                       */
/* PURPOSE:       Extract and transform the udf values of the reports in the efile.*/
/* PARAMETERS:                                                                     */
/*                rr_subset_dsn: name of the table containing the list of reports  */
/*                        to be processed.                                         */
/*                outdsn: output data set name                                     */
/***********************************************************************************/

%macro ecmrr_efile_fincen_ctrx_detail(rr_subset_dsn=, 
                                      outdsn=rr_udf
                                      );
                                          
%put %sysfunc(sasmsg(&smdds,GEN_MAC_START_NOTE,NOQUOTE,&sysmacroname)) ;


%let sucessYN=Y;

  /***********************************************/
  /* Create SAS formats for code conversion      */ 
  /***********************************************/

   proc format cntlin=ecm_form.ctrx_code_mapping (rename=(format_nm=fmtname
                                                          format_type=type
                                                          input_cd=start
													      output_cd=label)
											       where=(label ne '')
													  
                                                  );
   run;

   %if &syserr > 4 %then 
   %do;
          %let successYN=N;
          %put %sysfunc(sasmsg(&smdds,GEN_STP_ABORT,NOQUOTE,&sysmacroname)) ;
          %goto mExit;
   %end;
    
  
   %let format_list=;

   proc sql noprint;
        select distinct quote(strip(format_nm)) into :format_list separated by ' '
	    from ecm_form.ctrx_code_mapping
	    where output_cd ne ''
	 ;
    quit;

	%if &sqlrc > 4 %then 
    %do;
          %let successYN=N;
          %put %sysfunc(sasmsg(&smdds,GEN_STP_ABORT,NOQUOTE,&sysmacroname)) ;
          %goto mExit;
    %end;
    

    %if &ecm_debug=Y %then %put &format_list;


/***********************************************/
/* Get RR records                              */
/* and write udf nams and values into xml      */
/***********************************************/

    
   /* List the udf tables that are relavent to CTRX */
   %let table_wh="X_FOREIGN_CASH_IN" "X_FOREIGN_CASH_OUT" "X_INSTITUTION" 
                 "RR" "X_ACCOUNT_CASH_IN" "X_ACCOUNT_CASH_OUT" "X_PERSON_INVOLVED" 
                 "X_TRAN_METHOD"
   ;

    

 %macro ecm_ext_std_udf_value(udf_table_nm=); 

 %put %sysfunc(sasmsg(&smdds,GEN_MAC_START_NOTE,NOQUOTE,&sysmacroname)) ;

/* extract and standardize the udf values */ 
    proc sql;
   	 	create table &udf_table_nm as
    	select a.rr_rk, a.udf_table_nm, a.row_no, a.udf_nm,
	%if  %scan(%upcase(&udf_table_nm),3,_)=CHAR %then
	%do;
	     udf_value as udf_value_str
	%end;
	%if  %scan(%upcase(&udf_table_nm),3,_)=NUM %then
	%do;
	     strip(put(udf_value,best.)) as udf_value_str
	%end;
	%if  %scan(%upcase(&udf_table_nm),3,_)=DATE %then
	%do;
	     strip(put(datepart(udf_value),yymmddn8.)) as udf_value_str
	%end;
    	from   ECM_DB.&udf_table_nm as a  
        	 , ECM_DB.RR_live as b
    	where a.RR_rk=b.RR_rk 
        	  and a.valid_from_dttm=b.valid_from_dttm 
         	  and a.RR_rk &rr_wh;
   		quit;
    %if &sqlrc > 4 %then 
    %do;
          %let successYN=N; 
          %put %sysfunc(sasmsg(&smdds,GEN_STP_ABORT,NOQUOTE,&sysmacroname)) ; 
    %end;
    
    %put %sysfunc(sasmsg(&smdds,GEN_MAC_END_NOTE,NOQUOTE,&sysmacroname)) ;

 %mend;
    
    %let rr_cnt=%ecm_nobs(&rr_subset_dsn);
    %if &rr_cnt < 1  %then  %goto mExit;
    
    proc sql noprint;
         select distinct put(rr_rk,best.) 
                into :rr_rk_list separated by ' ' 
          from &rr_subset_dsn
          ;
    quit;

	/* define filter condition before calling macro ecm_ext_std_udf_value */
    %if &rr_cnt=1 %then %let rr_wh=%str(= &rr_rk_list);
    %else %let rr_wh=%str(in (&rr_rk_list));
  
    /* Extract udf fields by udf data types */
    %ecm_ext_std_udf_value(udf_table_nm=RR_UDF_CHAR_VALUE);
	%if &successYN=N %then %goto mExit;
    %ecm_ext_std_udf_value(udf_table_nm=RR_UDF_DATE_VALUE);
	%if &successYN=N %then %goto mExit;
    %ecm_ext_std_udf_value(udf_table_nm=RR_UDF_NUM_VALUE);
	%if &successYN=N %then %goto mExit;


	/* Concatenate all udf rows excluding the boolean flags that are false */
	data rr_udf_all;
		set rr_udf_char_value  (where=(not (index(udf_nm,'_FLG') and udf_value_str='0')))    
		    rr_udf_num_value  
		    rr_udf_date_value  
		    ;

		if udf_nm in (&format_list) then
		do;
		   udf_value_str=putc(udf_value_str,strip(udf_nm));
		end;

		else if udf_nm = 'X_BIRTHDAY_TXT' then
		do;
		   udf_value_str=substr(udf_value_str,5,4)||substr(udf_value_str,1,4);
		end;
	 
	run;

    %if &syserr > 4 %then 
    %do;
          %let successYN=N;
          %put %sysfunc(sasmsg(&smdds,GEN_STP_ABORT,NOQUOTE,&sysmacroname)) ;
          %goto mExit;
    %end;
    

    /* Get subject keys */ 
	proc sql;
	    
	    create table &outdsn as
	    select a.*, b.subject_key
	    from rr_udf_all as a
	    left join ( select  rr_rk,
	                        udf_table_nm, 
	                        row_no, 
							udf_value_str as subject_key  
					from rr_udf_num_value 
					where udf_table_nm in ( 'X_PERSON_INVOLVED' 'X_ACCOUNT_CASH_IN', 'X_ACCOUNT_CASH_OUT') 
					      and udf_nm='X_PERSON_INVOLVED_RK'				  
	    			) as b
	    on a.rr_rk= b.rr_rk and a.udf_table_nm=b.udf_table_nm and a.row_no=b.row_no	
	    order by rr_rk, subject_key, udf_table_nm, row_no, udf_nm
	    ;
		
		/* delete any orphan data which does not have a valid subject_key*/
		delete 
		from &outdsn
        where subject_key ne '' and 
		      subject_key not in (select distinct udf_value_str
		                          from rr_udf_num_value 
		                          where udf_table_nm= 'X_PERSON_INVOLVED'
								        and udf_nm='X_PERSON_INVOLVED_RK'
								  )		
        ;
	quit;
	 
	%if &sqlrc > 4 %then 
    %do;
          %let successYN=N;
          %put %sysfunc(sasmsg(&smdds,GEN_STP_ABORT,NOQUOTE,&sysmacroname)) ;
          %goto mExit;
    %end;



%mExit:

%put %sysfunc(sasmsg(&smdds,GEN_MAC_END_NOTE,NOQUOTE,&sysmacroname)) ;

%mend;
 
