
/***********************************************************************************/
/* Copyright (c) 2018, SAS Institute Inc., Cary, NC, USA, All Rights Reserved      */
/*                                                                                 */
/* NAME:          ecmrr_efile_fincen_nested_key                                    */
/* PRODUCT:       Enterprise Case Management                                       */
/* PURPOSE:       Get the grandparent keys of a udf table.                         */
/* PARAMETERS:    child_udf_table_nm: udf table name for the child nodes           */
/*                parent_udf_table_nm: udf table name of the parent nodes with     */
/*                                     parent key.                                 */
/*                parent_key_udf_nm: udf name of the parent key                    */
/*                grandparent_key_udf_list: list of quoted udf names of the        */
/*                                          grandparent keys.                      */
/*                outdsn: output data set name                                     */
 /***********************************************************************************/

%macro ecmrr_efile_fincen_nested_key(child_udf_table_nm=,
                                     parent_udf_table_nm=,
                                     parent_key_udf_nm=,
									 grandparent_key_udf_list=,
									 outdsn=
                                     );
 
	%put %sysfunc(sasmsg(&smdds,GEN_MAC_START_NOTE,NOQUOTE,&sysmacroname)) ;

	%let sucessYN=Y;
	proc sql;
		     create table &outdsn as		 
			 select distinct mtr.rr_rk,               
	                mtr.udf_table_nm,
					mtr.row_no,
					ultimate_parent.udf_nm,
	                ultimate_parent.udf_value_str
			 from  rr_udf_char_value (where=(udf_table_nm="&child_udf_table_nm"))as mtr,   
	                (select child.rr_rk, 
                             child.row_no, 
	                         grandparent.udf_nm,
					         grandparent.udf_value_str				                
			        from   rr_udf_num_value (where=(udf_table_nm="&child_udf_table_nm" 
                                                    and udf_nm="&parent_key_udf_nm")) as child,				                
	                       rr_udf_num_value (where=(udf_table_nm="&parent_udf_table_nm" 
                                                    and udf_nm="&parent_key_udf_nm")) as parent,
	                       rr_udf_num_value (where=(udf_table_nm="&parent_udf_table_nm"
                                                    and udf_nm in (&grandparent_key_udf_list))) as grandparent
			        where  child.rr_rk=parent.rr_rk  
	                       and child.udf_value_str=parent.udf_value_str
						   and parent.rr_rk=grandparent.rr_rk
						   and parent.row_no=grandparent.row_no
	                )  as ultimate_parent
			 where mtr.rr_rk=ultimate_parent.rr_rk 
                   and mtr.row_no=ultimate_parent.row_no 
                   
	         ;     
	 quit; 

 	 
	%if &sqlrc > 4 %then 
    %do;
          %let successYN=N;
          %put %sysfunc(sasmsg(&smdds,GEN_STP_ABORT,NOQUOTE,&sysmacroname)) ;
          %goto mExit;
    %end;



%mExit:

%put %sysfunc(sasmsg(&smdds,GEN_MAC_END_NOTE,NOQUOTE,&sysmacroname)) ;

%mend;
 

 
