
/***********************************************************************************/
/* Copyright (c) 2018, SAS Institute Inc., Cary, NC, USA, All Rights Reserved      */
/*                                                                                 */
/* NAME:          ecmrr_efile_fincen_sarx_attach                                    */
/* PRODUCT:       Enterprise Case Management                                       */
/* PURPOSE:       create .zip of sar attachments                                   */
/* PARAMETERS:                                                                     */
/*                udf_dsn: name of table containing attachment name                */
/*                attachment_udf_nm: udf name for attachment file name.            */
/*                efile_rk: efile key                                              */
/*                form_config_rk: key of the report to efile (required)            */
/* NOTE:                                                                           */                                                                                  
/* Attachments must be extracted in the subdirectory (efile_&efile_rk) under WORK  */ 
/* for efile generationd program to create the .zip file                           */ 
/* *********************************************************************************/
%macro ecmrr_efile_fincen_sarx_attach(udf_dsn=rr_udf,
                                      attachment_udf_nm=X_SAR_ATTACHMENT_NM,
                                      efile_rk=,
                                      form_config_rk=
                                     );
                                          

%put %sysfunc(sasmsg(&smdds,GEN_MAC_START_NOTE,NOQUOTE,&sysmacroname)) ;

%local rc;
%let rc=0;
%let successYN=Y;
/* if efile_rk is unknown, assign null as efile_rk */
%if  &efile_rk = %then %let efile_rk=null;
%let attachment_cnt=0;
data _null_;
      set &udf_dsn end=eof;
     where upcase(udf_nm) =upcase("&attachment_udf_nm");
     call symput('OBJECT_ID'||strip(put(_n_,best.))
                 ,strip(put(rr_rk,best.))
                 );
     call symput('ATTACHMENT_NM'||strip(put(_n_,best.))
                 ,strip(udf_value_str)
                 );
     call symput('FNAME'||strip(put(_n_,best.)),
	              strip(put(rr_rk,best20.))
                  ||'_'||strip(udf_value_str)
                 );
     if eof then
     do;
        call symput('ATTACHMENT_CNT'
                    ,strip(put(_n_,best.))
                    );
        call symput('OUTPATH'
                    ,pathname('work')||"&slash.efile_&efile_rk"
                    );
     end;

run;
%if &attachment_cnt > 0 %then
%do;
    %local createdRC;
    %let createdRC=0;
    %ecm_mkdir(pathname=%superq(outpath),rcvar=createdRC,resetYN=Y);

    %if &createdRC ne 1 %then 
    %do; 
        %let successYN=N;
        %put %sysfunc(sasmsg(&smdds,GEN_MKDIR_ERROR,NOQUOTE,%superq(outpath))) ; 
        %goto mExit; 
    %end;
%end;



%local i_attach;

%do i_attach=1 %to &attachment_cnt;
    filename outatt "&outpath&slash&&&fname&i_attach";  
    %ecm_wip_get_attachment(object_type_id=545007
                        ,object_id=&&object_id&i_attach
                        ,outfref=outatt
                        ,attachment_nm=%nrbquote(&&attachment_nm&i_attach)
                        ,rcvar=RC);
    
%end;


%if &rc ne 0 %then 
%do; 
    %let successYN=N;
    %put %sysfunc(sasmsg(&smdds,SAR_EFILE_ATTACHMENT_ERROR,NOQUOTE,&efile_rk)) ; 
    %goto mExit; 
%end;

proc sql noprint;
    select efile_file_prefix into :efile_file_prefix
    from ecm_db.form_config 
    where form_config_rk=&form_config_rk
    ;
    select efile_id into :efile_id
    from ecm_db.efile_live
    where efile_rk=&efile_rk
    ;
quit;
filename outzip "%trim(&ecm_efile_path)&slash.%trim(&efile_file_prefix)&slash%trim(&efile_id).zip";
%if %sysfunc(fexist(outzip)) %then %let rc=%sysfunc(fdelete(outzip));

%if &attachment_cnt > 0 %then
%do;                
    
    %ecm_zip(zippath=%superq(outpath),rcvar=RC,outfref=outzip);
    filename outzip clear; 
    %if &rc ne 0 %then 
    %do; 
        %let successYN=N;
        %put %sysfunc(sasmsg(&smdds,SAR_EFILE_ZIP_ERROR,NOQUOTE,&efile_rk)) ; 
        %goto mExit; 
    %end;
%end;
 
%mExit: 

%put %sysfunc(sasmsg(&smdds,GEN_MAC_END_NOTE,NOQUOTE,&sysmacroname)) ;

%mend;
 
