
/***********************************************************************************/
/* Copyright (c) 2017, SAS Institute Inc., Cary, NC, USA, All Rights Reserved      */
/*                                                                                 */
/* NAME:          ecmrr_efile_xml_seqnum                                           */
/* PRODUCT:       Enterprise Case Management                                       */
/* PURPOSE:       assign sequence number to xml tags                               */
/* PARAMETERS:    exclude_dsn: name of table containing numbers that should        */
/*                        not be used for sequence number.                         */ 
/*                exclude_var: variable in exclude_dsn that contains the seq number*/
/*                             that should be excluded                             */  
/*                infname: file reference of input xml                             */
/*                outfname: file reference of output xml                           */
/*                linecntVar: name of macro variable to return total number of     */
/*                            in the xml.                                          */
/* NOTE:          replacing '.' in 'SeqNum="."' with unique seq number.            */
/*                although FinCEN CTRX user's guide requires the sequence number be*/
/*                consecutive and starts with 1, the efile got accepted as long    */
/*                as the sequence numbers are unique.                              */
/***********************************************************************************/


%macro ecmrr_efile_xml_seqnum(exclude_dsn=,
                              exclude_var=, 
                              infname=, 
                              outfname=,
                              linecntVar=line_cnt);

%put %sysfunc(sasmsg(&smdds,GEN_MAC_START_NOTE,NOQUOTE,&sysmacroname)) ;

/*
  Base on the list of excluded sequence numbers 
       (which are probably the report keys that are reserved for activity sequence numbers) 
  to find the next starting sequence number to use for the rest of the xml 
*/

%let factor=100000;
%let seq_offset=0;
%if %str(&exclude_dsn) ne %str() %then
%do; 
   
     proc sql noprint;
	     /* round up the maximum number to the nearest factor */
         select distinct strip(put(ceil(max(&exclude_var)/&factor)*&factor,best.)) 
                into :seq_offset
          from &exclude_dsn
          ;		  
    quit;
 
%end;
 

data _null_;
     
    infile &infname end=eof ;
    file &outfname;
    input;	

    if index(_infile_,'SeqNum="."') then
    do;  
        seqNum=&seq_offset + _n_;
       _infile_=tranwrd(_infile_,'SeqNum="."','SeqNum="'||strip(put(seqNum,best.))||'"');
    end;
    put _infile_;
	if eof then call symput("&lineCntVar",strip(put(_n_,best.)));
run;

%if &syserr > 4 %then
%do;
    %let successYN=N;	 
     %put %sysfunc(sasmsg(&smdds,GEN_STP_ABORT,NOQUOTE,&sysmacroname)) ;
    %goto mExit;
%end;

%mexit:

%put %sysfunc(sasmsg(&smdds,GEN_MAC_END_NOTE,NOQUOTE,&sysmacroname)) ;

%mend;


 
