
/***********************************************************************************/
/* Copyright (c) 2018, SAS Institute Inc., Cary, NC, USA, All Rights Reserved      */
/*                                                                                 */
/* NAME:          ecmrr_efile_fincen_concat_sarx_type_cd                           */
/* PRODUCT:       Enterprise Case Management                                       */
/* PURPOSE:      Concatenate the sar type codes into strings for SARX              */
/* PARAMETERS:   None                                                              */
/*                                                                                 */
/* NOTE:  This macro is using the output from %ecm_pivot_datatype                  */
/*        It is called by ecmrr_prvm_fincen_sarx_data                              */
/***********************************************************************************/

%macro ecmrr_fincen_concat_sarx_type_cd;
     
/*******************************************************************************/
/* Concatenate the following SAR type codes into a string for preview report   */
/* X_SAR_STRUCT_TYPE_CD  - structuring (item 32)                               */
/* X_SAR_TERRORIST_TYPE_CD  - Terrorist financing (item 33)                    */
/* X_SAR_FRAUD_TYPE_CD  - Fraud (item 34)                                      */
/* X_SAR_CASINO_TYPE_CD  - Gaming activities (item 35)                         */
/* X_SAR_ML_TYPE_CD  - Money Laundering (item 36)                              */
/* X_SAR_ID_TYPE_CD  - ID (item 37)                                            */
/* X_SAR_OTHER_TYPE_CD  - Other Suspicious Activities (Item 38)                */
/* X_SAR_INSURANCE_TYPE_CD  - Insurance (Item 39)                              */
/* X_SAR_SF_TYPE_CD  - Securities/Futures/Options (Item 40)                    */
/* X_SAR_MORTGAGE_TYPE_CD  - Mortgage Fraud (item 41)                          */
/* X_SAR_CYBER_CD  - Cyber event (item 42)                                     */
/* X_SAR_PROD_TYPE_CD  - Products type(s) involvfed (item 45)                  */
/* X_SAR_INSTRUMENT_TYPE_CD - Instruments Types/Payment                        */
/*******************************************************************************/
%put %sysfunc(sasmsg(&smdds,GEN_MAC_START_NOTE,NOQUOTE,&sysmacroname)) ;

%let SUCCESSYN=Y;
%let typeDim=13;
data _null_;
     array _sar_type{&typeDim} $50 ('STRUCT' 'TERRORIST' 'FRAUD' 'CASINO' 'ML'
                              'ID' 'OTHER' 'INSURANCE' 'SF' 'MORTGAGE' 
                              'CYBER' 'PROD' 'INSTRUMENT');
      
     do i=1 to dim(_sar_type);
        call symput('_SAR_TYPE_'||strip(put(i,best.)),_sar_type{i});        
     end;
run;

%do i=1 %to &typeDim;
    %let _sar_type=&&_sar_type_&i;
    %ecmrr_fincen_concat_cd(indsn=r_x_sar_&_sar_type._type
                            ,outdsn=t_zx_sar_&_sar_type._type
                            ,byvar=rr_rk
                            ,invar=x_sar_&_sar_type._type_cd
                            ,outvar=zx_sar_&_sar_type._type
                            ,maxsize=50);
    %if &successYN=N %then %goto mExit;
%end;


data r_x_sar_type;
    merge      
    %do i=1 %to &typeDim;
    %let _sar_type=&&_sar_type_&i;
          t_zx_sar_&_sar_type._type
                           
    %end;
    ;
    by rr_rk;
run;

%mExit:

%put %sysfunc(sasmsg(&smdds,GEN_MAC_END_NOTE,NOQUOTE,&sysmacroname)) ;

%mend;
