/***********************************************************************************/
/* Copyright (c) 2018, SAS Institute Inc., Cary, NC, USA, All Rights Reserved      */
/*                                                                                 */
/* NAME:          ecmrr_pivot_fincen_data                                          */
/* PRODUCT:       Enterprise Case Management                                       */
/* PURPOSE:       Transform the RR data for report preview or validation etc       */
/* PARAMETERS:                                                                     */
/*                rr_rk: key of a single report to be extracted.                   */
/*                rr_subset_dsn: name of sas table containing the list of rr_rk    */
/*                        When rr_rk is non blank, this parameter is ignored.      */   
/*                rr_config_rk: form config key                                    */
/*                        It is used to define the list of udf tables that are     */
/*                        relevant to the form.                                    */
/*                        Only 212 is supported at this point.                     */
/* NOTE:                                                                           */
/***********************************************************************************/
%macro ecmrr_pivot_fincen_data(rr_rk=, rr_subset_dsn=, form_config_rk=212);


%put %sysfunc(sasmsg(&smdds,GEN_MAC_START_NOTE,NOQUOTE,&sysmacroname)) ;
%let successYN=Y;
%let rr_list=;

%if %str(&rr_rk) ne %str() %then 
%do;
    %let rr_rk_list=&rr_rk;
%end;
%else
%do;
	%if %str(&rr_subset_dsn) ne %str() %then
	%do;
	    proc sql noprint;
	         select distinct strip(put(rr_rk,best.)) into :rr_rk_list separated by ' '
	         from &rr_subset_dsn
	         ;
	    quit;
	    %if &sqlrc > 4 or &sqlobs < 1 %then 
	    %do;
	         %put ERROR: No rr_rk found in &rr_subset_dsn.;
	         %let successYN=N;
	         %goto mExit;
	    %end;
	%end;
	%else 
	%do;
	     %put ERROR: Either rr_rk or rr_subset_dsn is required.;
	     %let successYN=N;
	     %goto mExit;
	%end;
%end;


 /* transform the data to efile ready format */
 %ecm_create_label_fmt; 

    %if &successYN=N %then %goto mEXIT;
%if &form_config_rk=212 %then
%do;
%let table_wh="X_FOREIGN_CASH_IN" "X_FOREIGN_CASH_OUT" "X_INSTITUTION" 
 "RR" "X_ACCOUNT_CASH_IN" "X_ACCOUNT_CASH_OUT" "X_PERSON_INVOLVED" "X_TRAN_METHOD"
;
%end;
%else
%do;
     %put ERROR: Only form 212 are supported at this point.;
     %let successYN=N;
     %goto mExit;
%end; 

    /* To improve performance, subset the data first */

    %macro ecm_extract_udf_value(udf_table_nm=);    
        proc sql;
        create table &udf_table_nm as
        select a.*
        from   ECM_DB.&udf_table_nm as a  
             , ECM_DB.RR_live as b
        where a.RR_rk=b.RR_rk 
              and a.valid_from_dttm=b.valid_from_dttm               
              and a.rr_rk in (&rr_rk_list)
           
        ;
        quit;
    %mend;    
    
    proc sql;
        create table rr_live as
        select * from ecm_db.rr_live
        where rr_rk in (&rr_rk_list) and form_config_rk=&form_config_rk                     
        ;
    quit; 
    %if &sqlobs < 1 %then 
	%do;
	    %put ERROR: No valid report found.;
	    %let successYN=N;
	    %goto mExit;
    %end;

    %ecm_extract_udf_value(udf_table_nm=RR_UDF_CHAR_VALUE);
    %ecm_extract_udf_value(udf_table_nm=RR_UDF_DATE_VALUE);
    %ecm_extract_udf_value(udf_table_nm=RR_UDF_NUM_VALUE);
    %ecm_extract_udf_value(udf_table_nm=RR_UDF_LGCHR_VIEW);

    /* Transform the data into report ready format using the extracted data in the WORK library. */
   %ecm_pivot_datatype(datatype=rr,in_lib=WORK,out_lib=WORK,datatype_rk=&rr_rk_list,table_wh=&table_wh);
   

%mExit:

%put %sysfunc(sasmsg(&smdds,GEN_MAC_END_NOTE,NOQUOTE,&sysmacroname)) ;

%mend;   
