
/***********************************************************************************/
/* Copyright (c) 2014, SAS Institute Inc., Cary, NC, USA, All Rights Reserved      */
/*                                                                                 */
/* NAME:          ecmrr_prvw_fincen_newctr_driver                                  */
/* PRODUCT:       Enterprise Case Management                                       */
/* PURPOSE:       Create preview report for new FINCEN CTR form                    */
/* PARAMETERS:                                                                     */
/*                rr_rk: key of the report to preview (required)                   */
/*                form_config_rk: key of the form configuration record             */
/* NOTE:                                                                           */
/***********************************************************************************/
%macro ecmrr_prvw_fincen_ctrx_driver(rr_rk=,form_config_rk=);
%put %sysfunc(sasmsg(&smdds,GEN_MAC_START_NOTE,NOQUOTE,&sysmacroname)) ;


proc sql noprint;
     select strip(FORM_AGENCY_CD),
            strip(FORM_TYPE_CD),
            strip(PREVIEW_MIME_TYPE_CD),
            strip(PREVIEW_FILE_PREFIX),
            strip(PREVIEW_PREPROCESS_PGM_NM) 
            into
            :form_agency_cd,
            :form_type_cd,
            :preview_mime_type_cd,
            :preview_file_prefix,
            :preview_preprocess_pgm_nm
     from ecm_db.form_config
     where form_config_rk=&form_config_rk;
quit;


/* Run the preprocessing code if it is defined */
 
%if &preview_preprocess_pgm_nm ne %then
%do;
   %&preview_preprocess_pgm_nm(rr_rk=&rr_rk);
%end;

    filename logfile temp;
    proc printto log=logfile;
    run;
     
    %ecmrr_fdf_ctrx_driver(  rr_rk=&rr_rk
                              ,form_config_rk=&form_config_rk                      
                            );
    proc printto; 
    run;

    /* Dump the saved log to standard log window. */
    data _null_;
             infile logfile;
             input;
             put _infile_;
    run;

    /* return the pdf to stored process _webout */ 

      filename  infile "%sysfunc(pathname(work))&slash%trim(&preview_file_prefix).pdf";

      %ecmrr_prvw_fincen_webout(  rr_rk=&rr_rk
                                , report_nm=CTR
                                ,infile_fref=infile
                                ,logfile_fref=logfile
                                );


 
     filename infile clear; 
     filename logfile clear;
   
%put %sysfunc(sasmsg(&smdds,GEN_MAC_END_NOTE,NOQUOTE,&sysmacroname)) ;
%MEXIT: 
%mend;
