/***********************************************************************************/
/* Copyright (c) 2018, SAS Institute Inc., Cary, NC, USA, All Rights Reserved      */
/*                                                                                 */
/* NAME:          ecmrr_prvw_fincen_sarx_data                                       */
/* PRODUCT:       Enterprise Case Management                                       */
/* PURPOSE:       Transform the RR data for report preview                         */
/* PARAMETERS:                                                                     */
/*                rr_config_rk: key of the report to preview (required)            */
/* NOTE:                                                                           */
/***********************************************************************************/
%macro ecmrr_prvw_fincen_sarx_data(rr_rk=, form_config_rk=211);


%put %sysfunc(sasmsg(&smdds,GEN_MAC_START_NOTE,NOQUOTE,&sysmacroname)) ;

%ecmrr_fincen_new_sas_format(form_config_rk=&form_config_rk);

%let successYN=Y;
 

/* transform the data to efile ready format */
%ecmrr_prvw_fincen_sarx_detail(rr_rk=&rr_rk,form_config_rk=&form_config_rk);

/* update the x_filed_dt to the filed date if x_filed_dt is not emtpy */
%let _report_dt=;
proc sql noprint;
     select put(x_filed_dt,best.)  into :_report_dt
     from rr_pivot
     where x_filed_dt > 0 ;
%if &_report_dt ne %then
%do;
     update zx_rr
     set x_filed_dt=&_report_dt
     ;
quit;   
%end;

/* create filing institution data for sar_s1.pdf */
%let z_institution_cnt=%ecm_nobs(zx_institution);

proc sql;
     create table zx_inst as
     select 1  as z_rr_seq_no,
            *,
            'Part III Information about Financial Institution Where Activity Occurred '||strip(put(z_institution_seq_no,best.))||
                  " of &z_institution_cnt"
            as z_header_txt length=100
     from zx_institution
     order by z_institution_seq_no
;
quit;  

proc sort data=zx_branch force;
     by z_institution_seq_no row_no;
run;
/* prepare institutions where activity occurred data with the first branch data */
/* for sar_s2.pdf                                                               */ 
%let z_institution_cnt=%ecm_nobs(zx_institution);
data zx_inst_branch
     t_zx_branch_more (keep=x_branch_role_cd
                            x_branch_address_txt
                            x_branch_city_nm
                            x_branch_state_cd
                            x_branch_country_cd
                            x_branch_postal_cd
                            x_branch_rssd_id
                            z_institution_seq_no
                            z_header_txt
                        )
;
   
     merge zx_inst
           zx_branch
     ;
     by z_institution_seq_no;
     if first.z_institution_seq_no then output zx_inst_branch;
     else output t_zx_branch_more;
run;

/* create additional branch data for sarx_inst_branch_more.pdf */
data zx_branch_more;
     set t_zx_branch_more;
     by z_institution_seq_no;

     array z_branch_role_cd {6} $1 x_branch_role_cd_1 - x_branch_role_cd_6;
     array z_branch_address_txt {6} $100 x_branch_address_txt_1 - x_branch_address_txt_6;
     array z_branch_city_nm {6} $50 x_branch_city_nm_1 - x_branch_city_nm_6;
     array z_branch_postal_cd {6} $9 x_branch_postal_cd_1 - x_branch_postal_cd_6;
     array z_branch_state_cd {6} $3 x_branch_state_cd_1 - x_branch_state_cd_6;
     array z_branch_country_cd {6} $2 x_branch_country_cd_1 - x_branch_country_cd_6;
     array z_branch_rssd_id {6} $20 x_branch_rssd_id_1 - x_branch_rssd_id_6;
     retain x_branch_role_cd_1 - x_branch_role_cd_6
            x_branch_address_txt_1 - x_branch_address_txt_6
            x_branch_city_nm_1 - x_branch_city_nm_6
            x_branch_postal_cd_1 - x_branch_postal_cd_6
            x_branch_state_cd_1 - x_branch_state_cd_6
            x_branch_country_cd_1 - x_branch_country_cd_6
            x_branch_rssd_id_1 - x_branch_rssd_id_6
     ;

     if first.z_institution_seq_no then link ARRAY_CLEAR;
     array_i+1;
     if array_i > 6 then
     do;
         output;
         link ARRAY_CLEAR;
         array_i=1;
     end;
     link ARRAY_ASSIGN;
     if last.z_institution_seq_no then output;
     return;

ARRAY_CLEAR:
    do i=1 to 6;
       z_branch_role_cd{i}='';
       z_branch_address_txt{i}='';
       z_branch_city_nm{i}='';
       z_branch_postal_cd{i}='';
       z_branch_state_cd{i}='';
       z_branch_country_cd{i}='';
       z_branch_rssd_id{i}='';
    end;
    array_i=0;
return;

ARRAY_ASSIGN:

       z_branch_role_cd{array_i}=x_branch_role_cd;
       z_branch_address_txt{array_i}=x_branch_address_txt;
       z_branch_city_nm{array_i}=x_branch_city_nm;
       z_branch_postal_cd{array_i}=x_branch_postal_cd;
       z_branch_state_cd{array_i}=x_branch_state_cd;
       z_branch_country_cd{array_i}=x_branch_country_cd;
       z_branch_rssd_id{array_i}=x_branch_rssd_id;


return;
run;

%if &syserr > 4 %then 
%do;
     %let successYN=N;
     %put %sysfunc(sasmsg(&smdds,GEN_STP_ABORT,NOQUOTE,&sysmacroname)) ;
     %goto mExit;
%end;


/* Expand the IP addresses to have multiple pages.  First IP address will be appended to Z_RR */
/* and the remainder will go to their own page on report preview.                             */
proc sort data=r_x_ip_address force;
   by rr_rk row_no;
run;
data zx_ip_address
     t_zx_ip_address_more (keep=row_no
                            rr_rk
                            x_ip_address_dt
                            x_ip_address_tm
                            x_ip_address_txt
                        );  
     set r_x_ip_address;
     by rr_rk;
     if first.rr_rk then output zx_ip_address;
     else output t_zx_ip_address_more;
run;
/* create additional IP address data for second pdf page of IP addresses. */
%let num_of_ips=6;
data zx_ip_address_more;
     set t_zx_ip_address_more;
     by rr_rk;
     z_rr_seq_no=1; 
     array z_rr_rk {&num_of_ips.} 8 x_rr_rk_1 - x_rr_rk_&num_of_ips.;
     array z_x_ip_address_dt {&num_of_ips.}  8 x_ip_address_dt_1 - x_ip_address_dt_&num_of_ips.;
     array z_x_ip_address_tm {&num_of_ips.}  $8 x_ip_address_tm_1 - x_ip_address_tm_&num_of_ips.;
     array z_x_ip_address_txt {&num_of_ips.} $39 x_ip_address_txt_1 - x_ip_address_txt_&num_of_ips.;
	  
     retain x_rr_rk_1 - x_rr_rk_&num_of_ips.
            x_ip_address_dt_1 - x_ip_address_dt_&num_of_ips.
            x_ip_address_tm_1 - x_ip_address_tm_&num_of_ips.
            x_ip_address_txt_1 - x_ip_address_txt_&num_of_ips.
     ;

     if first.rr_rk then link ARRAY_CLEAR;
     array_i+1;
     if array_i > &num_of_ips. then
     do;
         output;
         link ARRAY_CLEAR;
         array_i=1;
     end;
     link ARRAY_ASSIGN;
     if last.rr_rk then output;
     return;

ARRAY_CLEAR:
    do i=1 to &num_of_ips.;
       z_rr_rk{i}=.;
       z_x_ip_address_dt{i}=.;
       z_x_ip_address_tm{i}='';
       z_x_ip_address_txt{i}='';
    end;
    array_i=0;
return;

ARRAY_ASSIGN:
       z_rr_rk{array_i}=rr_rk;
       z_x_ip_address_dt{array_i}=x_ip_address_dt;
       z_x_ip_address_tm{array_i}=x_ip_address_tm;
       z_x_ip_address_txt{array_i}=x_ip_address_txt;

return;
run;

%if &syserr > 4 %then 
%do;
     %let successYN=N;
     %put %sysfunc(sasmsg(&smdds,GEN_STP_ABORT,NOQUOTE,&sysmacroname)) ;
     %goto mExit;
%end;

/* Expand the Cyber Events to have multiple pages.  First Cyber Event will be appended to Z_RR */
/* and the remainder will go to their own page on report preview.                              */
proc sort data=r_x_cyber_event force;
   by rr_rk row_no;
run;
data zx_cyber_event
     t_zx_cyber_event_more (keep=row_no
                            rr_rk
                            x_cyber_event_dt
                            x_cyber_event_tm
                            x_cyber_event_type_cd
							x_cyber_event_type_oth_txt
							x_cyber_event_value
                        );  
     set r_x_cyber_event;
     by rr_rk;
     if first.rr_rk then output zx_cyber_event;
     else output t_zx_cyber_event_more;
run;
/* create additional cyber event data for second pdf page of events. */
%let num_of_events=6;
data zx_cyber_event_more;
     set t_zx_cyber_event_more;
     by rr_rk;
     z_rr_seq_no=1; 
     array z_rr_rk {&num_of_events.} 8 x_rr_rk_1 - x_rr_rk_&num_of_events.;
     array z_x_cyber_event_dt {&num_of_events.}  8 x_cyber_event_dt_1 - x_cyber_event_dt_&num_of_events.;
     array z_x_cyber_event_tm {&num_of_events.}  $8 x_cyber_event_tm_1 - x_cyber_event_tm_&num_of_events.;
	 array z_x_cyber_event_type_cd {&num_of_events.}  $3 x_cyber_event_type_cd_1 - x_cyber_event_type_cd_&num_of_events.;
	 array z_x_cyber_event_oth_txt {&num_of_events.}  $3 x_cyber_event_oth_txt_1 - x_cyber_event_oth_txt_&num_of_events.;
     array z_x_cyber_event_value {&num_of_events.} $4000 x_cyber_event_value_1 - x_cyber_event_value_&num_of_events.;
	  
     retain x_rr_rk_1 - x_rr_rk_&num_of_events.
            x_cyber_event_dt_1 - x_cyber_event_dt_&num_of_events.
            x_cyber_event_tm_1 - x_cyber_event_tm_&num_of_events.
			x_cyber_event_type_cd_1 - x_cyber_event_type_cd_&num_of_events.
			x_cyber_event_oth_txt_1 - x_cyber_event_oth_txt_&num_of_events.
            x_cyber_event_value_1 - x_cyber_event_value_&num_of_events.
     ;

     if first.rr_rk then link ARRAY_CLEAR;
     array_i+1;
     if array_i > &num_of_events. then
     do;
         output;
         link ARRAY_CLEAR;
         array_i=1;
     end;
     link ARRAY_ASSIGN;
     if last.rr_rk then output;
     return;

ARRAY_CLEAR:
    do i=1 to &num_of_events.;
       z_rr_rk{i}=.;
       z_x_cyber_event_dt{i}=.;
       z_x_cyber_event_tm{i}='';
	   z_x_cyber_event_type_cd{i}='';
	   z_x_cyber_event_oth_txt{i}='';
       z_x_cyber_event_value{i}='';
    end;
    array_i=0;
return;

ARRAY_ASSIGN:
       z_rr_rk{array_i}=rr_rk;
       z_x_cyber_event_dt{array_i}=x_cyber_event_dt;
       z_x_cyber_event_tm{array_i}=x_cyber_event_tm;
	   z_x_cyber_event_type_cd{array_i}=x_cyber_event_type_cd;
	   z_x_cyber_event_oth_txt{array_i}=x_cyber_event_oth_txt;
       z_x_cyber_event_value{array_i}=x_cyber_event_value;

return;
run;

%if &syserr > 4 %then 
%do;
     %let successYN=N;
     %put %sysfunc(sasmsg(&smdds,GEN_STP_ABORT,NOQUOTE,&sysmacroname)) ;
     %goto mExit;
%end;

/* concatenate commodity data */
%ecmrr_fincen_concat_txt(indsn=r_x_commodity
                            ,outdsn=z_commodity
                            ,byvar=rr_rk
                            ,invar=x_commodity_type_txt
                            ,outvar=zx_commodity_type_txt
                            ,delimiter=%str(, )
                            ,maxsize=32760
                            ,sortedYN=N
                            ,sortby=rr_rk
                            ,fmtnm=
                           );
%if &successYN=N %then %goto mExit;


/* concatenate product data */
%ecmrr_fincen_concat_txt(indsn=r_x_product
                            ,outdsn=z_product
                            ,byvar=rr_rk
                            ,invar=x_prod_desc
                            ,outvar=zx_prod_desc
                            ,delimiter=%str(, )
                            ,maxsize=32760
                            ,sortedYN=N
                            ,sortby=rr_rk
                            ,fmtnm=
                           );
%if &successYN=N %then %goto mExit;

/* concatenate CUSIP data */
%ecmrr_fincen_concat_txt(indsn=r_x_cusip
                            ,outdsn=z_cusip
                            ,byvar=rr_rk
                            ,invar=x_cusip_no
                            ,outvar=zx_cusip_no
                            ,delimiter=%str(, )
                            ,maxsize=32760
                            ,sortedYN=N
                            ,sortby=rr_rk
                            ,fmtnm=
                           );
%if &successYN=N %then %goto mExit;


/* concatenate market data */
%ecmrr_fincen_concat_txt(indsn=r_x_market
                            ,outdsn=z_market
                            ,byvar=rr_rk
                            ,invar=x_mic_cd
                            ,outvar=zx_mic_cd
                            ,delimiter=%str(, )
                            ,maxsize=32760
                            ,sortedYN=N
                            ,sortby=rr_rk
                            ,fmtnm=
                           );
%if &successYN=N %then %goto mExit;


/* prepare report data for sar_s0, sar_s10. sar_s11, sar_s12 */                           
data z_rr;
     merge zx_rr
           z_commodity (keep=rr_rk zx_commodity_type_txt)
           z_product (keep=rr_rk zx_prod_desc)
           z_cusip (keep=rr_rk zx_cusip_no)
           z_market (keep=rr_rk zx_mic_cd)
           zx_ip_address (keep=rr_rk x_ip_address_txt x_ip_address_dt x_ip_address_tm) 
		   zx_cyber_event (keep=rr_rk x_cyber_event_type_cd x_cyber_event_dt x_cyber_event_tm
		                        x_cyber_event_type_oth_txt x_cyber_event_value)
    ;
    by rr_rk;
run;

%if &syserr > 4 %then 
%do;
     %let successYN=N;
     %put %sysfunc(sasmsg(&smdds,GEN_STP_ABORT,NOQUOTE,&sysmacroname)) ;
     %goto mExit;
%end;

/* prepare subject data */
%ecmrr_prvw_fincen_sarx_subj;

%mExit:

%put %sysfunc(sasmsg(&smdds,GEN_MAC_END_NOTE,NOQUOTE,&sysmacroname)) ;

%mend;
