
/***********************************************************************************/
/* Copyright (c) 2018, SAS Institute Inc., Cary, NC, USA, All Rights Reserved      */
/*                                                                                 */
/* NAME:          ecmrr_prvw_fincen_sarx_detail                                    */
/* PRODUCT:       Enterprise Case Management                                       */
/* PURPOSE:       Transform the RR data for rectanglar structure                   */
/*                And concatenate the type codes from rows into a single field     */
/* PARAMETERS:                                                                     */
/*                rr_rk: report key                                                */
/*                form_config_rk: form config key                                  */
/*                                                                                 */
 /***********************************************************************************/

%macro ecmrr_prvw_fincen_sarx_detail(rr_rk=,form_config_rk=211);
                                          
%put %sysfunc(sasmsg(&smdds,GEN_MAC_START_NOTE,NOQUOTE,&sysmacroname)) ;

%let successYN=Y;

/***********************************************/
/* Get RR records                              */
/* and transpose them to rectangular structure */
/***********************************************/

   %ecm_create_label_fmt; 

    %if &successYN=N %then %goto mEXIT;

%let table_wh="X_BRANCH" "X_COMMODITY" "X_CUSIP"  "X_FILING_INST_SF_TYPE" "X_INSTITUTION" "X_INST_SF_TYPE"
"X_IP_ADDRESS" "X_MARKET" "X_PRODUCT" "X_CYBER_EVENT" "X_SAR_CASINO_TYPE" "X_SAR_FRAUD_TYPE" "X_SAR_ID_TYPE" "X_SAR_INSTRUMENT_TYPE"
"X_SAR_INSURANCE_TYPE" "X_SAR_ML_TYPE" "X_SAR_MORTGAGE_TYPE" "X_SAR_OTHER_TYPE" "X_SAR_PROD_TYPE" "X_SAR_SF_TYPE"
"X_SAR_STRUCT_TYPE" "X_SAR_TERRORIST_TYPE" "X_SAR_CYBER_TYPE" "X_SUBJECT" "X_SUBJECT_ACCT_INST" "X_SUBJECT_ADDRESS"
"X_SUBJECT_ALTERNATE_NM" "X_SUBJECT_EMAIL_ADDRESS" "X_SUBJECT_ID" "X_SUBJECT_INST_ACCT"
"X_SUBJECT_RELATION_INST" "X_SUBJECT_TELEPHONE_NO" "X_SUBJECT_URL_ADDRESS" "RR"
;

    /* To improve performance, subset the data first */

    %macro ecm_extract_udf_value(udf_table_nm=);  

    %let successYN=Y; 
    proc sql;
	    create table &udf_table_nm as
	    select a.*
	    from   ecm_db.&udf_table_nm as a  
	         , ecm_db.rr_live as b
	    where b.rr_rk=&rr_rk 
		      and a.rr_rk=&rr_rk
	          and a.valid_from_dttm=b.valid_from_dttm 
	          ;
    quit;
	%if &sqlrc > 4 %then 
    %do;
        %let successYN=N;
		%put %sysfunc(sasmsg(&smdds,GEN_STP_ABORT,NOQUOTE,&sysmacroname)) ; 
    %end;
    %mend;


    proc sql;
        create table rr_live as
        select * from ecm_db.rr_live
        where rr_rk=&rr_rk ;
    quit;
	%if &sqlrc > 4 %then 
    %do;
        %let successYN=N;
		%put %sysfunc(sasmsg(&smdds,GEN_STP_ABORT,NOQUOTE,&sysmacroname)) ; 
    %end;

    %ecm_extract_udf_value(udf_table_nm=RR_UDF_CHAR_VALUE);
	%if &successYN=N %then %goto mEXIT;

    %ecm_extract_udf_value(udf_table_nm=RR_UDF_DATE_VALUE);
	 %if &successYN=N %then %goto mEXIT;

    %ecm_extract_udf_value(udf_table_nm=RR_UDF_NUM_VALUE);
	 %if &successYN=N %then %goto mEXIT;

    %ecm_extract_udf_value(udf_table_nm=RR_UDF_LGCHR_VIEW);

 

    /* Transform the data into rectangular structure */
   %ecm_pivot_datatype(datatype=rr,in_lib=WORK,out_lib=WORK,datatype_rk=&rr_rk,table_wh=&table_wh);
    
   %if &successYN=N %then %goto mEXIT;


  
/*********************************************************************************************/
/* Concatenate the following codes into a string, maxsize is not relevant for preview report */
/* X_FILING_INST_SF_TYPE_CD   - filing institution SF types                                  */
/* X_INST_SF_TYPE_CD          - Institution SF types                                         */
/*********************************************************************************************/

%ecmrr_fincen_concat_cd(indsn=r_x_filing_inst_sf_type
                            ,outdsn=t_zx_filing_inst_sf_type
                            ,byvar=rr_rk
                            ,invar=x_filing_inst_sf_type_cd
                            ,outvar=zx_filing_inst_sf_type
                            ,maxsize=50);

%if &successYN=N %then %goto mExit;

%ecmrr_fincen_concat_cd(indsn=r_x_inst_sf_type
                            ,outdsn=t_zx_inst_sf_type
                            ,byvar=rr_rk x_inst_rk
                            ,invar=x_inst_sf_type_cd
                            ,outvar=zx_inst_sf_type
                            ,inothervar=x_inst_sf_type_oth_txt
                            ,otherVal=Z
                            ,outothervar=zx_inst_sf_type_oth_txt
                            ,maxsize=50
                            ,sortedYN=N
                            ,sortby=rr_rk x_inst_rk
                            );

%if &successYN=N %then %goto mExit;

/***********************************************************************/
/* Concatenate  X_SAR*_TYPE_*_CD  codes into strings in R_X_SAR_TYPE   */
 /**********************************************************************/

%ecmrr_fincen_concat_sarx_type_cd;

 %if &successYN=N %then %goto mEXIT;


 
/********************************************/
/* Prepare ZX_INSTITUION                    */
/********************************************/
proc sql;
    create table zx_institution as
    select distinct a.*, b.zx_inst_sf_type, b.zx_inst_sf_type_oth_txt
    from  r_x_institution (rename=(row_no=z_institution_seq_no)) as a
    left join   t_zx_inst_sf_type as b
    on a.rr_rk=b.rr_rk and a.x_inst_rk=b.x_inst_rk
     ;
run;


%if &sqlrc > 4 %then 
%do;
     %let successYN=N;
     %put %sysfunc(sasmsg(&smdds,GEN_STP_ABORT,NOQUOTE,&sysmacroname)) ;
     %goto mExit;
%end;



/********************************************/
/* Prepare ZX_BRANCH                        */
/********************************************/
proc sql;
    create table zx_branch as
    select distinct a.*, b.z_institution_seq_no
    from  r_x_branch as a
    left join  zx_institution as b
    on a.rr_rk=b.rr_rk and a.x_inst_rk=b.x_inst_rk
	order by z_institution_seq_no
     ;
run;


%if &sqlrc > 4 %then 
%do;
     %let successYN=N;
     %put %sysfunc(sasmsg(&smdds,GEN_STP_ABORT,NOQUOTE,&sysmacroname)) ;
     %goto mExit;
%end;

 
/*************************************************************************/
/* Prepare ZX_RR (report detail and filing institution                   */
/*************************************************************************/
 

data zx_rr;
    z_rr_seq_no=1;
    merge rr_pivot (in=inrr)
          r_x_sar_type        
          t_zx_filing_inst_sf_type 
    ;
    by rr_rk;
	length z_sar_narrative_desc_long $ 4000; 
    if inrr;
    x_filed_dt=today();

	/* escape  \ and () to avoid error in pdf generation with the FDF files.          */
	/* Change to separate invocations of tranwrd.  The previous nesting of calls were */
	/* behaving different on Win vs. Linux systems.                                   */
	/* The \ has to be first, because () will generate an extra \ character.          */
	z_sar_narrative_desc_long=tranwrd(x_sar_narrative_desc,'\','\\');
	z_sar_narrative_desc_long=tranwrd(z_sar_narrative_desc_long,'\)','\)');
	z_sar_narrative_desc_long=tranwrd(z_sar_narrative_desc_long,'\(','\(');
    drop x_sar_narrative_desc;     
run;


%if &syserr > 4 %then 
%do;
     %let successYN=N;
     %put %sysfunc(sasmsg(&smdds,GEN_STP_ABORT,NOQUOTE,&sysmacroname)) ;
     %goto mExit;
%end;


/************************************************/
/* These detail tables will be returned as-is   */
/* R_X_COMMODITY                                */
/* R_X_PRODUCT                                  */
/* R_X_MARKET                                   */
/* R_X_IP_ADDRESS                               */
/* R_X_CUSIP                                    */
/* R_X_CYBER_EVENT                              */
/************************************************/
 


/********************************************/
/* Prepare zx_subject                       */
/********************************************/
 
data zx_subject;
     z_rr_seq_no=1;
     set r_x_subject;
     rename row_no=z_subject_seq_no
     ;
run;

%if &syserr > 4 %then 
%do;
     %let successYN=N;
     %put %sysfunc(sasmsg(&smdds,GEN_STP_ABORT,NOQUOTE,&sysmacroname)) ;
     %goto mExit;
%end;

%macro ecmrr_add_subj_seq_no(indsn=,
                             outdsn=
                             );
		 %let successYN=Y;
		     create table &outdsn as 
			 select 1  as z_rr_seq_no,
			        subj.z_subject_seq_no,
                    mtr.*			       
			 from &indsn as mtr
			 left join zx_subject as subj
			 on mtr.x_subject_rk=subj.x_subject_rk
             order by  z_subject_seq_no, row_no
         ;
     %if &syserr > 4 %then 
     %do;
	     %let successYN=N;
	     %put %sysfunc(sasmsg(&smdds,GEN_STP_ABORT,NOQUOTE,&sysmacroname)) ;      
      %end;
		 
%mend;


/********************************************/
/* Add z_subject_seq_no to these tables     */
/* R_X_SUBJECT_ADDRRESS                     */
/* R_X_SUBJECT_ID                           */
/* R_X_SUBJECT_ALTERNATE_NM                 */
/* R_X_SUBJECT_TELEPHONE_NO                 */
/* R_X_SUBJECT_EMAIL_ADDRESS                */
/* R_X_SUBJECT_URL_ADDRESS                  */
/********************************************/

proc sql noprint;

%ecmrr_add_subj_seq_no(indsn=R_X_SUBJECT_ADDRESS,
                       outdsn=zx_SUBJECT_ADDRESS
                       );
%if &successYN=N %then %goto mExit;

%ecmrr_add_subj_seq_no(indsn=R_X_SUBJECT_ID,
                       outdsn=zx_SUBJECT_ID
                       );
%if &successYN=N %then %goto mExit;

%ecmrr_add_subj_seq_no(indsn=R_X_SUBJECT_ALTERNATE_NM,
                       outdsn=zx_SUBJECT_ALTERNATE_NM
                       );
%if &successYN=N %then %goto mExit;

%ecmrr_add_subj_seq_no(indsn=R_X_SUBJECT_TELEPHONE_NO,
                       outdsn=zx_SUBJECT_TELEPHONE_NO
                       );
%if &successYN=N %then %goto mExit;

%ecmrr_add_subj_seq_no(indsn=R_X_SUBJECT_EMAIL_ADDRESS,
                       outdsn=zx_SUBJECT_EMAIL_ADDRESS
                       );
%if &successYN=N %then %goto mExit;

%ecmrr_add_subj_seq_no(indsn=R_X_SUBJECT_URL_ADDRESS,
                       outdsn=zx_SUBJECT_URL_ADDRESS
                       );
 
%if &successYN=N %then %goto mExit;

/*********************************************/
/* Prepare ZX_SUBJECT_RELATION_INST          */
/*********************************************/
/* For SARX. Subject Relation tin number is stored on X_SUBJECT_RELATION_INST so don't have   */
/* to join against X_INSTITUTION for TIN number.  Will use value from X_SUBJECT_RELATION_INST */
/* and rename to X_INST_TIN_NO so don't have to rename usage through rest of the programs.    */
	create table zx_subject_relation_inst as
	select distinct 1  as z_rr_seq_no,
                    subj.z_subject_seq_no,
                    mtr.*,
					mtr.x_subject_relation_tin_no as x_inst_tin_no
                    /*inst.x_inst_tin_no */		
	from   r_x_subject_relation_inst as mtr
	/*left join  r_x_institution as inst
	on mtr.x_inst_rk=inst.x_inst_rk*/
    left join zx_subject as subj 
	on mtr.x_subject_rk=subj.x_subject_rk
    order by  z_subject_seq_no, x_inst_rk
    ;
 


%if &sqlrc > 4 %then 
%do;
     %let successYN=N;
     %put %sysfunc(sasmsg(&smdds,GEN_STP_ABORT,NOQUOTE,&sysmacroname)) ;
     %goto mExit;
%end;


/*********************************************/
/* Prepare ZX_SUBJECT_INST_ACCT              */
/*********************************************/

	create table zx_subject_inst_acct as
	select 1  as z_rr_seq_no,
           subj.z_subject_seq_no,
           mtr.*, 
           acct.x_acct_id, 
           acct.x_acct_closed_flg            
	from r_x_subject_acct_inst as mtr
	left join r_x_subject_inst_acct as acct 
	on mtr.x_subject_rk=acct.x_subject_rk and mtr.x_acct_inst_rk=acct.x_acct_inst_rk
	left join zx_subject as subj
	on mtr.x_subject_rk=subj.x_subject_rk
	order by z_subject_seq_no, x_acct_inst_rk
;
quit;

%if &sqlrc > 4 %then 
%do;
     %let successYN=N;
     %put %sysfunc(sasmsg(&smdds,GEN_STP_ABORT,NOQUOTE,&sysmacroname)) ;
     %goto mExit;
%end;


%mExit:

%put %sysfunc(sasmsg(&smdds,GEN_MAC_END_NOTE,NOQUOTE,&sysmacroname)) ;

%mend;
 
